-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1200) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1200.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- Alter_Tab_FacialAcc_Cls_FacialCodeEx4000_to_FacialCodeEx100.sql
-- #########################################################
-- #########################################################

/*     FacialCodeEx 
  FacialAcc_Cls  100 */
ALTER TRIGGER TR_FACIALACC_CLS_BU_500 DISABLE
/
ALTER TABLE TB_FacialAcc_Cls ADD (
  FacialCodeExTEMP VARCHAR2(100)
)
/

CREATE OR REPLACE VIEW FacialAcc_Cls (
  ID,
  CODE1,
  CODE2,
  CODE3,
  CODE4,
  KVSR,
  KCSR,
  KFSR,
  KVR,
  KESR,
  FINTYPE,
  ORG_REF,
  DATEOPEN,
  SERVICEACCOUNT,
  STATUSACCOUNT,
  HARACTERACCOUNT,
  REGIONCLS,
  CREATEDATE,
  UPDATEDATE,
  FACIALCODE,
  MEANSTYPE,
  GENERALORG_REF,
  DEPARTMENTCLS,
  RVERSION,
  CLOSEDOCNUMBER,
  HIGHERORG_REF,
  BUDGETREF,
  FCACCOUNT,
  CLOSECODE,
  DATECLOSE,
  CREATERUSER,
  UPDATERUSER,
  NOTE,
  NAME,
  ISRBS,
  ISPBS,
  ISBU,
  ISSEPARATEBU,
  ISPROXY,
  OPENDOCNUMBER,
  ISOMS,
  CHANGEDOCNUMBER,
  DATECHANGE,
  GENERALORGFACIALACC,
  GRANTEEORG_REF,
  PREVCLS,
  FACIALCODEEX,
  FACIALCODEEXTEMP)
AS
  SELECT
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEX,
    FACIALCODEEXTEMP
  FROM TB_FacialAcc_Cls
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_ID
  INSTEAD OF DELETE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (facialacc_cls_bd0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(CONSTVALUE ) INTO CNT$1
  from INTCONST where ((CONSTVALUE = :old.id)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_CANNOTDELETE_FACIAL_ACC');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALACC_CLS
  WHERE ID = :OLD.ID
       AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALACC_CLS_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
     VALUES (19, :OLD.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_II
  INSTEAD OF INSERT
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$FACIALCODEEXTEMP FACIALACC_CLS.FACIALCODEEXTEMP%TYPE := :NEW.FACIALCODEEXTEMP;
--
  OrgDateClose$ Number;
  id_org$ NUMBER(10);
  id_reg$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALACC_CLS_BI_0)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  BEGIN

    --     
    select o.generalorg_ref
    into id_org$     from organizations o
    where o.id = new$org_ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (id_org$  is null) then
    id_org$ := new$org_ref;
  END IF;
  new$generalorg_ref := id_org$;
  BEGIN

    --      
    --  -
    --   --------------------------
    select o.RegionCLS
    into id_reg$     from Organizations o
    where o.ID = new$Org_Ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  new$regioncls := id_reg$;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALACC_CLS_BI_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

/*    -    */
   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALACC_CLS_BI_200)
-- Create 27.07.2007
-- - - - - - - - - - - - -

    if (new$Org_Ref is not null) then
      select DateClose into OrgDateClose$ from organizations where Id = new$Org_ref;
      if (OrgDateClose$ is not null) then
         if ((new$DateClose is null) or (new$DateClose > OrgDateClose$)) then
           new$DateClose := OrgDateClose$;
         end if;
         new$StatusAccount := 1;
         new$CloseCode := 10; /*   */
      end if;
    end if;

    if ((new$DateClose is not null) and (new$StatusAccount = 0)) then
      new$StatusAccount := 1;
      new$CloseCode := 1;
    end if;

    if (new$CloseCode is null) then new$CloseCode := 0; end if;

-- - - - - - - - - - - - -
-- BI_400 (TR_FACIALACC_CLS_BI_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALACC_CLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALACC_CLS (
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEX,
    FACIALCODEEXTEMP
  ) VALUES (
    new$ID,
    new$CODE1,
    new$CODE2,
    new$CODE3,
    new$CODE4,
    new$KVSR,
    new$KCSR,
    new$KFSR,
    new$KVR,
    new$KESR,
    new$FINTYPE,
    new$ORG_REF,
    new$DATEOPEN,
    new$SERVICEACCOUNT,
    new$STATUSACCOUNT,
    new$HARACTERACCOUNT,
    new$REGIONCLS,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$FACIALCODE,
    new$MEANSTYPE,
    new$GENERALORG_REF,
    new$DEPARTMENTCLS,
    new$RVERSION,
    new$CLOSEDOCNUMBER,
    new$HIGHERORG_REF,
    new$BUDGETREF,
    new$FCACCOUNT,
    new$CLOSECODE,
    new$DATECLOSE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$NOTE,
    new$NAME,
    new$ISRBS,
    new$ISPBS,
    new$ISBU,
    new$ISSEPARATEBU,
    new$ISPROXY,
    new$OPENDOCNUMBER,
    new$ISOMS,
    new$CHANGEDOCNUMBER,
    new$DATECHANGE,
    new$GENERALORGFACIALACC,
    new$GRANTEEORG_REF,
    new$PREVCLS,
    new$FACIALCODEEX,
    new$FACIALCODEEXTEMP);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALACC_CLS_AI_500)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 19) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_IU
  INSTEAD OF UPDATE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEX FACIALACC_CLS.FACIALCODEEX%TYPE := :NEW.FACIALCODEEX;
  new$FACIALCODEEXTEMP FACIALACC_CLS.FACIALCODEEXTEMP%TYPE := :NEW.FACIALCODEEXTEMP;
--
  id_org$ NUMBER(10);
  vOrgType$ NUMBER(10);
  id_org1$ NUMBER(10);
  id_reg1$ NUMBER(10);
  DiffCode$ NUMBER(10);
  Code1$ NUMBER(10);
  Code2$ NUMBER(10);
  Code51$ NUMBER(10);
  CodeX$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALACC_CLS_BU_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$id <> :old.id) then
    facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  if ((new$org_ref <> :old.org_ref) and not(new$fcaccount is null)) then
    BEGIN
      select org_ref      into id_org1$ from org_accounts
      where id = new$fcaccount
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (id_org1$ <> new$org_ref) then
      new$fcaccount := null;

    END IF;
  END IF;
  if (:old.Org_Ref <> new$Org_Ref) then
    BEGIN
      --   --------------------------
      select o.RegionCLS
      into id_reg1$        from Organizations o
      where o.ID = new$Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    --   -----------------

    new$regioncls := id_reg1$;
    BEGIN
      --       /----
      select o.Org_Type
      into vOrgType$      from Organizations o
      where o.ID = :old.Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType$  >= 10800)and(vOrgType$  <= 10900)) then
      update org_accounts
      set facialacc_cls = null
      where facialacc_cls = :old.id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_FACIALACC_CLS_BU_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALACC_CLS_BU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /* /  ??     ??   AU   */
  if ((((new$DateClose is not null) and (:old.DateClose is null)) or
  ((new$DateClose is null) and (:old.DateClose is not null)))
  and (new$CloseCode = :old.CloseCode))
  then
    BEGIN
      /*      /    .
                / ??    ?
          */
      select o.Org_Type     into vOrgType1$ from Organizations o where o.id = new$org_ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType1$  >= 10800)and(vOrgType1$  <= 10900)) then
      if (new$DateClose is not null or (new$statusaccount = 1 and :old.statusaccount=0))
      then
        update org_accounts set
        CloseCode = CloseCode + 10000,
        DateClose = new$DateClose
        where facialacc_cls = new$id;

      END IF;
      if (new$DateClose is null or (new$statusaccount = 0 and :old.statusaccount=1))
      then
        update org_accounts set
        CloseCode = CloseCode - 10000
        where facialacc_cls = new$id;

      END IF;
    END IF;
    if (new$DateClose is not null) then
      new$CloseCode := 1;
    END IF;
    if (new$DateClose is null) then
      new$CloseCode := 0;

    END IF;
  END IF;

  /* /   (only      ) */
  if (new$CloseCode <> :old.CloseCode)
  then
    DiffCode$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
    CloseOrgCls_Div(:old.CloseCode,Code1$, Code2$, CodeX$, CodeX$, Code51$);

    /*   "" */
    if (DiffCode$ = 1) then
      Code1$ := 1;
    END IF;
    if (DiffCode$ = 10) then
      Code2$ := 1;
    END IF;
    if (DiffCode$ = 10000) then
      Code51$ := 1;
    END IF;
    if (DiffCode$ = -1) then
      Code1$ := 0;
    END IF;
    if (DiffCode$ = -10) then
      Code2$ := 0;
    END IF;
    if (DiffCode$ = -10000) then
      Code51$ := 0;
    END IF;
    new$CloseCode := Code1$ + Code2$*10 + Code51$*10000;

    if (new$CloseCode <> 0) then
      new$StatusAccount := 1;
    END IF;

    /*     ??      -  - !*/
    if (((new$CloseCode <> 0) and (new$DateClose is null)) or (new$DateClose >= :old.DateClose)) then
      new$DateClose := :old.DateClose;

    else
      if (new$CloseCode = 0) then
        new$DateClose := null;
        if (new$StatusAccount <> 0) then
          new$StatusAccount := 0;

        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_FACIALACC_CLS_BU_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_550 (TR_FACIALACC_CLS_BU_550)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF ((new$GeneralOrg_ref IS NULL)or(new$Org_Ref <> :old.Org_Ref)) THEN
     select
       o.GeneralOrg_Ref
     into
       id_org$
     from
       Organizations o
     where
       o.id = new$Org_Ref;
      /*      */
     if (id_org$ is Null)
       then id_org$ := new$Org_Ref;
     end if;
     new$GeneralOrg_ref := id_org$;

   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALACC_CLS_BU_700)
-- Create 19.09.2004
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (NEW$RVersion IS NULL) THEN
      NEW$RVersion := 1;
   ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      NEW$RVersion := :OLD.RVersion;
   ELSE
      NEW$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALACC_CLS SET
    ID = new$ID,
    CODE1 = new$CODE1,
    CODE2 = new$CODE2,
    CODE3 = new$CODE3,
    CODE4 = new$CODE4,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KFSR = new$KFSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FINTYPE = new$FINTYPE,
    ORG_REF = new$ORG_REF,
    DATEOPEN = new$DATEOPEN,
    SERVICEACCOUNT = new$SERVICEACCOUNT,
    STATUSACCOUNT = new$STATUSACCOUNT,
    HARACTERACCOUNT = new$HARACTERACCOUNT,
    REGIONCLS = new$REGIONCLS,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    FACIALCODE = new$FACIALCODE,
    MEANSTYPE = new$MEANSTYPE,
    GENERALORG_REF = new$GENERALORG_REF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    RVERSION = new$RVERSION,
    CLOSEDOCNUMBER = new$CLOSEDOCNUMBER,
    HIGHERORG_REF = new$HIGHERORG_REF,
    BUDGETREF = new$BUDGETREF,
    FCACCOUNT = new$FCACCOUNT,
    CLOSECODE = new$CLOSECODE,
    DATECLOSE = new$DATECLOSE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    NAME = new$NAME,
    ISRBS = new$ISRBS,
    ISPBS = new$ISPBS,
    ISBU = new$ISBU,
    ISSEPARATEBU = new$ISSEPARATEBU,
    ISPROXY = new$ISPROXY,
    OPENDOCNUMBER = new$OPENDOCNUMBER,
    ISOMS = new$ISOMS,
    CHANGEDOCNUMBER = new$CHANGEDOCNUMBER,
    DATECHANGE = new$DATECHANGE,
    GENERALORGFACIALACC = new$GENERALORGFACIALACC,
    GRANTEEORG_REF = new$GRANTEEORG_REF,
    PREVCLS = new$PREVCLS,
    FACIALCODEEX = new$FACIALCODEEX,
    FACIALCODEEXTEMP = new$FACIALCODEEXTEMP
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALACC_CLS_AU_500)
-- Create 28.04.2005
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (19, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 19) AND (RecordId = new$ID);
   END IF;

END;
/
update FacialAcc_Cls set FacialCodeExTEMP = SUBSTR(FacialCodeEx ,1 ,100)
/
ALTER TABLE TB_FacialAcc_Cls DROP (FacialCodeEx)
/

CREATE OR REPLACE VIEW FacialAcc_Cls (
  ID,
  CODE1,
  CODE2,
  CODE3,
  CODE4,
  KVSR,
  KCSR,
  KFSR,
  KVR,
  KESR,
  FINTYPE,
  ORG_REF,
  DATEOPEN,
  SERVICEACCOUNT,
  STATUSACCOUNT,
  HARACTERACCOUNT,
  REGIONCLS,
  CREATEDATE,
  UPDATEDATE,
  FACIALCODE,
  MEANSTYPE,
  GENERALORG_REF,
  DEPARTMENTCLS,
  RVERSION,
  CLOSEDOCNUMBER,
  HIGHERORG_REF,
  BUDGETREF,
  FCACCOUNT,
  CLOSECODE,
  DATECLOSE,
  CREATERUSER,
  UPDATERUSER,
  NOTE,
  NAME,
  ISRBS,
  ISPBS,
  ISBU,
  ISSEPARATEBU,
  ISPROXY,
  OPENDOCNUMBER,
  ISOMS,
  CHANGEDOCNUMBER,
  DATECHANGE,
  GENERALORGFACIALACC,
  GRANTEEORG_REF,
  PREVCLS,
  FACIALCODEEXTEMP)
AS
  SELECT
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEXTEMP
  FROM TB_FacialAcc_Cls
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_ID
  INSTEAD OF DELETE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (facialacc_cls_bd0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(CONSTVALUE ) INTO CNT$1
  from INTCONST where ((CONSTVALUE = :old.id)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_CANNOTDELETE_FACIAL_ACC');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALACC_CLS
  WHERE ID = :OLD.ID
       AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALACC_CLS_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
     VALUES (19, :OLD.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_II
  INSTEAD OF INSERT
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEXTEMP FACIALACC_CLS.FACIALCODEEXTEMP%TYPE := :NEW.FACIALCODEEXTEMP;
--
  OrgDateClose$ Number;
  id_org$ NUMBER(10);
  id_reg$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALACC_CLS_BI_0)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  BEGIN

    --     
    select o.generalorg_ref
    into id_org$     from organizations o
    where o.id = new$org_ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (id_org$  is null) then
    id_org$ := new$org_ref;
  END IF;
  new$generalorg_ref := id_org$;
  BEGIN

    --      
    --  -
    --   --------------------------
    select o.RegionCLS
    into id_reg$     from Organizations o
    where o.ID = new$Org_Ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  new$regioncls := id_reg$;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALACC_CLS_BI_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

/*    -    */
   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALACC_CLS_BI_200)
-- Create 27.07.2007
-- - - - - - - - - - - - -

    if (new$Org_Ref is not null) then
      select DateClose into OrgDateClose$ from organizations where Id = new$Org_ref;
      if (OrgDateClose$ is not null) then
         if ((new$DateClose is null) or (new$DateClose > OrgDateClose$)) then
           new$DateClose := OrgDateClose$;
         end if;
         new$StatusAccount := 1;
         new$CloseCode := 10; /*   */
      end if;
    end if;

    if ((new$DateClose is not null) and (new$StatusAccount = 0)) then
      new$StatusAccount := 1;
      new$CloseCode := 1;
    end if;

    if (new$CloseCode is null) then new$CloseCode := 0; end if;

-- - - - - - - - - - - - -
-- BI_400 (TR_FACIALACC_CLS_BI_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALACC_CLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALACC_CLS (
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FACIALCODEEXTEMP
  ) VALUES (
    new$ID,
    new$CODE1,
    new$CODE2,
    new$CODE3,
    new$CODE4,
    new$KVSR,
    new$KCSR,
    new$KFSR,
    new$KVR,
    new$KESR,
    new$FINTYPE,
    new$ORG_REF,
    new$DATEOPEN,
    new$SERVICEACCOUNT,
    new$STATUSACCOUNT,
    new$HARACTERACCOUNT,
    new$REGIONCLS,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$FACIALCODE,
    new$MEANSTYPE,
    new$GENERALORG_REF,
    new$DEPARTMENTCLS,
    new$RVERSION,
    new$CLOSEDOCNUMBER,
    new$HIGHERORG_REF,
    new$BUDGETREF,
    new$FCACCOUNT,
    new$CLOSECODE,
    new$DATECLOSE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$NOTE,
    new$NAME,
    new$ISRBS,
    new$ISPBS,
    new$ISBU,
    new$ISSEPARATEBU,
    new$ISPROXY,
    new$OPENDOCNUMBER,
    new$ISOMS,
    new$CHANGEDOCNUMBER,
    new$DATECHANGE,
    new$GENERALORGFACIALACC,
    new$GRANTEEORG_REF,
    new$PREVCLS,
    new$FACIALCODEEXTEMP);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALACC_CLS_AI_500)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 19) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_IU
  INSTEAD OF UPDATE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FACIALCODEEXTEMP FACIALACC_CLS.FACIALCODEEXTEMP%TYPE := :NEW.FACIALCODEEXTEMP;
--
  id_org$ NUMBER(10);
  vOrgType$ NUMBER(10);
  id_org1$ NUMBER(10);
  id_reg1$ NUMBER(10);
  DiffCode$ NUMBER(10);
  Code1$ NUMBER(10);
  Code2$ NUMBER(10);
  Code51$ NUMBER(10);
  CodeX$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALACC_CLS_BU_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$id <> :old.id) then
    facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  if ((new$org_ref <> :old.org_ref) and not(new$fcaccount is null)) then
    BEGIN
      select org_ref      into id_org1$ from org_accounts
      where id = new$fcaccount
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (id_org1$ <> new$org_ref) then
      new$fcaccount := null;

    END IF;
  END IF;
  if (:old.Org_Ref <> new$Org_Ref) then
    BEGIN
      --   --------------------------
      select o.RegionCLS
      into id_reg1$        from Organizations o
      where o.ID = new$Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    --   -----------------

    new$regioncls := id_reg1$;
    BEGIN
      --       /----
      select o.Org_Type
      into vOrgType$      from Organizations o
      where o.ID = :old.Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType$  >= 10800)and(vOrgType$  <= 10900)) then
      update org_accounts
      set facialacc_cls = null
      where facialacc_cls = :old.id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_FACIALACC_CLS_BU_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALACC_CLS_BU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /* /  ??     ??   AU   */
  if ((((new$DateClose is not null) and (:old.DateClose is null)) or
  ((new$DateClose is null) and (:old.DateClose is not null)))
  and (new$CloseCode = :old.CloseCode))
  then
    BEGIN
      /*      /    .
                / ??    ?
          */
      select o.Org_Type     into vOrgType1$ from Organizations o where o.id = new$org_ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType1$  >= 10800)and(vOrgType1$  <= 10900)) then
      if (new$DateClose is not null or (new$statusaccount = 1 and :old.statusaccount=0))
      then
        update org_accounts set
        CloseCode = CloseCode + 10000,
        DateClose = new$DateClose
        where facialacc_cls = new$id;

      END IF;
      if (new$DateClose is null or (new$statusaccount = 0 and :old.statusaccount=1))
      then
        update org_accounts set
        CloseCode = CloseCode - 10000
        where facialacc_cls = new$id;

      END IF;
    END IF;
    if (new$DateClose is not null) then
      new$CloseCode := 1;
    END IF;
    if (new$DateClose is null) then
      new$CloseCode := 0;

    END IF;
  END IF;

  /* /   (only      ) */
  if (new$CloseCode <> :old.CloseCode)
  then
    DiffCode$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
    CloseOrgCls_Div(:old.CloseCode,Code1$, Code2$, CodeX$, CodeX$, Code51$);

    /*   "" */
    if (DiffCode$ = 1) then
      Code1$ := 1;
    END IF;
    if (DiffCode$ = 10) then
      Code2$ := 1;
    END IF;
    if (DiffCode$ = 10000) then
      Code51$ := 1;
    END IF;
    if (DiffCode$ = -1) then
      Code1$ := 0;
    END IF;
    if (DiffCode$ = -10) then
      Code2$ := 0;
    END IF;
    if (DiffCode$ = -10000) then
      Code51$ := 0;
    END IF;
    new$CloseCode := Code1$ + Code2$*10 + Code51$*10000;

    if (new$CloseCode <> 0) then
      new$StatusAccount := 1;
    END IF;

    /*     ??      -  - !*/
    if (((new$CloseCode <> 0) and (new$DateClose is null)) or (new$DateClose >= :old.DateClose)) then
      new$DateClose := :old.DateClose;

    else
      if (new$CloseCode = 0) then
        new$DateClose := null;
        if (new$StatusAccount <> 0) then
          new$StatusAccount := 0;

        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_FACIALACC_CLS_BU_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_550 (TR_FACIALACC_CLS_BU_550)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF ((new$GeneralOrg_ref IS NULL)or(new$Org_Ref <> :old.Org_Ref)) THEN
     select
       o.GeneralOrg_Ref
     into
       id_org$
     from
       Organizations o
     where
       o.id = new$Org_Ref;
      /*      */
     if (id_org$ is Null)
       then id_org$ := new$Org_Ref;
     end if;
     new$GeneralOrg_ref := id_org$;

   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALACC_CLS_BU_700)
-- Create 19.09.2004
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (NEW$RVersion IS NULL) THEN
      NEW$RVersion := 1;
   ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      NEW$RVersion := :OLD.RVersion;
   ELSE
      NEW$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALACC_CLS SET
    ID = new$ID,
    CODE1 = new$CODE1,
    CODE2 = new$CODE2,
    CODE3 = new$CODE3,
    CODE4 = new$CODE4,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KFSR = new$KFSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FINTYPE = new$FINTYPE,
    ORG_REF = new$ORG_REF,
    DATEOPEN = new$DATEOPEN,
    SERVICEACCOUNT = new$SERVICEACCOUNT,
    STATUSACCOUNT = new$STATUSACCOUNT,
    HARACTERACCOUNT = new$HARACTERACCOUNT,
    REGIONCLS = new$REGIONCLS,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    FACIALCODE = new$FACIALCODE,
    MEANSTYPE = new$MEANSTYPE,
    GENERALORG_REF = new$GENERALORG_REF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    RVERSION = new$RVERSION,
    CLOSEDOCNUMBER = new$CLOSEDOCNUMBER,
    HIGHERORG_REF = new$HIGHERORG_REF,
    BUDGETREF = new$BUDGETREF,
    FCACCOUNT = new$FCACCOUNT,
    CLOSECODE = new$CLOSECODE,
    DATECLOSE = new$DATECLOSE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    NAME = new$NAME,
    ISRBS = new$ISRBS,
    ISPBS = new$ISPBS,
    ISBU = new$ISBU,
    ISSEPARATEBU = new$ISSEPARATEBU,
    ISPROXY = new$ISPROXY,
    OPENDOCNUMBER = new$OPENDOCNUMBER,
    ISOMS = new$ISOMS,
    CHANGEDOCNUMBER = new$CHANGEDOCNUMBER,
    DATECHANGE = new$DATECHANGE,
    GENERALORGFACIALACC = new$GENERALORGFACIALACC,
    GRANTEEORG_REF = new$GRANTEEORG_REF,
    PREVCLS = new$PREVCLS,
    FACIALCODEEXTEMP = new$FACIALCODEEXTEMP
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALACC_CLS_AU_500)
-- Create 28.04.2005
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (19, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 19) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TABLE TB_FacialAcc_Cls RENAME COLUMN FacialCodeExTEMP TO FacialCodeEx
/

CREATE OR REPLACE VIEW FacialAcc_Cls (
  ID,
  CODE1,
  CODE2,
  CODE3,
  CODE4,
  KVSR,
  KCSR,
  KFSR,
  KVR,
  KESR,
  FINTYPE,
  ORG_REF,
  DATEOPEN,
  SERVICEACCOUNT,
  STATUSACCOUNT,
  HARACTERACCOUNT,
  REGIONCLS,
  CREATEDATE,
  UPDATEDATE,
  FACIALCODE,
  MEANSTYPE,
  GENERALORG_REF,
  DEPARTMENTCLS,
  RVERSION,
  CLOSEDOCNUMBER,
  HIGHERORG_REF,
  BUDGETREF,
  FCACCOUNT,
  CLOSECODE,
  DATECLOSE,
  CREATERUSER,
  UPDATERUSER,
  NOTE,
  NAME,
  ISRBS,
  ISPBS,
  ISBU,
  ISSEPARATEBU,
  ISPROXY,
  OPENDOCNUMBER,
  ISOMS,
  CHANGEDOCNUMBER,
  DATECHANGE,
  GENERALORGFACIALACC,
  GRANTEEORG_REF,
  PREVCLS,
  FacialCodeEx)
AS
  SELECT
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FacialCodeEx
  FROM TB_FacialAcc_Cls
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_ID
  INSTEAD OF DELETE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (facialacc_cls_bd0)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(CONSTVALUE ) INTO CNT$1
  from INTCONST where ((CONSTVALUE = :old.id)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_CANNOTDELETE_FACIAL_ACC');
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_FACIALACC_CLS
  WHERE ID = :OLD.ID
       AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AD_500 (TR_FACIALACC_CLS_AD_500)
-- Last update 20.05.2005
-- - - - - - - - - - - - -

   INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
     VALUES (19, :OLD.ID, SYSDATE);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_II
  INSTEAD OF INSERT
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FacialCodeEx FACIALACC_CLS.FacialCodeEx%TYPE := :NEW.FacialCodeEx;
--
  OrgDateClose$ Number;
  id_org$ NUMBER(10);
  id_reg$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACIALACC_CLS_BI_0)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  BEGIN

    --     
    select o.generalorg_ref
    into id_org$     from organizations o
    where o.id = new$org_ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (id_org$  is null) then
    id_org$ := new$org_ref;
  END IF;
  new$generalorg_ref := id_org$;
  BEGIN

    --      
    --  -
    --   --------------------------
    select o.RegionCLS
    into id_reg$     from Organizations o
    where o.ID = new$Org_Ref
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  new$regioncls := id_reg$;

-- - - - - - - - - - - - -
-- BI_100 (TR_FACIALACC_CLS_BI_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

/*    -    */
   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_FACIALACC_CLS_BI_200)
-- Create 27.07.2007
-- - - - - - - - - - - - -

    if (new$Org_Ref is not null) then
      select DateClose into OrgDateClose$ from organizations where Id = new$Org_ref;
      if (OrgDateClose$ is not null) then
         if ((new$DateClose is null) or (new$DateClose > OrgDateClose$)) then
           new$DateClose := OrgDateClose$;
         end if;
         new$StatusAccount := 1;
         new$CloseCode := 10; /*   */
      end if;
    end if;

    if ((new$DateClose is not null) and (new$StatusAccount = 0)) then
      new$StatusAccount := 1;
      new$CloseCode := 1;
    end if;

    if (new$CloseCode is null) then new$CloseCode := 0; end if;

-- - - - - - - - - - - - -
-- BI_400 (TR_FACIALACC_CLS_BI_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACIALACC_CLS_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_FACIALACC_CLS (
    ID,
    CODE1,
    CODE2,
    CODE3,
    CODE4,
    KVSR,
    KCSR,
    KFSR,
    KVR,
    KESR,
    FINTYPE,
    ORG_REF,
    DATEOPEN,
    SERVICEACCOUNT,
    STATUSACCOUNT,
    HARACTERACCOUNT,
    REGIONCLS,
    CREATEDATE,
    UPDATEDATE,
    FACIALCODE,
    MEANSTYPE,
    GENERALORG_REF,
    DEPARTMENTCLS,
    RVERSION,
    CLOSEDOCNUMBER,
    HIGHERORG_REF,
    BUDGETREF,
    FCACCOUNT,
    CLOSECODE,
    DATECLOSE,
    CREATERUSER,
    UPDATERUSER,
    NOTE,
    NAME,
    ISRBS,
    ISPBS,
    ISBU,
    ISSEPARATEBU,
    ISPROXY,
    OPENDOCNUMBER,
    ISOMS,
    CHANGEDOCNUMBER,
    DATECHANGE,
    GENERALORGFACIALACC,
    GRANTEEORG_REF,
    PREVCLS,
    FacialCodeEx
  ) VALUES (
    new$ID,
    new$CODE1,
    new$CODE2,
    new$CODE3,
    new$CODE4,
    new$KVSR,
    new$KCSR,
    new$KFSR,
    new$KVR,
    new$KESR,
    new$FINTYPE,
    new$ORG_REF,
    new$DATEOPEN,
    new$SERVICEACCOUNT,
    new$STATUSACCOUNT,
    new$HARACTERACCOUNT,
    new$REGIONCLS,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$FACIALCODE,
    new$MEANSTYPE,
    new$GENERALORG_REF,
    new$DEPARTMENTCLS,
    new$RVERSION,
    new$CLOSEDOCNUMBER,
    new$HIGHERORG_REF,
    new$BUDGETREF,
    new$FCACCOUNT,
    new$CLOSECODE,
    new$DATECLOSE,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$NOTE,
    new$NAME,
    new$ISRBS,
    new$ISPBS,
    new$ISBU,
    new$ISSEPARATEBU,
    new$ISPROXY,
    new$OPENDOCNUMBER,
    new$ISOMS,
    new$CHANGEDOCNUMBER,
    new$DATECHANGE,
    new$GENERALORGFACIALACC,
    new$GRANTEEORG_REF,
    new$PREVCLS,
    new$FacialCodeEx);

-- - - - - - - - - - - - -
-- AI_500 (TR_FACIALACC_CLS_AI_500)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 19) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_FACIALACC_CLS_IU
  INSTEAD OF UPDATE
  ON FACIALACC_CLS
  FOR EACH ROW
DECLARE
  new$ID FACIALACC_CLS.ID%TYPE := :NEW.ID;
  new$CODE1 FACIALACC_CLS.CODE1%TYPE := :NEW.CODE1;
  new$CODE2 FACIALACC_CLS.CODE2%TYPE := :NEW.CODE2;
  new$CODE3 FACIALACC_CLS.CODE3%TYPE := :NEW.CODE3;
  new$CODE4 FACIALACC_CLS.CODE4%TYPE := :NEW.CODE4;
  new$KVSR FACIALACC_CLS.KVSR%TYPE := :NEW.KVSR;
  new$KCSR FACIALACC_CLS.KCSR%TYPE := :NEW.KCSR;
  new$KFSR FACIALACC_CLS.KFSR%TYPE := :NEW.KFSR;
  new$KVR FACIALACC_CLS.KVR%TYPE := :NEW.KVR;
  new$KESR FACIALACC_CLS.KESR%TYPE := :NEW.KESR;
  new$FINTYPE FACIALACC_CLS.FINTYPE%TYPE := :NEW.FINTYPE;
  new$ORG_REF FACIALACC_CLS.ORG_REF%TYPE := :NEW.ORG_REF;
  new$DATEOPEN FACIALACC_CLS.DATEOPEN%TYPE := :NEW.DATEOPEN;
  new$SERVICEACCOUNT FACIALACC_CLS.SERVICEACCOUNT%TYPE := :NEW.SERVICEACCOUNT;
  new$STATUSACCOUNT FACIALACC_CLS.STATUSACCOUNT%TYPE := :NEW.STATUSACCOUNT;
  new$HARACTERACCOUNT FACIALACC_CLS.HARACTERACCOUNT%TYPE := :NEW.HARACTERACCOUNT;
  new$REGIONCLS FACIALACC_CLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATEDATE FACIALACC_CLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE FACIALACC_CLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$FACIALCODE FACIALACC_CLS.FACIALCODE%TYPE := :NEW.FACIALCODE;
  new$MEANSTYPE FACIALACC_CLS.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$GENERALORG_REF FACIALACC_CLS.GENERALORG_REF%TYPE := :NEW.GENERALORG_REF;
  new$DEPARTMENTCLS FACIALACC_CLS.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$RVERSION FACIALACC_CLS.RVERSION%TYPE := :NEW.RVERSION;
  new$CLOSEDOCNUMBER FACIALACC_CLS.CLOSEDOCNUMBER%TYPE := :NEW.CLOSEDOCNUMBER;
  new$HIGHERORG_REF FACIALACC_CLS.HIGHERORG_REF%TYPE := :NEW.HIGHERORG_REF;
  new$BUDGETREF FACIALACC_CLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$FCACCOUNT FACIALACC_CLS.FCACCOUNT%TYPE := :NEW.FCACCOUNT;
  new$CLOSECODE FACIALACC_CLS.CLOSECODE%TYPE := :NEW.CLOSECODE;
  new$DATECLOSE FACIALACC_CLS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$CREATERUSER FACIALACC_CLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER FACIALACC_CLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE FACIALACC_CLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME FACIALACC_CLS.NAME%TYPE := :NEW.NAME;
  new$ISRBS FACIALACC_CLS.ISRBS%TYPE := :NEW.ISRBS;
  new$ISPBS FACIALACC_CLS.ISPBS%TYPE := :NEW.ISPBS;
  new$ISBU FACIALACC_CLS.ISBU%TYPE := :NEW.ISBU;
  new$ISSEPARATEBU FACIALACC_CLS.ISSEPARATEBU%TYPE := :NEW.ISSEPARATEBU;
  new$ISPROXY FACIALACC_CLS.ISPROXY%TYPE := :NEW.ISPROXY;
  new$OPENDOCNUMBER FACIALACC_CLS.OPENDOCNUMBER%TYPE := :NEW.OPENDOCNUMBER;
  new$ISOMS FACIALACC_CLS.ISOMS%TYPE := :NEW.ISOMS;
  new$CHANGEDOCNUMBER FACIALACC_CLS.CHANGEDOCNUMBER%TYPE := :NEW.CHANGEDOCNUMBER;
  new$DATECHANGE FACIALACC_CLS.DATECHANGE%TYPE := :NEW.DATECHANGE;
  new$GENERALORGFACIALACC FACIALACC_CLS.GENERALORGFACIALACC%TYPE := :NEW.GENERALORGFACIALACC;
  new$GRANTEEORG_REF FACIALACC_CLS.GRANTEEORG_REF%TYPE := :NEW.GRANTEEORG_REF;
  new$PREVCLS FACIALACC_CLS.PREVCLS%TYPE := :NEW.PREVCLS;
  new$FacialCodeEx FACIALACC_CLS.FacialCodeEx%TYPE := :NEW.FacialCodeEx;
--
  id_org$ NUMBER(10);
  vOrgType$ NUMBER(10);
  id_org1$ NUMBER(10);
  id_reg1$ NUMBER(10);
  DiffCode$ NUMBER(10);
  Code1$ NUMBER(10);
  Code2$ NUMBER(10);
  Code51$ NUMBER(10);
  CodeX$ NUMBER(10);
  vOrgType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FACIALACC_CLS_BU_0)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$id <> :old.id) then
    facialacc_clsdiv(new$id,new$code1,new$code2,new$code3,new$code4);
  END IF;
  if (new$kvsr is null) then
    new$kvsr := 0;
  END IF;
  if (new$kcsr is null) then
    new$kcsr := 0;
  END IF;
  if (new$kfsr is null) then
    new$kfsr := 0;
  END IF;
  if (new$kvr is null) then
    new$kvr := 0;
  END IF;
  if (new$kesr is null) then
    new$kesr := 0;
  END IF;
  if (new$fintype is null) then
    new$fintype := 0;
  END IF;
  if (new$regioncls is null) then
    new$regioncls := 0;
  END IF;
  if (new$meanstype is null) then
    new$meanstype := 0;
  END IF;
  if (new$haracteraccount is null) then
    new$haracteraccount := 0;
  END IF;
  if (new$org_ref is null) then
    new$org_ref := 0; -- ,   select min (...)
  END IF;
  if ((new$org_ref <> :old.org_ref) and not(new$fcaccount is null)) then
    BEGIN
      select org_ref      into id_org1$ from org_accounts
      where id = new$fcaccount
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (id_org1$ <> new$org_ref) then
      new$fcaccount := null;

    END IF;
  END IF;
  if (:old.Org_Ref <> new$Org_Ref) then
    BEGIN
      --   --------------------------
      select o.RegionCLS
      into id_reg1$        from Organizations o
      where o.ID = new$Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    --   -----------------

    new$regioncls := id_reg1$;
    BEGIN
      --       /----
      select o.Org_Type
      into vOrgType$      from Organizations o
      where o.ID = :old.Org_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType$  >= 10800)and(vOrgType$  <= 10900)) then
      update org_accounts
      set facialacc_cls = null
      where facialacc_cls = :old.id;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_FACIALACC_CLS_BU_100)
-- Create 01.12.2005
-- - - - - - - - - - - - -

   IF (    (   (new$ID = 0)
            OR (new$serviceaccount = 0)
            OR (new$serviceaccount IS NULL)
           )
       AND (new$budgetref IS NULL)
      ) THEN
      new$budgetRef := 0;
   END IF;

   IF (    (new$ID <> 0)
       AND (new$serviceaccount = 1)
       AND ((new$budgetref IS NULL) OR (new$budgetref = 0))
      ) THEN
      getintconst (-1, 3, new$budgetRef);
   END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_FACIALACC_CLS_BU_200)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  /* /  ??     ??   AU   */
  if ((((new$DateClose is not null) and (:old.DateClose is null)) or
  ((new$DateClose is null) and (:old.DateClose is not null)))
  and (new$CloseCode = :old.CloseCode))
  then
    BEGIN
      /*      /    .
                / ??    ?
          */
      select o.Org_Type     into vOrgType1$ from Organizations o where o.id = new$org_ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((vOrgType1$  >= 10800)and(vOrgType1$  <= 10900)) then
      if (new$DateClose is not null or (new$statusaccount = 1 and :old.statusaccount=0))
      then
        update org_accounts set
        CloseCode = CloseCode + 10000,
        DateClose = new$DateClose
        where facialacc_cls = new$id;

      END IF;
      if (new$DateClose is null or (new$statusaccount = 0 and :old.statusaccount=1))
      then
        update org_accounts set
        CloseCode = CloseCode - 10000
        where facialacc_cls = new$id;

      END IF;
    END IF;
    if (new$DateClose is not null) then
      new$CloseCode := 1;
    END IF;
    if (new$DateClose is null) then
      new$CloseCode := 0;

    END IF;
  END IF;

  /* /   (only      ) */
  if (new$CloseCode <> :old.CloseCode)
  then
    DiffCode$ := new$CloseCode - :old.CloseCode; /* >0 -  , <0 -  */
    CloseOrgCls_Div(:old.CloseCode,Code1$, Code2$, CodeX$, CodeX$, Code51$);

    /*   "" */
    if (DiffCode$ = 1) then
      Code1$ := 1;
    END IF;
    if (DiffCode$ = 10) then
      Code2$ := 1;
    END IF;
    if (DiffCode$ = 10000) then
      Code51$ := 1;
    END IF;
    if (DiffCode$ = -1) then
      Code1$ := 0;
    END IF;
    if (DiffCode$ = -10) then
      Code2$ := 0;
    END IF;
    if (DiffCode$ = -10000) then
      Code51$ := 0;
    END IF;
    new$CloseCode := Code1$ + Code2$*10 + Code51$*10000;

    if (new$CloseCode <> 0) then
      new$StatusAccount := 1;
    END IF;

    /*     ??      -  - !*/
    if (((new$CloseCode <> 0) and (new$DateClose is null)) or (new$DateClose >= :old.DateClose)) then
      new$DateClose := :old.DateClose;

    else
      if (new$CloseCode = 0) then
        new$DateClose := null;
        if (new$StatusAccount <> 0) then
          new$StatusAccount := 0;

        END IF;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_FACIALACC_CLS_BU_400)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$IsRBS is null) then
    if (new$HaracterAccount in (1, 2)) then
      new$IsRBS := 1;

    else
      new$IsRBS := 0;

    END IF;
  END IF;
  if (new$IsPBS is null) then
    if (new$HaracterAccount in (0, 2)) then
      new$IsPBS := 1;

    else
      new$IsPBS := 0;

    END IF;
  END IF;
  if (new$IsBU is null) then
    new$IsBU := 0;
  END IF;
  if (new$IsOMS is null) then
    new$IsOMS := 0;
  END IF;
  if (new$IsSeparateBU is null) then
    new$IsSeparateBU := 0;
  END IF;
  if (new$IsProxy is null) then
    new$IsProxy := 0;
  END IF;
  if ((new$IsRBS + new$IsPBS + new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) = 0) then
    new$HaracterAccount := 3;

  else
    if ((new$IsBU + new$IsOMS + new$IsSeparateBU + new$IsProxy) > 0) then
      new$HaracterAccount := 0;

    else
      if (new$IsRBS = 1) then
        new$HaracterAccount := new$IsRBS + new$IsPBS;

      else
        new$HaracterAccount := 0;
      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_550 (TR_FACIALACC_CLS_BU_550)
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF ((new$GeneralOrg_ref IS NULL)or(new$Org_Ref <> :old.Org_Ref)) THEN
     select
       o.GeneralOrg_Ref
     into
       id_org$
     from
       Organizations o
     where
       o.id = new$Org_Ref;
      /*      */
     if (id_org$ is Null)
       then id_org$ := new$Org_Ref;
     end if;
     new$GeneralOrg_ref := id_org$;

   END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_FACIALACC_CLS_BU_700)
-- Create 19.09.2004
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (NEW$RVersion IS NULL) THEN
      NEW$RVersion := 1;
   ELSIF ((NEW$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      NEW$RVersion := :OLD.RVersion;
   ELSE
      NEW$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_FACIALACC_CLS SET
    ID = new$ID,
    CODE1 = new$CODE1,
    CODE2 = new$CODE2,
    CODE3 = new$CODE3,
    CODE4 = new$CODE4,
    KVSR = new$KVSR,
    KCSR = new$KCSR,
    KFSR = new$KFSR,
    KVR = new$KVR,
    KESR = new$KESR,
    FINTYPE = new$FINTYPE,
    ORG_REF = new$ORG_REF,
    DATEOPEN = new$DATEOPEN,
    SERVICEACCOUNT = new$SERVICEACCOUNT,
    STATUSACCOUNT = new$STATUSACCOUNT,
    HARACTERACCOUNT = new$HARACTERACCOUNT,
    REGIONCLS = new$REGIONCLS,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    FACIALCODE = new$FACIALCODE,
    MEANSTYPE = new$MEANSTYPE,
    GENERALORG_REF = new$GENERALORG_REF,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    RVERSION = new$RVERSION,
    CLOSEDOCNUMBER = new$CLOSEDOCNUMBER,
    HIGHERORG_REF = new$HIGHERORG_REF,
    BUDGETREF = new$BUDGETREF,
    FCACCOUNT = new$FCACCOUNT,
    CLOSECODE = new$CLOSECODE,
    DATECLOSE = new$DATECLOSE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    NAME = new$NAME,
    ISRBS = new$ISRBS,
    ISPBS = new$ISPBS,
    ISBU = new$ISBU,
    ISSEPARATEBU = new$ISSEPARATEBU,
    ISPROXY = new$ISPROXY,
    OPENDOCNUMBER = new$OPENDOCNUMBER,
    ISOMS = new$ISOMS,
    CHANGEDOCNUMBER = new$CHANGEDOCNUMBER,
    DATECHANGE = new$DATECHANGE,
    GENERALORGFACIALACC = new$GENERALORGFACIALACC,
    GRANTEEORG_REF = new$GRANTEEORG_REF,
    PREVCLS = new$PREVCLS,
    FacialCodeEx = new$FacialCodeEx
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_FACIALACC_CLS_AU_500)
-- Create 28.04.2005
-- Last update 15.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (19, :OLD.ID, SYSDATE);

      DELETE FROM DelRecIndexes
            WHERE (TableID = 19) AND (RecordId = new$ID);
   END IF;

END;
/
ALTER TRIGGER TR_FACIALACC_CLS_BU_500 ENABLE
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- alter_DocLock_expand_Formula.sql
-- #########################################################
-- #########################################################

/*     DocLock  4000  */
ALTER TRIGGER TR_DOCLOCK_BU_500 DISABLE
/
ALTER TABLE DocLock ADD (
  TempFormula VARCHAR2(4000),
  TempValidateFilter VARCHAR2(4000)
)
/
commit work 
/
update DocLock set
  TempFormula = Formula,
  TempValidateFilter = ValidateFilter
/
ALTER TABLE DocLock DROP (Formula)
/
ALTER TABLE DocLock DROP (ValidateFilter)
/
commit work 
/
ALTER TABLE DocLock ADD (
  Formula VARCHAR2(4000),
  ValidateFilter VARCHAR2(4000)
)
/
commit work 
/
update DocLock set
  Formula = TempFormula,
  ValidateFilter = TempValidateFilter
/
ALTER TABLE DocLock DROP (TempFormula)
/
ALTER TABLE DocLock DROP (TempValidateFilter)
/
ALTER TRIGGER TR_DOCLOCK_BU_500 ENABLE
/
commit work 
/

-- #########################################################
-- #########################################################
-- Alter_RegionCls_Add_OKTMO.sql
-- #########################################################
-- #########################################################

/*       */
ALTER TABLE RegionCls ADD (
  OKTMO NUMBER(10),
    CHECK((OKTMO<=2147483647)AND(OKTMO>-2147483648)),
  constraint FK_RegionCls_OKTMO foreign key (OKTMO) references OKTMO(ID)
)
/
CREATE INDEX FK_RegionCls_OKTMO ON RegionCls(OKTMO)
/
commit work
/

-- #########################################################
-- #########################################################
-- Add_StoredContent_CorrectionCaption.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE CorrectionCaption ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
COMMIT WORK
/



-- #########################################################
-- #########################################################
-- Add_StoredContent_CorrectionDetail.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE TB_CorrectionDetail ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW CorrectionDetail (
  ID,
  PARENTID,
  BUDGETREF,
  SUMMA,
  CLSTYPE,
  FACIALACC_CLS,
  KVSR,
  KFSR,
  KCSR,
  KVR,
  KESR,
  DIRECTIONCLS,
  MEANSTYPE,
  FACT,
  REGIONCLS,
  FINSOURCE,
  FINTYPE,
  DOCTYPE,
  SUBKESR,
  FUNDSSOURCE,
  KD,
  IFS,
  BUHOPERATIONCLS,
  CHANGEACC_REF,
  CHANGEACC,
  CHANGEORGINN,
  CHANGEORGINN20,
  PROGINDEX,
  RECORDINDEX,
  DOCUMENTPROGINDEX,
  DOCUMENTRECORDINDEX,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  SENDERID,
  SENDERRECORDID,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  NOTE,
  ISCLSCHANGED,
  PROMISE,
  BUDGETPROMISE,
  EXECDOC,
  OKATO,
  ADDOKATO,
  TRANSFERTCLS,
  ORIGINALCLSSUMMA,
  NOTECLS,
  OPERATIONTYPE,
  REVERSEFLAG,
  EXECINNERNUMBER,
  CLSFIELFCHANGED,
  FAORGTYPE,
  SUBSIDYCLS,
  BUDALLOCATIONCLS,
  PAYPROMISECLS,
  NOTEQUALEX,
  OKTMO,
  UINCODE,
  INVESTOBJECT,
  CHANGEORGNAME,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  STOREDCONTENT)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    STOREDCONTENT
  FROM TB_CorrectionDetail
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_ID
  INSTEAD OF DELETE
  ON CORRECTIONDETAIL
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_500 (TR_CORRECTIONDETAIL_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update CorrectionCaption set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CORRECTIONDETAIL
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONDETAIL_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate, ProgIndex, SUMMA) values(5504,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_II
  INSTEAD OF INSERT
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STOREDCONTENT CORRECTIONDETAIL.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS$ NUMBER(10);
  vOperationTypeD$ NUMBER(10);
  vOperationType$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONDETAIL_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN
    new$SubKesr := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS$, vOperationTypeD$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN
      vOperationType$ := vOperationTypeS$;

    ELSE
      vOperationType$ := vOperationTypeD$;
    END IF;
    new$OperationType := vOperationType$;

  END IF;
  BEGIN

    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN FacialAcc_Cls fac  ON (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BI_100 (tr_correctiondetail_bi_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if (new$progindex = 316) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BI_120 (TR_CORRECTIONDETAIL_BI_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */

  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */

    else
      if (new$ClsType is null)
      then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_CORRECTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (new$Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null) and (new$BudgetPromise is null)) then
      select
      max(InnerPromiseNum)
      into BPInnerNum$       from
      PaymentSchedule
      where
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*    ,   ,   */
    if ((new$BudgetPromise is not null) and (new$Promise is null)) then
      BEGIN
        select
        ANumber
        into BPInnerNum$       from
        PaymentSchedule
        where
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      new$Promise := BPInnerNum$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_CORRECTIONDETAIL_BI_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;

      else
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$ExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*    ,   ,  */
    else
      if (new$ExecDoc is not null) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONDETAIL_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update CorrectionCaption set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CORRECTIONDETAIL (
    ID,
    PARENTID,
    BUDGETREF,
    SUMMA,
    CLSTYPE,
    FACIALACC_CLS,
    KVSR,
    KFSR,
    KCSR,
    KVR,
    KESR,
    DIRECTIONCLS,
    MEANSTYPE,
    FACT,
    REGIONCLS,
    FINSOURCE,
    FINTYPE,
    DOCTYPE,
    SUBKESR,
    FUNDSSOURCE,
    KD,
    IFS,
    BUHOPERATIONCLS,
    CHANGEACC_REF,
    CHANGEACC,
    CHANGEORGINN,
    CHANGEORGINN20,
    PROGINDEX,
    RECORDINDEX,
    DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    SENDERID,
    SENDERRECORDID,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    NOTE,
    ISCLSCHANGED,
    PROMISE,
    BUDGETPROMISE,
    EXECDOC,
    OKATO,
    ADDOKATO,
    TRANSFERTCLS,
    ORIGINALCLSSUMMA,
    NOTECLS,
    OPERATIONTYPE,
    REVERSEFLAG,
    EXECINNERNUMBER,
    CLSFIELFCHANGED,
    FAORGTYPE,
    SUBSIDYCLS,
    BUDALLOCATIONCLS,
    PAYPROMISECLS,
    NOTEQUALEX,
    OKTMO,
    UINCODE,
    INVESTOBJECT,
    CHANGEORGNAME,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$SUMMA,
    new$CLSTYPE,
    new$FACIALACC_CLS,
    new$KVSR,
    new$KFSR,
    new$KCSR,
    new$KVR,
    new$KESR,
    new$DIRECTIONCLS,
    new$MEANSTYPE,
    new$FACT,
    new$REGIONCLS,
    new$FINSOURCE,
    new$FINTYPE,
    new$DOCTYPE,
    new$SUBKESR,
    new$FUNDSSOURCE,
    new$KD,
    new$IFS,
    new$BUHOPERATIONCLS,
    new$CHANGEACC_REF,
    new$CHANGEACC,
    new$CHANGEORGINN,
    new$CHANGEORGINN20,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$DOCUMENTPROGINDEX,
    new$DOCUMENTRECORDINDEX,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$SENDERID,
    new$SENDERRECORDID,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$NOTE,
    new$ISCLSCHANGED,
    new$PROMISE,
    new$BUDGETPROMISE,
    new$EXECDOC,
    new$OKATO,
    new$ADDOKATO,
    new$TRANSFERTCLS,
    new$ORIGINALCLSSUMMA,
    new$NOTECLS,
    new$OPERATIONTYPE,
    new$REVERSEFLAG,
    new$EXECINNERNUMBER,
    new$CLSFIELFCHANGED,
    new$FAORGTYPE,
    new$SUBSIDYCLS,
    new$BUDALLOCATIONCLS,
    new$PAYPROMISECLS,
    new$NOTEQUALEX,
    new$OKTMO,
    new$UINCODE,
    new$INVESTOBJECT,
    new$CHANGEORGNAME,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONDETAIL_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID =5504 ) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CORRECTIONDETAIL_IU
  INSTEAD OF UPDATE
  ON CORRECTIONDETAIL
  FOR EACH ROW
DECLARE
  new$ID CORRECTIONDETAIL.ID%TYPE := :NEW.ID;
  new$PARENTID CORRECTIONDETAIL.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CORRECTIONDETAIL.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$SUMMA CORRECTIONDETAIL.SUMMA%TYPE := :NEW.SUMMA;
  new$CLSTYPE CORRECTIONDETAIL.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$FACIALACC_CLS CORRECTIONDETAIL.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$KVSR CORRECTIONDETAIL.KVSR%TYPE := :NEW.KVSR;
  new$KFSR CORRECTIONDETAIL.KFSR%TYPE := :NEW.KFSR;
  new$KCSR CORRECTIONDETAIL.KCSR%TYPE := :NEW.KCSR;
  new$KVR CORRECTIONDETAIL.KVR%TYPE := :NEW.KVR;
  new$KESR CORRECTIONDETAIL.KESR%TYPE := :NEW.KESR;
  new$DIRECTIONCLS CORRECTIONDETAIL.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$MEANSTYPE CORRECTIONDETAIL.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$FACT CORRECTIONDETAIL.FACT%TYPE := :NEW.FACT;
  new$REGIONCLS CORRECTIONDETAIL.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$FINSOURCE CORRECTIONDETAIL.FINSOURCE%TYPE := :NEW.FINSOURCE;
  new$FINTYPE CORRECTIONDETAIL.FINTYPE%TYPE := :NEW.FINTYPE;
  new$DOCTYPE CORRECTIONDETAIL.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$SUBKESR CORRECTIONDETAIL.SUBKESR%TYPE := :NEW.SUBKESR;
  new$FUNDSSOURCE CORRECTIONDETAIL.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$KD CORRECTIONDETAIL.KD%TYPE := :NEW.KD;
  new$IFS CORRECTIONDETAIL.IFS%TYPE := :NEW.IFS;
  new$BUHOPERATIONCLS CORRECTIONDETAIL.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$CHANGEACC_REF CORRECTIONDETAIL.CHANGEACC_REF%TYPE := :NEW.CHANGEACC_REF;
  new$CHANGEACC CORRECTIONDETAIL.CHANGEACC%TYPE := :NEW.CHANGEACC;
  new$CHANGEORGINN CORRECTIONDETAIL.CHANGEORGINN%TYPE := :NEW.CHANGEORGINN;
  new$CHANGEORGINN20 CORRECTIONDETAIL.CHANGEORGINN20%TYPE := :NEW.CHANGEORGINN20;
  new$PROGINDEX CORRECTIONDETAIL.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX CORRECTIONDETAIL.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$DOCUMENTPROGINDEX CORRECTIONDETAIL.DOCUMENTPROGINDEX%TYPE := :NEW.DOCUMENTPROGINDEX;
  new$DOCUMENTRECORDINDEX CORRECTIONDETAIL.DOCUMENTRECORDINDEX%TYPE := :NEW.DOCUMENTRECORDINDEX;
  new$ISBLOCKED CORRECTIONDETAIL.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE CORRECTIONDETAIL.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE CORRECTIONDETAIL.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE CORRECTIONDETAIL.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$SENDERID CORRECTIONDETAIL.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CORRECTIONDETAIL.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$RVERSION CORRECTIONDETAIL.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CORRECTIONDETAIL.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CORRECTIONDETAIL.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CORRECTIONDETAIL.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CORRECTIONDETAIL.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$NOTE CORRECTIONDETAIL.NOTE%TYPE := :NEW.NOTE;
  new$ISCLSCHANGED CORRECTIONDETAIL.ISCLSCHANGED%TYPE := :NEW.ISCLSCHANGED;
  new$PROMISE CORRECTIONDETAIL.PROMISE%TYPE := :NEW.PROMISE;
  new$BUDGETPROMISE CORRECTIONDETAIL.BUDGETPROMISE%TYPE := :NEW.BUDGETPROMISE;
  new$EXECDOC CORRECTIONDETAIL.EXECDOC%TYPE := :NEW.EXECDOC;
  new$OKATO CORRECTIONDETAIL.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO CORRECTIONDETAIL.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$TRANSFERTCLS CORRECTIONDETAIL.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$ORIGINALCLSSUMMA CORRECTIONDETAIL.ORIGINALCLSSUMMA%TYPE := :NEW.ORIGINALCLSSUMMA;
  new$NOTECLS CORRECTIONDETAIL.NOTECLS%TYPE := :NEW.NOTECLS;
  new$OPERATIONTYPE CORRECTIONDETAIL.OPERATIONTYPE%TYPE := :NEW.OPERATIONTYPE;
  new$REVERSEFLAG CORRECTIONDETAIL.REVERSEFLAG%TYPE := :NEW.REVERSEFLAG;
  new$EXECINNERNUMBER CORRECTIONDETAIL.EXECINNERNUMBER%TYPE := :NEW.EXECINNERNUMBER;
  new$CLSFIELFCHANGED CORRECTIONDETAIL.CLSFIELFCHANGED%TYPE := :NEW.CLSFIELFCHANGED;
  new$FAORGTYPE CORRECTIONDETAIL.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$SUBSIDYCLS CORRECTIONDETAIL.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$BUDALLOCATIONCLS CORRECTIONDETAIL.BUDALLOCATIONCLS%TYPE := :NEW.BUDALLOCATIONCLS;
  new$PAYPROMISECLS CORRECTIONDETAIL.PAYPROMISECLS%TYPE := :NEW.PAYPROMISECLS;
  new$NOTEQUALEX CORRECTIONDETAIL.NOTEQUALEX%TYPE := :NEW.NOTEQUALEX;
  new$OKTMO CORRECTIONDETAIL.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE CORRECTIONDETAIL.UINCODE%TYPE := :NEW.UINCODE;
  new$INVESTOBJECT CORRECTIONDETAIL.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CHANGEORGNAME CORRECTIONDETAIL.CHANGEORGNAME%TYPE := :NEW.CHANGEORGNAME;
  new$CONTRACTCOSTSCLS CORRECTIONDETAIL.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS CORRECTIONDETAIL.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STOREDCONTENT CORRECTIONDETAIL.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  ExecRegType$ NUMBER(10);
  ExecAgrInnerNum$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  vOperationTypeS1$ NUMBER(10);
  vOperationTypeD1$ NUMBER(10);
  vOperationType1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONDETAIL_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  IF (new$IFS IS NULL) THEN
    new$IFS := 0;
  END IF;
  IF (new$FacialAcc_Cls IS NULL) THEN
    new$FacialAcc_Cls := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DirectionCls IS NULL) THEN
    new$DirectionCls := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$Finsource IS NULL) THEN
    new$Finsource := 0;
  END IF;
  IF (new$FinType IS NULL) THEN
    new$FinType := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$SubKesr IS NULL) THEN
    new$SubKesr := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$buhoperationCls IS NULL) THEN
    new$buhoperationCls := 0;
  END IF;
  IF (new$ReverseFlag IS NULL) THEN
    new$ReverseFlag := 1;
  END IF;
  IF (new$OperationType IS NULL) THEN
    BEGIN
      SELECT CorCap.SourceType, CorCap.DestType
      INTO
      vOperationTypeS1$, vOperationTypeD1$       FROM correctioncaption CorCap
      WHERE
      (CorCap.id = new$recordindex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    IF (new$ProgIndex = 315) THEN
      vOperationType1$ := vOperationTypeS1$;

    ELSE
      vOperationType1$ := vOperationTypeD1$;
    END IF;
    new$OperationType := vOperationType1$;

  END IF;
  /*     \*/
  IF ((new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType IS NULL)) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  ON (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_100 (tr_correctiondetail_bu_100)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$buhoperationcls <> :old.buhoperationcls) and (new$progindex = 316)) then
    update correctiondetail set
    buhoperationcls = new$buhoperationcls
    where ID = new$parentid;
  END IF;

-- - - - - - - - - - - - -
-- BU_120 (TR_CORRECTIONDETAIL_BU_120)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  if ((new$ClsType is NULL) and (new$IFS <> 0)) then
    new$ClsType := 1; /*       ClsType */

  else
    if ((new$ClsType is NULL) and (new$KD <> 0)) then
      new$ClsType := 2; /*        ClsType */

    else
      if (new$ClsType is null)
      then
        new$ClsType := 0; /*  -  */
      END IF;
    END IF;
  END IF;
  IF ((new$ClsType = 0) AND ((new$IFS <> 0) or (new$KD <> 0)))THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ( (new$ClsType = 1) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$KD <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((new$ClsType = 2) AND (
  (new$KVSR <> 0) OR (new$KFSR <> 0) OR
  (new$KCSR <> 0) OR (new$KVR <> 0) OR
  (new$IFS <> 0)
  ))
  THEN /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_CORRECTIONDETAIL_BU_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = new$PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((new$Promise is not null)and((:old.Promise is null)or(:old.Promise <> new$Promise )) and
    (new$BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select
      max(InnerPromiseNum)
      into BPInnerNum$       from
      PaymentSchedule
      where
      (ANumber = new$Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        new$BudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /*    ,   */
    if (((new$BudgetPromise is not null) and (:old.BudgetPromise is null)) or
    (new$BudgetPromise <> :old.BudgetPromise)) then
      BEGIN
        select
        ANumber
        into BPInnerNum$       from
        PaymentSchedule
        where
        (InnerPromiseNum = new$BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      new$Promise := BPInnerNum$;

    END IF;

    /*    ,     */
    if ((new$BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      new$Promise := null;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_CORRECTIONDETAIL_BU_210)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (new$Promise is not null and (
    (:old.Promise is null or :old.Promise <> new$Promise) or
    (:old.ExecDoc is null or new$ExecDoc is null or :old.ExecDoc <> new$ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = new$Promise and ps.InnerPromiseNum = new$BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      /*    ,      */
      if (ProgIndex$ = 308) then
        new$ExecDoc := ExecID$;
        new$ExecInnerNumber := ExecInnerNumber$;

      else
        if (new$ExecDoc is not null) then
          BEGIN
            /*      ,         */
            /*        */
            select
            RegistrationType, AgreementInnerNumber, InnerNumber
            into ExecRegType$, ExecAgrInnerNum$, ExecInnerNumber$         from ExecutionDocumentsCaption
            where
            Id = new$ExecDoc
            ;
          EXCEPTION
            WHEN NO_DATA_FOUND THEN NULL;
          END;
          /*    ,    */
          if (ExecRegType$ = 4) then
            RaiseException('EX_IncorrectBindingExec_BO');
          END IF;
          /*        ,     */
          if (ExecAgrInnerNum$ <> AgrInnerNumber$) then
            RaiseException('EX_DiffAgree_InBOExec');
          END IF;
          /*    ,      */
          new$ExecInnerNumber := ExecInnerNumber$;

        END IF;
      END IF;/*       ,   ,  */
    else
      if (new$ExecDoc is null or :old.ExecDoc is null or new$ExecDoc <> :old.ExecDoc) then
        BEGIN
          /*      */
          select
          InnerNumber
          into ExecInnerNumber$       from ExecutionDocumentsCaption
          where
          Id = new$ExecDoc
          ;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;
        new$ExecInnerNumber := ExecInnerNumber$;

      END IF;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONDETAIL_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;
 end if;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CORRECTIONDETAIL SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    SUMMA = new$SUMMA,
    CLSTYPE = new$CLSTYPE,
    FACIALACC_CLS = new$FACIALACC_CLS,
    KVSR = new$KVSR,
    KFSR = new$KFSR,
    KCSR = new$KCSR,
    KVR = new$KVR,
    KESR = new$KESR,
    DIRECTIONCLS = new$DIRECTIONCLS,
    MEANSTYPE = new$MEANSTYPE,
    FACT = new$FACT,
    REGIONCLS = new$REGIONCLS,
    FINSOURCE = new$FINSOURCE,
    FINTYPE = new$FINTYPE,
    DOCTYPE = new$DOCTYPE,
    SUBKESR = new$SUBKESR,
    FUNDSSOURCE = new$FUNDSSOURCE,
    KD = new$KD,
    IFS = new$IFS,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    CHANGEACC_REF = new$CHANGEACC_REF,
    CHANGEACC = new$CHANGEACC,
    CHANGEORGINN = new$CHANGEORGINN,
    CHANGEORGINN20 = new$CHANGEORGINN20,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    DOCUMENTPROGINDEX = new$DOCUMENTPROGINDEX,
    DOCUMENTRECORDINDEX = new$DOCUMENTRECORDINDEX,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    NOTE = new$NOTE,
    ISCLSCHANGED = new$ISCLSCHANGED,
    PROMISE = new$PROMISE,
    BUDGETPROMISE = new$BUDGETPROMISE,
    EXECDOC = new$EXECDOC,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    TRANSFERTCLS = new$TRANSFERTCLS,
    ORIGINALCLSSUMMA = new$ORIGINALCLSSUMMA,
    NOTECLS = new$NOTECLS,
    OPERATIONTYPE = new$OPERATIONTYPE,
    REVERSEFLAG = new$REVERSEFLAG,
    EXECINNERNUMBER = new$EXECINNERNUMBER,
    CLSFIELFCHANGED = new$CLSFIELFCHANGED,
    FAORGTYPE = new$FAORGTYPE,
    SUBSIDYCLS = new$SUBSIDYCLS,
    BUDALLOCATIONCLS = new$BUDALLOCATIONCLS,
    PAYPROMISECLS = new$PAYPROMISECLS,
    NOTEQUALEX = new$NOTEQUALEX,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    INVESTOBJECT = new$INVESTOBJECT,
    CHANGEORGNAME = new$CHANGEORGNAME,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONDETAIL_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5504, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5504) and (RecordId=new$ID);
  end if;

END;
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- CorrectionCaption
-- #########################################################
-- #########################################################


DROP TRIGGER TR_CORRECTIONCAPTION_BD
/
DROP TRIGGER TR_CORRECTIONCAPTION_BI
/
DROP TRIGGER TR_CORRECTIONCAPTION_BU
/
DROP TRIGGER TR_CORRECTIONCAPTION_BU_500
/
DROP TRIGGER TR_CORRECTIONCAPTION_AD
/
DROP TRIGGER TR_CORRECTIONCAPTION_AI
/
DROP TRIGGER TR_CORRECTIONCAPTION_AU
/

RENAME CorrectionCaption TO TB_CorrectionCaption
/
CREATE OR REPLACE TRIGGER TR_CORRECTIONCAPTION_BU_500
  BEFORE UPDATE
  ON TB_CorrectionCaption
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_500 (TR_CORRECTIONCAPTION_BU_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  :new.Updatedate := SYSDATE;
  :new.DocChangeDate := :new.UpdateDate;
  :new.UpdaterUser := User;

END;
/

CREATE OR REPLACE VIEW CorrectionCaption (
  ID,
  PARENTID,
  BUDGETREF,
  DOCNUMBER,
  INPUTDATE,
  ACCEPTDATE,
  SUMMA,
  NOTE,
  DOCTYPE,
  PROGINDEX,
  OPERATIONDIRECTION,
  SOURCETYPE,
  DESTTYPE,
  ORIGINALNUMBER,
  ORIGINALDATE,
  ORIGINALSUMMA,
  ORIGINALNOTE,
  ORIGINALPROGINDEX,
  ORIGINALRECORDINDEX,
  ORIGINALPAYERACC_REF,
  ORIGINALPAYERACC,
  ORIGINALPAYERORGNAME,
  ORIGINALPAYERORGINN20,
  ORIGINALPAYERBANKNAME,
  ORIGINALPAYERBANKMFO,
  ORIGINALPAYERBANKCOR,
  ORIGINALPAYERFKORGINN,
  ORIGINALPAYERFKORGNAME,
  ORIGINALPAYERFKLS,
  ORIGINALACCEPTORACC_REF,
  ORIGINALACCEPTORACC,
  ORIGINALACCEPTORORGNAME,
  ORIGINALACCEPTORORGINN20,
  ORIGINALACCEPTORBANKNAME,
  ORIGINALACCEPTORBANKMFO,
  ORIGINALACCEPTORBANKCOR,
  ORIGINALACCEPTORFKORGINN,
  ORIGINALACCEPTORFKORGNAME,
  ORIGINALACCEPTORFKLS,
  REJECT_CLS,
  SENDERID,
  SENDERRECORDID,
  DOCSTATEREF,
  RVERSION,
  CREATERUSER,
  CREATEDATE,
  UPDATERUSER,
  UPDATEDATE,
  ORIGINALACCEPTORFKCODE,
  ORIGINALPAYERFKCODE,
  ADMINACCEPTORINN,
  ADMINACCEPTORINN20,
  FKINN,
  FKINN20,
  FKNAME,
  TERRITORIALFKINN,
  TERRITORIALFKINN20,
  ORIGINALPAYERORGINN,
  ORIGINALACCEPTORORGINN,
  ORIGINALPAYERBANKFILNAME,
  ORIGINALACCEPTORBANKFILNAME,
  RECORDDATE,
  BASICNOTE,
  LASTEXTRCHANGE,
  CRYPTOSTATUS,
  OKATO,
  ELNUM,
  FACIALACC_CLS,
  ADDOKATO,
  PERSONALINFO,
  ELDOCREF,
  REQUESTNUMBER,
  DEPARTMENTCLS,
  DOCCHANGEDATE,
  SIGNERS,
  REJECTCAUSE,
  STOREDCONTENT)
AS
  SELECT
    ID,
    PARENTID,
    BUDGETREF,
    DOCNUMBER,
    INPUTDATE,
    ACCEPTDATE,
    SUMMA,
    NOTE,
    DOCTYPE,
    PROGINDEX,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    ORIGINALNUMBER,
    ORIGINALDATE,
    ORIGINALSUMMA,
    ORIGINALNOTE,
    ORIGINALPROGINDEX,
    ORIGINALRECORDINDEX,
    ORIGINALPAYERACC_REF,
    ORIGINALPAYERACC,
    ORIGINALPAYERORGNAME,
    ORIGINALPAYERORGINN20,
    ORIGINALPAYERBANKNAME,
    ORIGINALPAYERBANKMFO,
    ORIGINALPAYERBANKCOR,
    ORIGINALPAYERFKORGINN,
    ORIGINALPAYERFKORGNAME,
    ORIGINALPAYERFKLS,
    ORIGINALACCEPTORACC_REF,
    ORIGINALACCEPTORACC,
    ORIGINALACCEPTORORGNAME,
    ORIGINALACCEPTORORGINN20,
    ORIGINALACCEPTORBANKNAME,
    ORIGINALACCEPTORBANKMFO,
    ORIGINALACCEPTORBANKCOR,
    ORIGINALACCEPTORFKORGINN,
    ORIGINALACCEPTORFKORGNAME,
    ORIGINALACCEPTORFKLS,
    REJECT_CLS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    ORIGINALACCEPTORFKCODE,
    ORIGINALPAYERFKCODE,
    ADMINACCEPTORINN,
    ADMINACCEPTORINN20,
    FKINN,
    FKINN20,
    FKNAME,
    TERRITORIALFKINN,
    TERRITORIALFKINN20,
    ORIGINALPAYERORGINN,
    ORIGINALACCEPTORORGINN,
    ORIGINALPAYERBANKFILNAME,
    ORIGINALACCEPTORBANKFILNAME,
    RECORDDATE,
    BASICNOTE,
    LASTEXTRCHANGE,
    CRYPTOSTATUS,
    OKATO,
    ELNUM,
    FACIALACC_CLS,
    ADDOKATO,
    PERSONALINFO,
    ELDOCREF,
    REQUESTNUMBER,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    SIGNERS,
    REJECTCAUSE,
    STOREDCONTENT
  FROM TB_CorrectionCaption
/

GRANT SELECT, INSERT, UPDATE, DELETE ON CorrectionCaption TO BUDGET_USERS
/
CREATE OR REPLACE TRIGGER TR_CorrectionCaption_II
  INSTEAD OF INSERT
  ON CorrectionCaption
  FOR EACH ROW
DECLARE
  new$ID CorrectionCaption.ID%TYPE := :NEW.ID;
  new$PARENTID CorrectionCaption.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CorrectionCaption.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCNUMBER CorrectionCaption.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$INPUTDATE CorrectionCaption.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE CorrectionCaption.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA CorrectionCaption.SUMMA%TYPE := :NEW.SUMMA;
  new$NOTE CorrectionCaption.NOTE%TYPE := :NEW.NOTE;
  new$DOCTYPE CorrectionCaption.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$PROGINDEX CorrectionCaption.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$OPERATIONDIRECTION CorrectionCaption.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE CorrectionCaption.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE CorrectionCaption.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$ORIGINALNUMBER CorrectionCaption.ORIGINALNUMBER%TYPE := :NEW.ORIGINALNUMBER;
  new$ORIGINALDATE CorrectionCaption.ORIGINALDATE%TYPE := :NEW.ORIGINALDATE;
  new$ORIGINALSUMMA CorrectionCaption.ORIGINALSUMMA%TYPE := :NEW.ORIGINALSUMMA;
  new$ORIGINALNOTE CorrectionCaption.ORIGINALNOTE%TYPE := :NEW.ORIGINALNOTE;
  new$ORIGINALPROGINDEX CorrectionCaption.ORIGINALPROGINDEX%TYPE := :NEW.ORIGINALPROGINDEX;
  new$ORIGINALRECORDINDEX CorrectionCaption.ORIGINALRECORDINDEX%TYPE := :NEW.ORIGINALRECORDINDEX;
  new$ORIGINALPAYERACC_REF CorrectionCaption.ORIGINALPAYERACC_REF%TYPE := :NEW.ORIGINALPAYERACC_REF;
  new$ORIGINALPAYERACC CorrectionCaption.ORIGINALPAYERACC%TYPE := :NEW.ORIGINALPAYERACC;
  new$ORIGINALPAYERORGNAME CorrectionCaption.ORIGINALPAYERORGNAME%TYPE := :NEW.ORIGINALPAYERORGNAME;
  new$ORIGINALPAYERORGINN20 CorrectionCaption.ORIGINALPAYERORGINN20%TYPE := :NEW.ORIGINALPAYERORGINN20;
  new$ORIGINALPAYERBANKNAME CorrectionCaption.ORIGINALPAYERBANKNAME%TYPE := :NEW.ORIGINALPAYERBANKNAME;
  new$ORIGINALPAYERBANKMFO CorrectionCaption.ORIGINALPAYERBANKMFO%TYPE := :NEW.ORIGINALPAYERBANKMFO;
  new$ORIGINALPAYERBANKCOR CorrectionCaption.ORIGINALPAYERBANKCOR%TYPE := :NEW.ORIGINALPAYERBANKCOR;
  new$ORIGINALPAYERFKORGINN CorrectionCaption.ORIGINALPAYERFKORGINN%TYPE := :NEW.ORIGINALPAYERFKORGINN;
  new$ORIGINALPAYERFKORGNAME CorrectionCaption.ORIGINALPAYERFKORGNAME%TYPE := :NEW.ORIGINALPAYERFKORGNAME;
  new$ORIGINALPAYERFKLS CorrectionCaption.ORIGINALPAYERFKLS%TYPE := :NEW.ORIGINALPAYERFKLS;
  new$ORIGINALACCEPTORACC_REF CorrectionCaption.ORIGINALACCEPTORACC_REF%TYPE := :NEW.ORIGINALACCEPTORACC_REF;
  new$ORIGINALACCEPTORACC CorrectionCaption.ORIGINALACCEPTORACC%TYPE := :NEW.ORIGINALACCEPTORACC;
  new$ORIGINALACCEPTORORGNAME CorrectionCaption.ORIGINALACCEPTORORGNAME%TYPE := :NEW.ORIGINALACCEPTORORGNAME;
  new$ORIGINALACCEPTORORGINN20 CorrectionCaption.ORIGINALACCEPTORORGINN20%TYPE := :NEW.ORIGINALACCEPTORORGINN20;
  new$ORIGINALACCEPTORBANKNAME CorrectionCaption.ORIGINALACCEPTORBANKNAME%TYPE := :NEW.ORIGINALACCEPTORBANKNAME;
  new$ORIGINALACCEPTORBANKMFO CorrectionCaption.ORIGINALACCEPTORBANKMFO%TYPE := :NEW.ORIGINALACCEPTORBANKMFO;
  new$ORIGINALACCEPTORBANKCOR CorrectionCaption.ORIGINALACCEPTORBANKCOR%TYPE := :NEW.ORIGINALACCEPTORBANKCOR;
  new$ORIGINALACCEPTORFKORGINN CorrectionCaption.ORIGINALACCEPTORFKORGINN%TYPE := :NEW.ORIGINALACCEPTORFKORGINN;
  new$ORIGINALACCEPTORFKORGNAME CorrectionCaption.ORIGINALACCEPTORFKORGNAME%TYPE := :NEW.ORIGINALACCEPTORFKORGNAME;
  new$ORIGINALACCEPTORFKLS CorrectionCaption.ORIGINALACCEPTORFKLS%TYPE := :NEW.ORIGINALACCEPTORFKLS;
  new$REJECT_CLS CorrectionCaption.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$SENDERID CorrectionCaption.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CorrectionCaption.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF CorrectionCaption.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION CorrectionCaption.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CorrectionCaption.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CorrectionCaption.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CorrectionCaption.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CorrectionCaption.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$ORIGINALACCEPTORFKCODE CorrectionCaption.ORIGINALACCEPTORFKCODE%TYPE := :NEW.ORIGINALACCEPTORFKCODE;
  new$ORIGINALPAYERFKCODE CorrectionCaption.ORIGINALPAYERFKCODE%TYPE := :NEW.ORIGINALPAYERFKCODE;
  new$ADMINACCEPTORINN CorrectionCaption.ADMINACCEPTORINN%TYPE := :NEW.ADMINACCEPTORINN;
  new$ADMINACCEPTORINN20 CorrectionCaption.ADMINACCEPTORINN20%TYPE := :NEW.ADMINACCEPTORINN20;
  new$FKINN CorrectionCaption.FKINN%TYPE := :NEW.FKINN;
  new$FKINN20 CorrectionCaption.FKINN20%TYPE := :NEW.FKINN20;
  new$FKNAME CorrectionCaption.FKNAME%TYPE := :NEW.FKNAME;
  new$TERRITORIALFKINN CorrectionCaption.TERRITORIALFKINN%TYPE := :NEW.TERRITORIALFKINN;
  new$TERRITORIALFKINN20 CorrectionCaption.TERRITORIALFKINN20%TYPE := :NEW.TERRITORIALFKINN20;
  new$ORIGINALPAYERORGINN CorrectionCaption.ORIGINALPAYERORGINN%TYPE := :NEW.ORIGINALPAYERORGINN;
  new$ORIGINALACCEPTORORGINN CorrectionCaption.ORIGINALACCEPTORORGINN%TYPE := :NEW.ORIGINALACCEPTORORGINN;
  new$ORIGINALPAYERBANKFILNAME CorrectionCaption.ORIGINALPAYERBANKFILNAME%TYPE := :NEW.ORIGINALPAYERBANKFILNAME;
  new$ORIGINALACCEPTORBANKFILNAM CorrectionCaption.ORIGINALACCEPTORBANKFILNAME%TYPE := :NEW.ORIGINALACCEPTORBANKFILNAME;
  new$RECORDDATE CorrectionCaption.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$BASICNOTE CorrectionCaption.BASICNOTE%TYPE := :NEW.BASICNOTE;
  new$LASTEXTRCHANGE CorrectionCaption.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$CRYPTOSTATUS CorrectionCaption.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OKATO CorrectionCaption.OKATO%TYPE := :NEW.OKATO;
  new$ELNUM CorrectionCaption.ELNUM%TYPE := :NEW.ELNUM;
  new$FACIALACC_CLS CorrectionCaption.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ADDOKATO CorrectionCaption.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$PERSONALINFO CorrectionCaption.PERSONALINFO%TYPE := :NEW.PERSONALINFO;
  new$ELDOCREF CorrectionCaption.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTNUMBER CorrectionCaption.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$DEPARTMENTCLS CorrectionCaption.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE CorrectionCaption.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS CorrectionCaption.SIGNERS%TYPE := :NEW.SIGNERS;
  new$REJECTCAUSE CorrectionCaption.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT CorrectionCaption.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_CORRECTIONCAPTION_BI)
-- Version 7.01.00.2
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
    
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$OriginalPayerOrgName is null) then 
    new$OriginalPayerOrgName := '';
  END IF;
  if (new$OriginalAcceptorOrgName is null) then 
    new$OriginalAcceptorOrgName := '';
  END IF;
    
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;
  END IF;
     
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
        
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1; 
      new$DestType := -1;
            
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
                
      else
        new$SourceType := -1;
        new$DestType := -1;
                
      END IF;
    END IF;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;
      
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_CORRECTIONCAPTION_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$DocChangeDate := new$UpdateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_CorrectionCaption (
    ID,
    PARENTID,
    BUDGETREF,
    DOCNUMBER,
    INPUTDATE,
    ACCEPTDATE,
    SUMMA,
    NOTE,
    DOCTYPE,
    PROGINDEX,
    OPERATIONDIRECTION,
    SOURCETYPE,
    DESTTYPE,
    ORIGINALNUMBER,
    ORIGINALDATE,
    ORIGINALSUMMA,
    ORIGINALNOTE,
    ORIGINALPROGINDEX,
    ORIGINALRECORDINDEX,
    ORIGINALPAYERACC_REF,
    ORIGINALPAYERACC,
    ORIGINALPAYERORGNAME,
    ORIGINALPAYERORGINN20,
    ORIGINALPAYERBANKNAME,
    ORIGINALPAYERBANKMFO,
    ORIGINALPAYERBANKCOR,
    ORIGINALPAYERFKORGINN,
    ORIGINALPAYERFKORGNAME,
    ORIGINALPAYERFKLS,
    ORIGINALACCEPTORACC_REF,
    ORIGINALACCEPTORACC,
    ORIGINALACCEPTORORGNAME,
    ORIGINALACCEPTORORGINN20,
    ORIGINALACCEPTORBANKNAME,
    ORIGINALACCEPTORBANKMFO,
    ORIGINALACCEPTORBANKCOR,
    ORIGINALACCEPTORFKORGINN,
    ORIGINALACCEPTORFKORGNAME,
    ORIGINALACCEPTORFKLS,
    REJECT_CLS,
    SENDERID,
    SENDERRECORDID,
    DOCSTATEREF,
    RVERSION,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    ORIGINALACCEPTORFKCODE,
    ORIGINALPAYERFKCODE,
    ADMINACCEPTORINN,
    ADMINACCEPTORINN20,
    FKINN,
    FKINN20,
    FKNAME,
    TERRITORIALFKINN,
    TERRITORIALFKINN20,
    ORIGINALPAYERORGINN,
    ORIGINALACCEPTORORGINN,
    ORIGINALPAYERBANKFILNAME,
    ORIGINALACCEPTORBANKFILNAME,
    RECORDDATE,
    BASICNOTE,
    LASTEXTRCHANGE,
    CRYPTOSTATUS,
    OKATO,
    ELNUM,
    FACIALACC_CLS,
    ADDOKATO,
    PERSONALINFO,
    ELDOCREF,
    REQUESTNUMBER,
    DEPARTMENTCLS,
    DOCCHANGEDATE,
    SIGNERS,
    REJECTCAUSE,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$PARENTID,
    new$BUDGETREF,
    new$DOCNUMBER,
    new$INPUTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$NOTE,
    new$DOCTYPE,
    new$PROGINDEX,
    new$OPERATIONDIRECTION,
    new$SOURCETYPE,
    new$DESTTYPE,
    new$ORIGINALNUMBER,
    new$ORIGINALDATE,
    new$ORIGINALSUMMA,
    new$ORIGINALNOTE,
    new$ORIGINALPROGINDEX,
    new$ORIGINALRECORDINDEX,
    new$ORIGINALPAYERACC_REF,
    new$ORIGINALPAYERACC,
    new$ORIGINALPAYERORGNAME,
    new$ORIGINALPAYERORGINN20,
    new$ORIGINALPAYERBANKNAME,
    new$ORIGINALPAYERBANKMFO,
    new$ORIGINALPAYERBANKCOR,
    new$ORIGINALPAYERFKORGINN,
    new$ORIGINALPAYERFKORGNAME,
    new$ORIGINALPAYERFKLS,
    new$ORIGINALACCEPTORACC_REF,
    new$ORIGINALACCEPTORACC,
    new$ORIGINALACCEPTORORGNAME,
    new$ORIGINALACCEPTORORGINN20,
    new$ORIGINALACCEPTORBANKNAME,
    new$ORIGINALACCEPTORBANKMFO,
    new$ORIGINALACCEPTORBANKCOR,
    new$ORIGINALACCEPTORFKORGINN,
    new$ORIGINALACCEPTORFKORGNAME,
    new$ORIGINALACCEPTORFKLS,
    new$REJECT_CLS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$DOCSTATEREF,
    new$RVERSION,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$ORIGINALACCEPTORFKCODE,
    new$ORIGINALPAYERFKCODE,
    new$ADMINACCEPTORINN,
    new$ADMINACCEPTORINN20,
    new$FKINN,
    new$FKINN20,
    new$FKNAME,
    new$TERRITORIALFKINN,
    new$TERRITORIALFKINN20,
    new$ORIGINALPAYERORGINN,
    new$ORIGINALACCEPTORORGINN,
    new$ORIGINALPAYERBANKFILNAME,
    new$ORIGINALACCEPTORBANKFILNAM,
    new$RECORDDATE,
    new$BASICNOTE,
    new$LASTEXTRCHANGE,
    new$CRYPTOSTATUS,
    new$OKATO,
    new$ELNUM,
    new$FACIALACC_CLS,
    new$ADDOKATO,
    new$PERSONALINFO,
    new$ELDOCREF,
    new$REQUESTNUMBER,
    new$DEPARTMENTCLS,
    new$DOCCHANGEDATE,
    new$SIGNERS,
    new$REJECTCAUSE,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_500 (TR_CORRECTIONCAPTION_AI_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

 delete from DelRecIndexes where (TableID = 5503) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_CorrectionCaption_IU
  INSTEAD OF UPDATE
  ON CorrectionCaption
  FOR EACH ROW
DECLARE
  new$ID CorrectionCaption.ID%TYPE := :NEW.ID;
  new$PARENTID CorrectionCaption.PARENTID%TYPE := :NEW.PARENTID;
  new$BUDGETREF CorrectionCaption.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DOCNUMBER CorrectionCaption.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$INPUTDATE CorrectionCaption.INPUTDATE%TYPE := :NEW.INPUTDATE;
  new$ACCEPTDATE CorrectionCaption.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA CorrectionCaption.SUMMA%TYPE := :NEW.SUMMA;
  new$NOTE CorrectionCaption.NOTE%TYPE := :NEW.NOTE;
  new$DOCTYPE CorrectionCaption.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$PROGINDEX CorrectionCaption.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$OPERATIONDIRECTION CorrectionCaption.OPERATIONDIRECTION%TYPE := :NEW.OPERATIONDIRECTION;
  new$SOURCETYPE CorrectionCaption.SOURCETYPE%TYPE := :NEW.SOURCETYPE;
  new$DESTTYPE CorrectionCaption.DESTTYPE%TYPE := :NEW.DESTTYPE;
  new$ORIGINALNUMBER CorrectionCaption.ORIGINALNUMBER%TYPE := :NEW.ORIGINALNUMBER;
  new$ORIGINALDATE CorrectionCaption.ORIGINALDATE%TYPE := :NEW.ORIGINALDATE;
  new$ORIGINALSUMMA CorrectionCaption.ORIGINALSUMMA%TYPE := :NEW.ORIGINALSUMMA;
  new$ORIGINALNOTE CorrectionCaption.ORIGINALNOTE%TYPE := :NEW.ORIGINALNOTE;
  new$ORIGINALPROGINDEX CorrectionCaption.ORIGINALPROGINDEX%TYPE := :NEW.ORIGINALPROGINDEX;
  new$ORIGINALRECORDINDEX CorrectionCaption.ORIGINALRECORDINDEX%TYPE := :NEW.ORIGINALRECORDINDEX;
  new$ORIGINALPAYERACC_REF CorrectionCaption.ORIGINALPAYERACC_REF%TYPE := :NEW.ORIGINALPAYERACC_REF;
  new$ORIGINALPAYERACC CorrectionCaption.ORIGINALPAYERACC%TYPE := :NEW.ORIGINALPAYERACC;
  new$ORIGINALPAYERORGNAME CorrectionCaption.ORIGINALPAYERORGNAME%TYPE := :NEW.ORIGINALPAYERORGNAME;
  new$ORIGINALPAYERORGINN20 CorrectionCaption.ORIGINALPAYERORGINN20%TYPE := :NEW.ORIGINALPAYERORGINN20;
  new$ORIGINALPAYERBANKNAME CorrectionCaption.ORIGINALPAYERBANKNAME%TYPE := :NEW.ORIGINALPAYERBANKNAME;
  new$ORIGINALPAYERBANKMFO CorrectionCaption.ORIGINALPAYERBANKMFO%TYPE := :NEW.ORIGINALPAYERBANKMFO;
  new$ORIGINALPAYERBANKCOR CorrectionCaption.ORIGINALPAYERBANKCOR%TYPE := :NEW.ORIGINALPAYERBANKCOR;
  new$ORIGINALPAYERFKORGINN CorrectionCaption.ORIGINALPAYERFKORGINN%TYPE := :NEW.ORIGINALPAYERFKORGINN;
  new$ORIGINALPAYERFKORGNAME CorrectionCaption.ORIGINALPAYERFKORGNAME%TYPE := :NEW.ORIGINALPAYERFKORGNAME;
  new$ORIGINALPAYERFKLS CorrectionCaption.ORIGINALPAYERFKLS%TYPE := :NEW.ORIGINALPAYERFKLS;
  new$ORIGINALACCEPTORACC_REF CorrectionCaption.ORIGINALACCEPTORACC_REF%TYPE := :NEW.ORIGINALACCEPTORACC_REF;
  new$ORIGINALACCEPTORACC CorrectionCaption.ORIGINALACCEPTORACC%TYPE := :NEW.ORIGINALACCEPTORACC;
  new$ORIGINALACCEPTORORGNAME CorrectionCaption.ORIGINALACCEPTORORGNAME%TYPE := :NEW.ORIGINALACCEPTORORGNAME;
  new$ORIGINALACCEPTORORGINN20 CorrectionCaption.ORIGINALACCEPTORORGINN20%TYPE := :NEW.ORIGINALACCEPTORORGINN20;
  new$ORIGINALACCEPTORBANKNAME CorrectionCaption.ORIGINALACCEPTORBANKNAME%TYPE := :NEW.ORIGINALACCEPTORBANKNAME;
  new$ORIGINALACCEPTORBANKMFO CorrectionCaption.ORIGINALACCEPTORBANKMFO%TYPE := :NEW.ORIGINALACCEPTORBANKMFO;
  new$ORIGINALACCEPTORBANKCOR CorrectionCaption.ORIGINALACCEPTORBANKCOR%TYPE := :NEW.ORIGINALACCEPTORBANKCOR;
  new$ORIGINALACCEPTORFKORGINN CorrectionCaption.ORIGINALACCEPTORFKORGINN%TYPE := :NEW.ORIGINALACCEPTORFKORGINN;
  new$ORIGINALACCEPTORFKORGNAME CorrectionCaption.ORIGINALACCEPTORFKORGNAME%TYPE := :NEW.ORIGINALACCEPTORFKORGNAME;
  new$ORIGINALACCEPTORFKLS CorrectionCaption.ORIGINALACCEPTORFKLS%TYPE := :NEW.ORIGINALACCEPTORFKLS;
  new$REJECT_CLS CorrectionCaption.REJECT_CLS%TYPE := :NEW.REJECT_CLS;
  new$SENDERID CorrectionCaption.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID CorrectionCaption.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$DOCSTATEREF CorrectionCaption.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION CorrectionCaption.RVERSION%TYPE := :NEW.RVERSION;
  new$CREATERUSER CorrectionCaption.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE CorrectionCaption.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER CorrectionCaption.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE CorrectionCaption.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$ORIGINALACCEPTORFKCODE CorrectionCaption.ORIGINALACCEPTORFKCODE%TYPE := :NEW.ORIGINALACCEPTORFKCODE;
  new$ORIGINALPAYERFKCODE CorrectionCaption.ORIGINALPAYERFKCODE%TYPE := :NEW.ORIGINALPAYERFKCODE;
  new$ADMINACCEPTORINN CorrectionCaption.ADMINACCEPTORINN%TYPE := :NEW.ADMINACCEPTORINN;
  new$ADMINACCEPTORINN20 CorrectionCaption.ADMINACCEPTORINN20%TYPE := :NEW.ADMINACCEPTORINN20;
  new$FKINN CorrectionCaption.FKINN%TYPE := :NEW.FKINN;
  new$FKINN20 CorrectionCaption.FKINN20%TYPE := :NEW.FKINN20;
  new$FKNAME CorrectionCaption.FKNAME%TYPE := :NEW.FKNAME;
  new$TERRITORIALFKINN CorrectionCaption.TERRITORIALFKINN%TYPE := :NEW.TERRITORIALFKINN;
  new$TERRITORIALFKINN20 CorrectionCaption.TERRITORIALFKINN20%TYPE := :NEW.TERRITORIALFKINN20;
  new$ORIGINALPAYERORGINN CorrectionCaption.ORIGINALPAYERORGINN%TYPE := :NEW.ORIGINALPAYERORGINN;
  new$ORIGINALACCEPTORORGINN CorrectionCaption.ORIGINALACCEPTORORGINN%TYPE := :NEW.ORIGINALACCEPTORORGINN;
  new$ORIGINALPAYERBANKFILNAME CorrectionCaption.ORIGINALPAYERBANKFILNAME%TYPE := :NEW.ORIGINALPAYERBANKFILNAME;
  new$ORIGINALACCEPTORBANKFILNAM CorrectionCaption.ORIGINALACCEPTORBANKFILNAME%TYPE := :NEW.ORIGINALACCEPTORBANKFILNAME;
  new$RECORDDATE CorrectionCaption.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$BASICNOTE CorrectionCaption.BASICNOTE%TYPE := :NEW.BASICNOTE;
  new$LASTEXTRCHANGE CorrectionCaption.LASTEXTRCHANGE%TYPE := :NEW.LASTEXTRCHANGE;
  new$CRYPTOSTATUS CorrectionCaption.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$OKATO CorrectionCaption.OKATO%TYPE := :NEW.OKATO;
  new$ELNUM CorrectionCaption.ELNUM%TYPE := :NEW.ELNUM;
  new$FACIALACC_CLS CorrectionCaption.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$ADDOKATO CorrectionCaption.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$PERSONALINFO CorrectionCaption.PERSONALINFO%TYPE := :NEW.PERSONALINFO;
  new$ELDOCREF CorrectionCaption.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTNUMBER CorrectionCaption.REQUESTNUMBER%TYPE := :NEW.REQUESTNUMBER;
  new$DEPARTMENTCLS CorrectionCaption.DEPARTMENTCLS%TYPE := :NEW.DEPARTMENTCLS;
  new$DOCCHANGEDATE CorrectionCaption.DOCCHANGEDATE%TYPE := :NEW.DOCCHANGEDATE;
  new$SIGNERS CorrectionCaption.SIGNERS%TYPE := :NEW.SIGNERS;
  new$REJECTCAUSE CorrectionCaption.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT CorrectionCaption.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  NewFAOrgType$ NUMBER(10);
  IsReject1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_CORRECTIONCAPTION_BU)
-- Version 7.01.00.3
-- - - - - - - - - - - - -

  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if ((new$BudgetRef is null) or (new$BudgetRef = 0))
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  if (new$OriginalPayerOrgName is null) then 
    new$OriginalPayerOrgName := '';
  END IF;
  if (new$OriginalAcceptorOrgName is null) then 
    new$OriginalAcceptorOrgName := '';
  END IF;
    
  if (new$OperationDirection is null) then 
    new$OperationDirection := 0;  
  END IF;
     
  if (new$OperationDirection = 0) then
    new$SourceType := 1;
    new$DestType := 1;
        
  else
    if (new$OperationDirection = 1) then
      new$SourceType := 1; 
      new$DestType := -1;
            
    else
      if (new$OperationDirection = 2) then
        new$SourceType := -1;
        new$DestType := 1;
                
      else
        new$SourceType := -1;
        new$DestType := -1;
                
      END IF;
    END IF;
  END IF;
  /*         \ 
       ,   */
  if ((new$AcceptDate is not null) and ((:old.AcceptDate is null)
  or (new$AcceptDate <> :old.AcceptDate))) then
    FOR REC$1 IN (select ID AS DetailID, FAOrgType AS OldFAOrgType, FacialAcc_Cls  AS DetailFacCls from CorrectionDetail
    where RecordIndex = new$ID
    )
    LOOP
      BEGIN
        select org.Org_Type into NewFAOrgType$ from Organizations org
        inner join FacialAcc_Cls fac on (fac.Org_Ref = org.ID)
        where fac.ID = REC$1.DetailFacCls  ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      if (NewFAOrgType$ <> REC$1.OldFaOrgType) then
        update CorrectionDetail set
        FAOrgType = NewFAOrgType$,
        RVersion = -1
        where ID = REC$1.DetailID;
           
      END IF;
    END LOOP;
  END IF;
  /*        */
  if ((new$AcceptDate is not null) and (new$Reject_Cls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;
       
  if (new$DepartmentCls is null) then
    new$DepartmentCls := 0;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (CORRECTIONCAPTION_BU200)
-- Create 05.05.2009
-- - - - - - - - - - - - -

  /*      */
   IF (:OLD.DOCSTATEREF <> new$DOCSTATEREF) THEN
      INSERT INTO StateJumpHistory(DocID, BeginStateRef, EndStateRef)
        VALUES (new$ID, :OLD.DOCSTATEREF, new$DOCSTATEREF);
   END IF;     

-- - - - - - - - - - - - -
-- BU_300 (TR_CORRECTIONCAPTION_BU_300)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  IsReject1$ := -1;
  if ((:old.Reject_CLS is null)and(new$Reject_CLS is not null)) then
    IsReject1$ := 1;
      
  else
    if ((:old.Reject_CLS is not null)and(new$Reject_CLS is null)) then
      IsReject1$ := 0;
    END IF;
  END IF;
  if (IsReject1$  <> -1) then
    update LinkRecords set
    IsRejected = IsReject1$

    where
    ChildID in (select d.id from CorrectionDetail d where d.RecordIndex = new$id);
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_CORRECTIONCAPTION_BU_700)
-- Create 13.08.2007
-- - - - - - - - - - - - -

 if (new$RVersion is null) then
   new$RVersion:=1;
 else
   if ((new$RVersion = -1) and (:Old.RVersion <> -1)) then
     new$RVersion:=:Old.RVersion;
   else
     new$RVersion:=:Old.RVersion+1;
   end if;  
 end if;     

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_CorrectionCaption SET
    ID = new$ID,
    PARENTID = new$PARENTID,
    BUDGETREF = new$BUDGETREF,
    DOCNUMBER = new$DOCNUMBER,
    INPUTDATE = new$INPUTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    NOTE = new$NOTE,
    DOCTYPE = new$DOCTYPE,
    PROGINDEX = new$PROGINDEX,
    OPERATIONDIRECTION = new$OPERATIONDIRECTION,
    SOURCETYPE = new$SOURCETYPE,
    DESTTYPE = new$DESTTYPE,
    ORIGINALNUMBER = new$ORIGINALNUMBER,
    ORIGINALDATE = new$ORIGINALDATE,
    ORIGINALSUMMA = new$ORIGINALSUMMA,
    ORIGINALNOTE = new$ORIGINALNOTE,
    ORIGINALPROGINDEX = new$ORIGINALPROGINDEX,
    ORIGINALRECORDINDEX = new$ORIGINALRECORDINDEX,
    ORIGINALPAYERACC_REF = new$ORIGINALPAYERACC_REF,
    ORIGINALPAYERACC = new$ORIGINALPAYERACC,
    ORIGINALPAYERORGNAME = new$ORIGINALPAYERORGNAME,
    ORIGINALPAYERORGINN20 = new$ORIGINALPAYERORGINN20,
    ORIGINALPAYERBANKNAME = new$ORIGINALPAYERBANKNAME,
    ORIGINALPAYERBANKMFO = new$ORIGINALPAYERBANKMFO,
    ORIGINALPAYERBANKCOR = new$ORIGINALPAYERBANKCOR,
    ORIGINALPAYERFKORGINN = new$ORIGINALPAYERFKORGINN,
    ORIGINALPAYERFKORGNAME = new$ORIGINALPAYERFKORGNAME,
    ORIGINALPAYERFKLS = new$ORIGINALPAYERFKLS,
    ORIGINALACCEPTORACC_REF = new$ORIGINALACCEPTORACC_REF,
    ORIGINALACCEPTORACC = new$ORIGINALACCEPTORACC,
    ORIGINALACCEPTORORGNAME = new$ORIGINALACCEPTORORGNAME,
    ORIGINALACCEPTORORGINN20 = new$ORIGINALACCEPTORORGINN20,
    ORIGINALACCEPTORBANKNAME = new$ORIGINALACCEPTORBANKNAME,
    ORIGINALACCEPTORBANKMFO = new$ORIGINALACCEPTORBANKMFO,
    ORIGINALACCEPTORBANKCOR = new$ORIGINALACCEPTORBANKCOR,
    ORIGINALACCEPTORFKORGINN = new$ORIGINALACCEPTORFKORGINN,
    ORIGINALACCEPTORFKORGNAME = new$ORIGINALACCEPTORFKORGNAME,
    ORIGINALACCEPTORFKLS = new$ORIGINALACCEPTORFKLS,
    REJECT_CLS = new$REJECT_CLS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    ORIGINALACCEPTORFKCODE = new$ORIGINALACCEPTORFKCODE,
    ORIGINALPAYERFKCODE = new$ORIGINALPAYERFKCODE,
    ADMINACCEPTORINN = new$ADMINACCEPTORINN,
    ADMINACCEPTORINN20 = new$ADMINACCEPTORINN20,
    FKINN = new$FKINN,
    FKINN20 = new$FKINN20,
    FKNAME = new$FKNAME,
    TERRITORIALFKINN = new$TERRITORIALFKINN,
    TERRITORIALFKINN20 = new$TERRITORIALFKINN20,
    ORIGINALPAYERORGINN = new$ORIGINALPAYERORGINN,
    ORIGINALACCEPTORORGINN = new$ORIGINALACCEPTORORGINN,
    ORIGINALPAYERBANKFILNAME = new$ORIGINALPAYERBANKFILNAME,
    ORIGINALACCEPTORBANKFILNAME = new$ORIGINALACCEPTORBANKFILNAM,
    RECORDDATE = new$RECORDDATE,
    BASICNOTE = new$BASICNOTE,
    LASTEXTRCHANGE = new$LASTEXTRCHANGE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    OKATO = new$OKATO,
    ELNUM = new$ELNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    ADDOKATO = new$ADDOKATO,
    PERSONALINFO = new$PERSONALINFO,
    ELDOCREF = new$ELDOCREF,
    REQUESTNUMBER = new$REQUESTNUMBER,
    DEPARTMENTCLS = new$DEPARTMENTCLS,
    DOCCHANGEDATE = new$DOCCHANGEDATE,
    SIGNERS = new$SIGNERS,
    REJECTCAUSE = new$REJECTCAUSE,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_CORRECTIONCAPTION_AU_500)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (5503, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=5503) and (RecordId=new$ID);
  end if;

END;
/

CREATE OR REPLACE TRIGGER TR_CorrectionCaption_ID
  INSTEAD OF DELETE
  ON CorrectionCaption
  FOR EACH ROW
DECLARE
  SDate$ NUMBER;
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_CORRECTIONCAPTION_BD)
-- Create 19.02.2008
-- - - - - - - - - - - - -

 /*      */
 delete 
  from correctiondetail
 where 
  (RecordIndex = :old.id);

-- - - - - - - - - - - - -
-- BD_5 (TR_CORRECTIONCAPTION_BD_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (:old.AcceptDate is not null) then
    RaiseException('ex_AcceptedCorrectionDelete');
  else
    BEGIN
      select SendDate     into SDate$ from
      PayDocExchange
      where
      PayDocRef=:old.id
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (SDate$ is not null) then
      RaiseException('ex_SendedCorrectionDelete');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_CorrectionCaption
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_200 (TR_CORRECTIONCAPTION_AD_200)
-- Create 29.12.2009
-- - - - - - - - - - - - -

  /*       */
  delete 
    from 
      StateJumpHistory
    where 
      DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_CORRECTIONCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID,RecordId,DeleteDate,ProgIndex, SUMMA) values(5503,:old.ID,SYSDATE,:old.ProgIndex, :old.SUMMA);

END;
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Alter_StoredAttrDetail_SourceField_Change.sql
-- #########################################################
-- #########################################################

/*    SOURCEFIELD   STOREDATTRIBUTESDETAIL  NOTE1024*//*       -*/
ALTER TABLE STOREDATTRIBUTESDETAIL DROP (SOURCEFIELD)
/
ALTER TABLE STOREDATTRIBUTESDETAIL ADD (
  SOURCEFIELD VARCHAR2(1024)
)
/
Commit work
/

-- #########################################################
-- #########################################################
-- Rename_NumberMoneyRespons_Field.sql
-- #########################################################
-- #########################################################

ALTER TABLE TB_ExecutionDocumentsCaption RENAME COLUMN NumberMoneyRespons TO MoneyPromiseNumber
/

CREATE OR REPLACE VIEW ExecutionDocumentsCaption (
  ID,
  DOCTYPE,
  DOCUMENTDATE,
  ACCEPTDATE,
  SUMMA,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  BUDGETREF,
  STEPNUMBER,
  FACIALACC_CLS,
  RECIPIENT_REF,
  REGISTRATIONTYPE,
  REESTRNUMBER,
  AGREEMENTINNERNUMBER,
  REJECTCLS,
  CRYPTOSTATUS,
  SENDERID,
  SENDERRECORDID,
  REVIEWNOTE,
  DOCSTATEREF,
  RVERSION,
  EXECDOCFINSUMMA,
  FACT,
  DOCNUMBER,
  SENDERIDKEY,
  SENDERRECORDIDKEY,
  REALID,
  INNERNUMBER,
  ADJUSTMENTREF,
  ADJUSTMENTNUMBER,
  ACCEPTED,
  LASTACCEPTED,
  LASTADJUSTMENT,
  AGREEMENTREF,
  NOTE,
  SUPPLIERSTOREDPROPS,
  SUPPLIER_REF,
  SUPPLIERACC_REF,
  REJECTCAUSE,
  INFONUMBER,
  NOTIFYDATE,
  PURPORTDOC,
  MoneyPromiseNumber)
AS
  SELECT
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    PURPORTDOC,
    MoneyPromiseNumber
  FROM TB_ExecutionDocumentsCaption
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_ID
  INSTEAD OF DELETE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  quant$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_DOCEXECCAPTION_BD)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  select count(ID)   into quant$ from executiondocumentscaption
  where AdjustmentRef = :old.ID
  ;
  if (quant$  = 0) then
    delete from ExecutionDocumentsDetail where (RecordIndex = :old.ID);
    delete from paymentschedule where (ExecutionRef = :old.ID)and(ProgIndex=308);

  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_10 (TR_DocExecCaption_BD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_EXECUTIONDOCUMENTSCAPTION
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AD_10 (TR_ExecDocCaption_AD_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*   LastAdjustment     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAdjustment = 1)) then
    update ExecutionDocumentsCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;
  /*   LastAccepted     */
  if ((:old.AdjustmentRef is not null) and (:old.LastAccepted = 1)) then
    update ExecutionDocumentsCaption set
    LastAccepted = 1,
    RVersion = -1
    where (ID = :old.AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AD_200 (TR_EXECDOCCAPTION_AD_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_EXECDOCCAPTION_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, SUMMA) values (114, :old.ID, SYSDATE, :old.SUMMA);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_II
  INSTEAD OF INSERT
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$MoneyPromiseNumber EXECUTIONDOCUMENTSCAPTION.MoneyPromiseNumber%TYPE := :NEW.MoneyPromiseNumber;
--
  Tmp$ NUMBER(10);
  AdjID$ NUMBER(10);
  AdjDocNum$ VARCHAR2(50);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  PreviousInner$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_ExecDoccaption_BI)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  if (new$id is null) then
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  if (new$Accepted is null) then
    new$Accepted := 1;
  END IF;
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef
      into new$BudgetRef     from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    GetIntConst(-1,3,new$BudgetRef);
  END IF;
  if (new$Supplier_Ref is null and new$SupplierAcc_Ref is not null) then
    BEGIN
      select oa.Org_Ref
      into new$Supplier_Ref   from Org_Accounts oa
      where oa.id = new$SupplierAcc_Ref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,     ,      */
  if (new$AdjustmentRef is null) then
    new$InnerNumber := GEN_ID('g_ExecDocNumber',1);

  else
    BEGIN
      /*          */
      select
      InnerNumber
      into PreviousInner$     from ExecutionDocumentsCaption
      where ID = new$AdjustmentRef and LastAccepted = 1 and LastAdjustment = 1
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (PreviousInner$ is null) then
      RaiseException('EX_ExecDoc_NotFindInner');
    END IF;
    new$InnerNumber := PreviousInner$;

  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_EXECDOCCAPTION_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_EXECDOCCAPTION_BI_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*    .*/
  if (new$InnerNumber is null) then
    RaiseException('EX_AGR_InnerNumsIsNull');
  END IF;

  /*    */
  select max(AdjustmentNumber)
  into Tmp$     from ExecutionDocumentsCaption
  where (InnerNumber = new$InnerNumber)
  ;
  /*      ,   0*/
  if (Tmp$ is null) then
    new$AdjustmentNumber := 0;

  else
    new$AdjustmentNumber := Tmp$ + 1;
  END IF;
  /*        ,     */
  if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
    new$LastAdjustment := 0;

  else
    new$LastAdjustment := 1;
  END IF;
  /*   ,       */
  if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
    new$LastAccepted := 1;

  else
    new$LastAccepted := 0;
  END IF;
  /*    */
  if (new$AdjustmentRef is not null) then
    /*      -    */
    select count(ID), max(ID), max(DocNumber)
    into Tmp$, AdjID$, AdjDocNum$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (LastAccepted = 1)
    ;
    /*   ,  */
    if (Tmp$ <> 1) then
      RaiseException('EX_ExecDoc_AdjustNotAccept');
    END IF;
    /*         ,  */
    select count(ID)
    into Tmp$       from ExecutionDocumentsCaption
    where (InnerNumber = new$InnerNumber) and (AcceptDate is null)
    ;
    if (Tmp$ > 0) then
      RaiseException('EX_ExecDoc_AdjustDuplicate');
    END IF;
    /* ,    ,    */
    new$AdjustmentRef := AdjID$;

  else /*     */
    /*       (    )*/
    new$AdjustmentRef := null;
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (tr_execdoccaption_bi_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then
    new$senderIdKey := -1;

  else
    new$senderIdKey := new$senderId;
  END IF;
  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;

  else
    new$SenderRecordIDKey := new$SenderRecordID;
  END IF;

-- - - - - - - - - - - - -
-- BI_60 (tr_execdoccaption_bi_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_EXECDOCCAPTION_BI_500)
-- Last update 08.12.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_EXECUTIONDOCUMENTSCAPTION (
    ID,
    DOCTYPE,
    DOCUMENTDATE,
    ACCEPTDATE,
    SUMMA,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    STEPNUMBER,
    FACIALACC_CLS,
    RECIPIENT_REF,
    REGISTRATIONTYPE,
    REESTRNUMBER,
    AGREEMENTINNERNUMBER,
    REJECTCLS,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXECDOCFINSUMMA,
    FACT,
    DOCNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REALID,
    INNERNUMBER,
    ADJUSTMENTREF,
    ADJUSTMENTNUMBER,
    ACCEPTED,
    LASTACCEPTED,
    LASTADJUSTMENT,
    AGREEMENTREF,
    NOTE,
    SUPPLIERSTOREDPROPS,
    SUPPLIER_REF,
    SUPPLIERACC_REF,
    REJECTCAUSE,
    INFONUMBER,
    NOTIFYDATE,
    PURPORTDOC,
    MoneyPromiseNumber
  ) VALUES (
    new$ID,
    new$DOCTYPE,
    new$DOCUMENTDATE,
    new$ACCEPTDATE,
    new$SUMMA,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$STEPNUMBER,
    new$FACIALACC_CLS,
    new$RECIPIENT_REF,
    new$REGISTRATIONTYPE,
    new$REESTRNUMBER,
    new$AGREEMENTINNERNUMBER,
    new$REJECTCLS,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXECDOCFINSUMMA,
    new$FACT,
    new$DOCNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REALID,
    new$INNERNUMBER,
    new$ADJUSTMENTREF,
    new$ADJUSTMENTNUMBER,
    new$ACCEPTED,
    new$LASTACCEPTED,
    new$LASTADJUSTMENT,
    new$AGREEMENTREF,
    new$NOTE,
    new$SUPPLIERSTOREDPROPS,
    new$SUPPLIER_REF,
    new$SUPPLIERACC_REF,
    new$REJECTCAUSE,
    new$INFONUMBER,
    new$NOTIFYDATE,
    new$PURPORTDOC,
    new$MoneyPromiseNumber);

-- - - - - - - - - - - - -
-- AI_0 (TR_ExecDocCaption_AI)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 0,
    RVersion = -1
    where (ID = new$AdjustmentRef);
    if (new$LastAccepted = 1) then
      update ExecutionDocuMENTSCaption set
      LastAccepted = 0,
      RVersion = -1
      where (ID = new$AdjustmentRef);

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_EXECDOCCAPTION_AI_500)
-- - - - - - - - - - - - -

-- 25.08.2004
  delete from DelRecIndexes where (TableID = 114) and (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_EXECUTIONDOCUMENTSCAPTIO_IU
  INSTEAD OF UPDATE
  ON EXECUTIONDOCUMENTSCAPTION
  FOR EACH ROW
DECLARE
  new$ID EXECUTIONDOCUMENTSCAPTION.ID%TYPE := :NEW.ID;
  new$DOCTYPE EXECUTIONDOCUMENTSCAPTION.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$DOCUMENTDATE EXECUTIONDOCUMENTSCAPTION.DOCUMENTDATE%TYPE := :NEW.DOCUMENTDATE;
  new$ACCEPTDATE EXECUTIONDOCUMENTSCAPTION.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$SUMMA EXECUTIONDOCUMENTSCAPTION.SUMMA%TYPE := :NEW.SUMMA;
  new$CREATERUSER EXECUTIONDOCUMENTSCAPTION.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE EXECUTIONDOCUMENTSCAPTION.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE EXECUTIONDOCUMENTSCAPTION.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER EXECUTIONDOCUMENTSCAPTION.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF EXECUTIONDOCUMENTSCAPTION.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$STEPNUMBER EXECUTIONDOCUMENTSCAPTION.STEPNUMBER%TYPE := :NEW.STEPNUMBER;
  new$FACIALACC_CLS EXECUTIONDOCUMENTSCAPTION.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$RECIPIENT_REF EXECUTIONDOCUMENTSCAPTION.RECIPIENT_REF%TYPE := :NEW.RECIPIENT_REF;
  new$REGISTRATIONTYPE EXECUTIONDOCUMENTSCAPTION.REGISTRATIONTYPE%TYPE := :NEW.REGISTRATIONTYPE;
  new$REESTRNUMBER EXECUTIONDOCUMENTSCAPTION.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$AGREEMENTINNERNUMBER EXECUTIONDOCUMENTSCAPTION.AGREEMENTINNERNUMBER%TYPE := :NEW.AGREEMENTINNERNUMBER;
  new$REJECTCLS EXECUTIONDOCUMENTSCAPTION.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$CRYPTOSTATUS EXECUTIONDOCUMENTSCAPTION.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID EXECUTIONDOCUMENTSCAPTION.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID EXECUTIONDOCUMENTSCAPTION.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$REVIEWNOTE EXECUTIONDOCUMENTSCAPTION.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF EXECUTIONDOCUMENTSCAPTION.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION EXECUTIONDOCUMENTSCAPTION.RVERSION%TYPE := :NEW.RVERSION;
  new$EXECDOCFINSUMMA EXECUTIONDOCUMENTSCAPTION.EXECDOCFINSUMMA%TYPE := :NEW.EXECDOCFINSUMMA;
  new$FACT EXECUTIONDOCUMENTSCAPTION.FACT%TYPE := :NEW.FACT;
  new$DOCNUMBER EXECUTIONDOCUMENTSCAPTION.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$SENDERIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY EXECUTIONDOCUMENTSCAPTION.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REALID EXECUTIONDOCUMENTSCAPTION.REALID%TYPE := :NEW.REALID;
  new$INNERNUMBER EXECUTIONDOCUMENTSCAPTION.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$ADJUSTMENTREF EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$ADJUSTMENTNUMBER EXECUTIONDOCUMENTSCAPTION.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$ACCEPTED EXECUTIONDOCUMENTSCAPTION.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$LASTACCEPTED EXECUTIONDOCUMENTSCAPTION.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$LASTADJUSTMENT EXECUTIONDOCUMENTSCAPTION.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$AGREEMENTREF EXECUTIONDOCUMENTSCAPTION.AGREEMENTREF%TYPE := :NEW.AGREEMENTREF;
  new$NOTE EXECUTIONDOCUMENTSCAPTION.NOTE%TYPE := :NEW.NOTE;
  new$SUPPLIERSTOREDPROPS EXECUTIONDOCUMENTSCAPTION.SUPPLIERSTOREDPROPS%TYPE := :NEW.SUPPLIERSTOREDPROPS;
  new$SUPPLIER_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIER_REF%TYPE := :NEW.SUPPLIER_REF;
  new$SUPPLIERACC_REF EXECUTIONDOCUMENTSCAPTION.SUPPLIERACC_REF%TYPE := :NEW.SUPPLIERACC_REF;
  new$REJECTCAUSE EXECUTIONDOCUMENTSCAPTION.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$INFONUMBER EXECUTIONDOCUMENTSCAPTION.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$NOTIFYDATE EXECUTIONDOCUMENTSCAPTION.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$PURPORTDOC EXECUTIONDOCUMENTSCAPTION.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$MoneyPromiseNumber EXECUTIONDOCUMENTSCAPTION.MoneyPromiseNumber%TYPE := :NEW.MoneyPromiseNumber;
--
  CNT$1 NUMBER(10);
  CNT$2 NUMBER(10);
  CntAgr$ NUMBER(10);
  CntStep$ NUMBER(10);
  agr_accepted$ NUMBER(10);
  agr_acceptdate$ NUMBER(10);
  CountExecDoc$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_EXECDOCCAPTION_BU)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$DocType is null) then
    new$DocType := 0;
  END IF;
  if (new$Summa is null) then
    new$Summa := 0;
  END IF;
  if (new$ExecDocFinSumma is null) then
    new$ExecDocFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$RegistrationType is null) then
    new$RegistrationType := 0;
  END IF;
  if (new$Fact is null) then
    new$Fact := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      SELECT COUNT(                   Id
      ) INTO CNT$1
      from ExecutionDocumentsDetail
      where
      (                   RecordIndex = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$1<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      SELECT COUNT(                   Id
      ) INTO CNT$2
      from PaymentSchedule
      where
      (                   ExecutionRef = :old.Id
      ) AND (ROWNUM = 1)                ;
      if ((CNT$2<> 0)         ) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
    END IF;
  END IF;
  /*     ,        */
  if (new$InnerNumber is null) then
    new$InnerNumber := :old.InnerNumber;
  END IF;
  /* c,           */
  /* ,    */
  if (new$InnerNumber <> :old.InnerNumber or
  new$AdjustmentRef <> :old.AdjustmentRef or
  new$AdjustmentNumber <> :old.AdjustmentNumber) then
    RaiseException('EX_Agr_ChangeInnerNums');
  END IF;
  /*      id */
  new$agreementinnernumber := null;
  if (new$agreementref is not null) then
    BEGIN
      select
      innernumber
      into new$agreementinnernumber     from agreements
      where
      id = new$agreementref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_5 (TR_EXECDOCCAPTION_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;

    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_EXECDOCCAPTION_BU_10)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*     */
  if (:old.AcceptDate is not null and :old.Accepted = 0 and (new$Accepted = 1 or new$AcceptDate is null)) then
    RaiseException('EX_RollbackCancel');
  END IF;

  /*   ,     LastAccepted*/
  if (:old.AcceptDate is null and new$AcceptDate is not null and new$Accepted = 1) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 1;

    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;

  /*    ,     LastAccepted*/
  if (:old.AcceptDate is not null and :old.Accepted = 1 and new$AcceptDate is null) then
    /*  LastAccepted         */
    if (:old.LastAdjustment = 1) then
      new$LastAccepted := 0;

    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
  END IF;

  /*   ,     LastAdjustment  LastAccepted */
  if (new$AcceptDate is not null and new$Accepted = 0 and (:old.AcceptDate is null or :old.Accepted = 1)) then
    if (:old.LastAdjustment = 1) then
      new$LastAdjustment := 0;
      new$LastAccepted := 0;

    else
      RaiseException('EX_ExecDoc_ChangeStateAdjust');
    END IF;
    SELECT COUNT(                 Id
    ) INTO CNT$1
    from ExecutionDocumentsCaption
    where
    (                 InnerNumber = new$InnerNumber and AdjustmentNumber > 0
    ) AND (ROWNUM = 1)              ;
    /*          */
    if (new$AdjustmentNumber = 0 and
    (CNT$1<> 0)       ) then
      RaiseException('EX_ExecDoc_PrimaryAgrHasNotify');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_40 (tr_execdoccaption_bu_40)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  if ((:old.AcceptDate is not null) and (new$AcceptDate is null)) then
    select count(ID) into CntAgr$ from Agreements where (CloseDoc = :old.ID) ;
    select count(ID) into CntStep$ from AgreementSteps where (CloseDoc = :old.ID) ;
    if ((CntAgr$ > 0) or (CntStep$ > 0)) then
      RaiseException('ex_CannotUpdateCloseDoc');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_60 (tr_execdoccaption_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$agreementinnernumber is not null) then
    BEGIN
      /*        , .. 
             ,    ,   
            ,     */
      select accepted, acceptdate     into
      agr_accepted$, agr_acceptdate$ from agreements
      where
      innernumber = new$agreementinnernumber and adjustmentnumber = 0
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*        */
    if (new$acceptdate is null and agr_accepted$ = 0 and agr_acceptdate$ is not null) then
      RaiseException('EX_Agr_Rejected');
    END IF;
    /*        */
    if (new$accepted = 1 and new$acceptdate is not null and
    (agr_accepted$ = 0 or agr_acceptdate$ is null)) then
      RaiseException('EX_Agr_NotAccepted');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_EXECDOCCAPTION_BU_200)
-- Create 04.10.2004
-- - - - - - - - - - - - -

  /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$ID, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_EXECDOCCAPTION_BU_210)
-- Version 11.20.00.1
-- - - - - - - - - - - - -

  /*   */
  if (new$rejectcls is not null and new$accepted = 0) then
    /*         */
    select
    count(ffd.id)
    into CountExecDoc$     from
    facialfindetail ffd
    left join facialfincaption ffc on ffc.id = ffd.recordindex
    where
    (ffc.acceptdate is not null and (ffd.sourceexecdoc = new$id or ffd.destexecdoc = new$id))
    ;
    /*       */
    if (CountExecDoc$ <> 0) then
      RaiseException('ex_exedoc_useinfacialfindetail');
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_EDCAPTION_BU_700)
-- Create 14.10.2004
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_EXECUTIONDOCUMENTSCAPTION SET
    ID = new$ID,
    DOCTYPE = new$DOCTYPE,
    DOCUMENTDATE = new$DOCUMENTDATE,
    ACCEPTDATE = new$ACCEPTDATE,
    SUMMA = new$SUMMA,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    STEPNUMBER = new$STEPNUMBER,
    FACIALACC_CLS = new$FACIALACC_CLS,
    RECIPIENT_REF = new$RECIPIENT_REF,
    REGISTRATIONTYPE = new$REGISTRATIONTYPE,
    REESTRNUMBER = new$REESTRNUMBER,
    AGREEMENTINNERNUMBER = new$AGREEMENTINNERNUMBER,
    REJECTCLS = new$REJECTCLS,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXECDOCFINSUMMA = new$EXECDOCFINSUMMA,
    FACT = new$FACT,
    DOCNUMBER = new$DOCNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REALID = new$REALID,
    INNERNUMBER = new$INNERNUMBER,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    ACCEPTED = new$ACCEPTED,
    LASTACCEPTED = new$LASTACCEPTED,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    AGREEMENTREF = new$AGREEMENTREF,
    NOTE = new$NOTE,
    SUPPLIERSTOREDPROPS = new$SUPPLIERSTOREDPROPS,
    SUPPLIER_REF = new$SUPPLIER_REF,
    SUPPLIERACC_REF = new$SUPPLIERACC_REF,
    REJECTCAUSE = new$REJECTCAUSE,
    INFONUMBER = new$INFONUMBER,
    NOTIFYDATE = new$NOTIFYDATE,
    PURPORTDOC = new$PURPORTDOC,
    MoneyPromiseNumber = new$MoneyPromiseNumber
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_0 (TR_ExecDocCaption_AU)
-- Version 7.00.01.1
-- - - - - - - - - - - - -

  /*       */
  /*     ,       */
  if ((new$AdjustmentRef is not null) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update ExecutionDocuMENTSCaption set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentRef is not null) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update ExecutionDocuMENTSCaption set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_EXECDOCCAPTION_AU_30)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$Accepted <> :old.Accepted) or
  (new$AcceptDate is not null and :old.AcceptDate is null) or
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where ExecutionRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_EXECDOCCAPTION_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (114, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=114) and (RecordId=new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- tr_DualRights_bu_50_1210.sql
-- #########################################################
-- #########################################################

/*  tr_DualRights_bu_50     ObjRef1, ObjRef2 */
-- CREATE TRIGGER tr_DualRights_bu_50
CREATE OR REPLACE TRIGGER TR_DUALRIGHTS_BU
  BEFORE UPDATE
  ON DUALRIGHTS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_50 (tr_DualRights_bu_50)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  if ((:new.ObjRef1 <> :old.ObjRef1) or (:new.ObjRef1Up is null)) then
    :new.ObjRef1Up := :new.ObjRef1;
  END IF;
  /* /    */
  if ((:new.ObjectKindRef in (8000000, 27000000)) and ((:new.ObjRef2 <> :old.ObjRef2) or (:new.ObjRef2Up is null))) then
    FacialAcc_CLSUp(:new.ObjRef2,:new.ObjRef2Up);
  END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- delete_dup_rights.sql
-- #########################################################
-- #########################################################

/*      */
delete from UsersRights t1
where 
  exists (
    select * from UsersRights t2 
    where
      (t1.Id < t2.Id) and (t1.UserRef = t2.UserRef) and
      (t1.RightRef = t2.RightRef) and (t1.IsReject = t2.IsReject) and (t1.ObjRef = t2.ObjRef) and 
      (t1.ObjectKindRef = t2.ObjectKindRef) and (t1.RightKindRef = t2.RightKindRef)
  )
/
delete from GroupsRights t1
where 
  exists (
    select * from GroupsRights t2 
    where
      (t1.Id < t2.Id) and (t1.GroupRef = t2.GroupRef) and
      (t1.RightRef = t2.RightRef) and (t1.IsReject = t2.IsReject) and (t1.ObjRef = t2.ObjRef) and 
      (t1.ObjectKindRef = t2.ObjectKindRef) and (t1.RightKindRef = t2.RightKindRef)
  )
/
commit work
/

-- #########################################################
-- #########################################################
-- Create_G_MoneyPromiseNum.sql
-- #########################################################
-- #########################################################

/*      (ExecutionDocumentsCaption.MoneyPromiseNumber) */
INSERT INTO Generators(Name, Value) VALUES ('G_MONEYPROMISENUM', 0)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_StoredContent_Incomes32.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE TB_INCOMES32 ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/

CREATE OR REPLACE VIEW INCOMES32 (
  ID,
  DOCNUMBER,
  DOCCOUNT,
  IDATE,
  DEBIT,
  CREDIT,
  DOCTYPE,
  INN,
  ORG_REF,
  ACCOUNTINDEX,
  KD,
  SUBKD,
  REGIONCLS,
  GOSNI,
  INCACCOUNT,
  PROGINDEX,
  RECORDINDEX,
  BUDGETREF,
  CREATERUSER,
  CREATEDATE,
  UPDATEDATE,
  UPDATERUSER,
  NOTE,
  RECORDINDEX2,
  ELNUM,
  NOTEEX,
  BUHPAYMENTCLS,
  ACCOUNTREF,
  ELPACKETNUM,
  FACIALACC_CLS,
  NDS,
  MEANSTYPE,
  RECORDDATE,
  TOTALREF,
  REQUESTSINDEX,
  KVSR,
  TAXNOTE,
  DOCNUM,
  REALPAYERORG_REF,
  DOCDATE,
  DOCBASE,
  FACT,
  RVERSION,
  KFSR,
  KESR,
  KVR,
  KCSR,
  SUMCOMPLETE,
  ELDOCREF,
  REQUESTSINDEX2,
  FEDERALFUNDSREF,
  BUHOPERATIONCLS,
  IFS,
  IFS_CORR,
  CLSTYPE,
  NDSNOTE,
  DOGNUM,
  SENDERID,
  SENDERRECORDID,
  OKATO,
  ADDOKATO,
  REJECTCLS,
  FUNDSSOURCE,
  DIRECTIONCLS,
  ISBLOCKED,
  BLOCKEDCAUSE,
  UNBLOCKEDDATE,
  UNBLOCKEDCAUSE,
  STIMATEID,
  TRANSFERTCLS,
  SUBSIDYCLS,
  FAORGTYPE,
  OKTMO,
  UINCODE,
  FINTYPE,
  INVESTOBJECT,
  CONTRACTCOSTSCLS,
  TARGETCLS,
  REJECTCAUSE,
  STOREDCONTENT)
AS
  SELECT
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE,
    STOREDCONTENT
  FROM TB_INCOMES32
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_ID
  INSTEAD OF DELETE
  ON INCOMES32
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_10 (TR_INCOMES32_BD10)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  delete
  from CurrencyIncomes
  where (id = :old.id);

-- - - - - - - - - - - - -
-- BD_20 (T_INCOMES32_BD_20)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

  /*    */
  if (:old.DocType between 1010 and 1019) then
    delete from PayDoc32
    where
      (ProgIndex = :old.ProgIndex)
    and
     (RecordIndex = :old.id);
  end if;

-- - - - - - - - - - - - -
-- BD_500 (TR_INCOMES32_BD_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  Update QuotesTitle set
  DocChangeDate = SYSDATE,
  RVersion = -1
  where id = :old.recordindex;

-- - - - - - - - - - - - -
-- BD_600 (TR_INCOMES32_BD_600)
-- Last update 14.10.2009
-- - - - - - - - - - - - -

    --    
    if (:old.ProgIndex = 41) then
        delete
            from Incomes32
        where
           (ProgIndex=42)and
           (RecordIndex=:old.id);
    end if;

    --  (  )
    if (:old.ProgIndex = 42) then
        delete
            from Incomes32
        where
            (ProgIndex=43)and
            (RecordIndex=:old.id);
    end if;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_INCOMES32
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_500 (TR_INCOMES32_AD_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordID, DeleteDate, ProgIndex, SUMMA) values (161, :old.ID, SYSDATE, :old.ProgIndex, :old.DEBIT + :old.CREDIT);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_II
  INSTEAD OF INSERT
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT INCOMES32.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  CapDocNumber VARCHAR2(20);
  unkKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  Kd_Master NUMBER(10);
  idKD$ NUMBER(10);
  unkVKD$ VARCHAR2(20);
  val_DocCount$ NUMBER(10);
  val_DocType$ NUMBER(10);
  val_Org_Ref$ NUMBER(10);
  val_AccountIndex$ NUMBER(10);
  val_SubKD$ NUMBER(10);
  val_RegionCLS$ NUMBER(10);
  val_GosNI$ NUMBER(10);
  val_IncAccount$ NUMBER(10);
  val_BudgetRef$ NUMBER(10);
  val_MEANSTYPE$ NUMBER(10);
  val_FACIALACC_CLS$ NUMBER(10);
  val_TransfertCls$ NUMBER(10);
  CapAcceptDate$ NUMBER;
  CapReestrNumber$ VARCHAR2(20);
  CapProgIndex1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INCOMES32_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$id IS NULL) THEN
    select g_shared.nextval into new$id from dual;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN
    new$Gosni := 0;
  END IF;
  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN
    new$DocBase := 0;
  END IF;
  /* 3 -    */
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  IF (new$ProgIndex IS NULL) THEN
    new$ProgIndex := 3;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS IS NULL) THEN
    new$IFS := 0;
  END IF;
  IF (new$IFS_CORR IS NULL) THEN
    new$Ifs_Corr := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;

  /*  ,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT qt.BudgetRef      INTO new$BudgetRef FROM QuotesTitle qt
      WHERE qt.Id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,     */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0)) THEN
    BEGIN
      SELECT fa.BudgetRef      INTO new$BudgetRef FROM FacialAcc_Cls fa
      WHERE fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    0,    */
  IF ((new$BudgetRef IS NULL) OR (new$BudgetRef = 0))
  THEN
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;

  IF (new$ProgIndex = 45)
  THEN
    IF (new$IncAccount IS NULL) THEN
      GetDefDFAccRefForBudget(new$BudgetRef,new$IncAccount);
    END IF;
    BEGIN

      /*     */
      SELECT qt.ProgIndex, qt.AcceptDate, qt.IncAccount, qt.ReestrNumber
      INTO CapProgIndex1$, CapAcceptDate$, new$IncAccount, CapReestrNumber$       FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    /*           / */
    /*  /   after insert */
    IF (CapProgIndex1$ <> 145) THEN
      new$iDate := CapAcceptDate$;
    END IF;
    IF ((CapProgIndex1$ = 145)AND (NOT ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0)OR (new$Credit<0)))) )
    THEN
      new$Idate := CapAcceptDate$;
    END IF;
    /*   -    () */
    IF ((CapProgIndex1$ = 45) AND (CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN
      /*        , *//*    */

      new$FederalFundsRef := new$ID;
      /* if-then */
    END IF;/* if-then*/
  END IF;
  BEGIN
    /*     \*/
    SELECT org.Org_Type   INTO new$FAOrgType FROM Organizations org
    INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
    WHERE fac.ID = new$FacialACC_Cls
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*    */
  GETTARGETCLS(null, new$transfertcls, null, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BI_5 (TR_INCOMES_BI_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BI_9 (TR_INCOMES32_BI_VZ)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   IF (new$ProgIndex = 9) THEN
      /*   */
      GetIntConst (9, 1, new$IncAccount);

      BEGIN
        /*      */
        SELECT ACCEPTDATE, BUDGETREF
          INTO new$IDate, new$BudgetRef
          FROM VZ_OFFSET
         WHERE ID = new$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_INCOMES32_BI_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   BEGIN
      SELECT Inn
        INTO new$Inn
        FROM Organizations o
       WHERE (o.ID = new$Org_Ref);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

/*  .    ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT c.BudgetRef
           INTO new$budgetref
           FROM QuotesTitle c
          WHERE c.ID = NEW$RecordIndex;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  .  ,     */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      BEGIN
         SELECT fa.BudgetRef
           INTO new$budgetref
           FROM FacialAcc_Cls fa
          WHERE fa.ID = NEW$FacialAcc_Cls;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
   END IF;

   /*  ,    */
   IF ((new$budgetref IS NULL) OR (new$budgetref = 0)) THEN
      GetIntConst (-1, 3, new$budgetref);
   END IF;

-- - - - - - - - - - - - -
-- BI_30 (TR_INCOMES32_BI_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then
    BEGIN
      select q.BuildDate
      into
      new$DocDate        from QuotesTitle q
      where q.id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BI_70 (TR_INCOMES32_BI_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
               */
         new$FederalFundsRef := new$ID;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BI_100 (TR_INCOMES32_BI_100)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if ((not (newKD$  like unkKD$)) and
    (not (newKD$  like unkVKD$))) then
      /*   (    
            ) ,  
         ,   */

      /*       */
      if (new$Debit <> 0) then
        RaiseException('ex_UnknownRedirect');
      END IF;
      BEGIN

        /*      */
        select KD,DocCount,DocType,
        Org_Ref,AccountIndex,SubKD,RegionCLS,GosNI,
        IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,
        TransfertCls
        into
        idKD$,
        val_DocCount$,
        val_DocType$,
        val_Org_Ref$,
        val_AccountIndex$,
        val_SubKD$,
        val_RegionCLS$,
        val_GosNI$,
        val_IncAccount$,
        val_BudgetRef$,
        val_MEANSTYPE$  ,
        val_FACIALACC_CLS$,
        val_TransfertCls$         from incomes32 where id=new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      if (not idKD$ is null) then
        insert into
        /* KD=   (      )
              Debit=0
              redit=-new.credit
              ProgIndex=43
              RecordIndex=new.id
              id    Incomes32*/
        Incomes32(CreaterUser, DocNum,DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS, TransfertCls)
        Values(new$CreaterUser, new$DocNum, val_DocCount$, new$iDate, new$DOCDATE, 0, -new$Credit, val_DocType$,
        val_Org_Ref$, val_AccountIndex$, idKD$, val_SubKD$, val_RegionCLS$, val_GosNI$,
        43,new$Id, val_IncAccount$, val_BudgetRef$, new$Note,val_MEANSTYPE$,val_FACIALACC_CLS$,val_TransfertCls$);

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_110 (TR_INCOMES32_BI_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       /*       ClsType */
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                /*  -  */
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      /*   */
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INCOMES32_BI_500)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

  Update QuotesTitle set
  DocChangeDate = new$UpdateDate,
  RVersion = -1
  where id = new$recordindex;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INCOMES32 (
    ID,
    DOCNUMBER,
    DOCCOUNT,
    IDATE,
    DEBIT,
    CREDIT,
    DOCTYPE,
    INN,
    ORG_REF,
    ACCOUNTINDEX,
    KD,
    SUBKD,
    REGIONCLS,
    GOSNI,
    INCACCOUNT,
    PROGINDEX,
    RECORDINDEX,
    BUDGETREF,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    NOTE,
    RECORDINDEX2,
    ELNUM,
    NOTEEX,
    BUHPAYMENTCLS,
    ACCOUNTREF,
    ELPACKETNUM,
    FACIALACC_CLS,
    NDS,
    MEANSTYPE,
    RECORDDATE,
    TOTALREF,
    REQUESTSINDEX,
    KVSR,
    TAXNOTE,
    DOCNUM,
    REALPAYERORG_REF,
    DOCDATE,
    DOCBASE,
    FACT,
    RVERSION,
    KFSR,
    KESR,
    KVR,
    KCSR,
    SUMCOMPLETE,
    ELDOCREF,
    REQUESTSINDEX2,
    FEDERALFUNDSREF,
    BUHOPERATIONCLS,
    IFS,
    IFS_CORR,
    CLSTYPE,
    NDSNOTE,
    DOGNUM,
    SENDERID,
    SENDERRECORDID,
    OKATO,
    ADDOKATO,
    REJECTCLS,
    FUNDSSOURCE,
    DIRECTIONCLS,
    ISBLOCKED,
    BLOCKEDCAUSE,
    UNBLOCKEDDATE,
    UNBLOCKEDCAUSE,
    STIMATEID,
    TRANSFERTCLS,
    SUBSIDYCLS,
    FAORGTYPE,
    OKTMO,
    UINCODE,
    FINTYPE,
    INVESTOBJECT,
    CONTRACTCOSTSCLS,
    TARGETCLS,
    REJECTCAUSE,
    STOREDCONTENT
  ) VALUES (
    new$ID,
    new$DOCNUMBER,
    new$DOCCOUNT,
    new$IDATE,
    new$DEBIT,
    new$CREDIT,
    new$DOCTYPE,
    new$INN,
    new$ORG_REF,
    new$ACCOUNTINDEX,
    new$KD,
    new$SUBKD,
    new$REGIONCLS,
    new$GOSNI,
    new$INCACCOUNT,
    new$PROGINDEX,
    new$RECORDINDEX,
    new$BUDGETREF,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$NOTE,
    new$RECORDINDEX2,
    new$ELNUM,
    new$NOTEEX,
    new$BUHPAYMENTCLS,
    new$ACCOUNTREF,
    new$ELPACKETNUM,
    new$FACIALACC_CLS,
    new$NDS,
    new$MEANSTYPE,
    new$RECORDDATE,
    new$TOTALREF,
    new$REQUESTSINDEX,
    new$KVSR,
    new$TAXNOTE,
    new$DOCNUM,
    new$REALPAYERORG_REF,
    new$DOCDATE,
    new$DOCBASE,
    new$FACT,
    new$RVERSION,
    new$KFSR,
    new$KESR,
    new$KVR,
    new$KCSR,
    new$SUMCOMPLETE,
    new$ELDOCREF,
    new$REQUESTSINDEX2,
    new$FEDERALFUNDSREF,
    new$BUHOPERATIONCLS,
    new$IFS,
    new$IFS_CORR,
    new$CLSTYPE,
    new$NDSNOTE,
    new$DOGNUM,
    new$SENDERID,
    new$SENDERRECORDID,
    new$OKATO,
    new$ADDOKATO,
    new$REJECTCLS,
    new$FUNDSSOURCE,
    new$DIRECTIONCLS,
    new$ISBLOCKED,
    new$BLOCKEDCAUSE,
    new$UNBLOCKEDDATE,
    new$UNBLOCKEDCAUSE,
    new$STIMATEID,
    new$TRANSFERTCLS,
    new$SUBSIDYCLS,
    new$FAORGTYPE,
    new$OKTMO,
    new$UINCODE,
    new$FINTYPE,
    new$INVESTOBJECT,
    new$CONTRACTCOSTSCLS,
    new$TARGETCLS,
    new$REJECTCAUSE,
    new$STOREDCONTENT);

-- - - - - - - - - - - - -
-- AI_20 (T_INCOMES32_AI_20)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   --     
   if (new$ProgIndex <> 42) then
     BEGIN
       SELECT ProgIndex, DocNumber, AcceptDate
        INTO CapProgIndex, CapDocNumber, CapAcceptDate
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
     EXCEPTION
       WHEN NO_DATA_FOUND THEN NULL;
     END;
   end if;

   --   - ,  
   IF ((CapProgIndex = 145) or (new$ProgIndex=42)) THEN

      If ((new$ProgIndex=42) and (new$DocType between 1010 and 1019) and
         (new$Debit>0) and (new$DOCDATE is not null))
      then
        BEGIN
          select kd into Kd_Master
    From Incomes32 inc
          where inc.id = new$RecordIndex;
        EXCEPTION
          WHEN NO_DATA_FOUND THEN NULL;
        END;

        if (Kd_Master = new$Kd) then
          CapAcceptDate := new$DOCDATE;
          CapProgIndex  := new$ProgIndex;
          CapDocNumber  := new$DocNum;
        end if;
      end if; --       (         )

      --             
      IF ((CapAcceptDate IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit > 0) OR (new$Credit < 0))) THEN
         --    ( RealPayerOrg_Ref(PayDoc32)=new$RealPayerOrg_Ref(Incomes32))
         INSERT INTO PayDoc32
            (BudgetRef, AccountRef, PayerAttrRef, InputDate,
             Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref, FACIALACC_CLS)
         VALUES (new$BudgetRef, new$AccountRef, new$IncAccount, CapAcceptDate,
             (new$Debit - new$Credit), new$Note, new$ProgIndex, new$id, CapDocNumber, new$TaxNote,
             new$RealPayerOrg_Ref,new$FACIALACC_CLS);
      -- (new$Debit - new$Credit) --- ..      ,    ,
      --             
      END IF;

   END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INCOMES32_AI_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 161) AND (RecordID = NEW$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_INCOMES32_IU
  INSTEAD OF UPDATE
  ON INCOMES32
  FOR EACH ROW
DECLARE
  new$ID INCOMES32.ID%TYPE := :NEW.ID;
  new$DOCNUMBER INCOMES32.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$DOCCOUNT INCOMES32.DOCCOUNT%TYPE := :NEW.DOCCOUNT;
  new$IDATE INCOMES32.IDATE%TYPE := :NEW.IDATE;
  new$DEBIT INCOMES32.DEBIT%TYPE := :NEW.DEBIT;
  new$CREDIT INCOMES32.CREDIT%TYPE := :NEW.CREDIT;
  new$DOCTYPE INCOMES32.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$INN INCOMES32.INN%TYPE := :NEW.INN;
  new$ORG_REF INCOMES32.ORG_REF%TYPE := :NEW.ORG_REF;
  new$ACCOUNTINDEX INCOMES32.ACCOUNTINDEX%TYPE := :NEW.ACCOUNTINDEX;
  new$KD INCOMES32.KD%TYPE := :NEW.KD;
  new$SUBKD INCOMES32.SUBKD%TYPE := :NEW.SUBKD;
  new$REGIONCLS INCOMES32.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$GOSNI INCOMES32.GOSNI%TYPE := :NEW.GOSNI;
  new$INCACCOUNT INCOMES32.INCACCOUNT%TYPE := :NEW.INCACCOUNT;
  new$PROGINDEX INCOMES32.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$RECORDINDEX INCOMES32.RECORDINDEX%TYPE := :NEW.RECORDINDEX;
  new$BUDGETREF INCOMES32.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$CREATERUSER INCOMES32.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE INCOMES32.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INCOMES32.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER INCOMES32.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$NOTE INCOMES32.NOTE%TYPE := :NEW.NOTE;
  new$RECORDINDEX2 INCOMES32.RECORDINDEX2%TYPE := :NEW.RECORDINDEX2;
  new$ELNUM INCOMES32.ELNUM%TYPE := :NEW.ELNUM;
  new$NOTEEX INCOMES32.NOTEEX%TYPE := :NEW.NOTEEX;
  new$BUHPAYMENTCLS INCOMES32.BUHPAYMENTCLS%TYPE := :NEW.BUHPAYMENTCLS;
  new$ACCOUNTREF INCOMES32.ACCOUNTREF%TYPE := :NEW.ACCOUNTREF;
  new$ELPACKETNUM INCOMES32.ELPACKETNUM%TYPE := :NEW.ELPACKETNUM;
  new$FACIALACC_CLS INCOMES32.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$NDS INCOMES32.NDS%TYPE := :NEW.NDS;
  new$MEANSTYPE INCOMES32.MEANSTYPE%TYPE := :NEW.MEANSTYPE;
  new$RECORDDATE INCOMES32.RECORDDATE%TYPE := :NEW.RECORDDATE;
  new$TOTALREF INCOMES32.TOTALREF%TYPE := :NEW.TOTALREF;
  new$REQUESTSINDEX INCOMES32.REQUESTSINDEX%TYPE := :NEW.REQUESTSINDEX;
  new$KVSR INCOMES32.KVSR%TYPE := :NEW.KVSR;
  new$TAXNOTE INCOMES32.TAXNOTE%TYPE := :NEW.TAXNOTE;
  new$DOCNUM INCOMES32.DOCNUM%TYPE := :NEW.DOCNUM;
  new$REALPAYERORG_REF INCOMES32.REALPAYERORG_REF%TYPE := :NEW.REALPAYERORG_REF;
  new$DOCDATE INCOMES32.DOCDATE%TYPE := :NEW.DOCDATE;
  new$DOCBASE INCOMES32.DOCBASE%TYPE := :NEW.DOCBASE;
  new$FACT INCOMES32.FACT%TYPE := :NEW.FACT;
  new$RVERSION INCOMES32.RVERSION%TYPE := :NEW.RVERSION;
  new$KFSR INCOMES32.KFSR%TYPE := :NEW.KFSR;
  new$KESR INCOMES32.KESR%TYPE := :NEW.KESR;
  new$KVR INCOMES32.KVR%TYPE := :NEW.KVR;
  new$KCSR INCOMES32.KCSR%TYPE := :NEW.KCSR;
  new$SUMCOMPLETE INCOMES32.SUMCOMPLETE%TYPE := :NEW.SUMCOMPLETE;
  new$ELDOCREF INCOMES32.ELDOCREF%TYPE := :NEW.ELDOCREF;
  new$REQUESTSINDEX2 INCOMES32.REQUESTSINDEX2%TYPE := :NEW.REQUESTSINDEX2;
  new$FEDERALFUNDSREF INCOMES32.FEDERALFUNDSREF%TYPE := :NEW.FEDERALFUNDSREF;
  new$BUHOPERATIONCLS INCOMES32.BUHOPERATIONCLS%TYPE := :NEW.BUHOPERATIONCLS;
  new$IFS INCOMES32.IFS%TYPE := :NEW.IFS;
  new$IFS_CORR INCOMES32.IFS_CORR%TYPE := :NEW.IFS_CORR;
  new$CLSTYPE INCOMES32.CLSTYPE%TYPE := :NEW.CLSTYPE;
  new$NDSNOTE INCOMES32.NDSNOTE%TYPE := :NEW.NDSNOTE;
  new$DOGNUM INCOMES32.DOGNUM%TYPE := :NEW.DOGNUM;
  new$SENDERID INCOMES32.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID INCOMES32.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$OKATO INCOMES32.OKATO%TYPE := :NEW.OKATO;
  new$ADDOKATO INCOMES32.ADDOKATO%TYPE := :NEW.ADDOKATO;
  new$REJECTCLS INCOMES32.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$FUNDSSOURCE INCOMES32.FUNDSSOURCE%TYPE := :NEW.FUNDSSOURCE;
  new$DIRECTIONCLS INCOMES32.DIRECTIONCLS%TYPE := :NEW.DIRECTIONCLS;
  new$ISBLOCKED INCOMES32.ISBLOCKED%TYPE := :NEW.ISBLOCKED;
  new$BLOCKEDCAUSE INCOMES32.BLOCKEDCAUSE%TYPE := :NEW.BLOCKEDCAUSE;
  new$UNBLOCKEDDATE INCOMES32.UNBLOCKEDDATE%TYPE := :NEW.UNBLOCKEDDATE;
  new$UNBLOCKEDCAUSE INCOMES32.UNBLOCKEDCAUSE%TYPE := :NEW.UNBLOCKEDCAUSE;
  new$STIMATEID INCOMES32.STIMATEID%TYPE := :NEW.STIMATEID;
  new$TRANSFERTCLS INCOMES32.TRANSFERTCLS%TYPE := :NEW.TRANSFERTCLS;
  new$SUBSIDYCLS INCOMES32.SUBSIDYCLS%TYPE := :NEW.SUBSIDYCLS;
  new$FAORGTYPE INCOMES32.FAORGTYPE%TYPE := :NEW.FAORGTYPE;
  new$OKTMO INCOMES32.OKTMO%TYPE := :NEW.OKTMO;
  new$UINCODE INCOMES32.UINCODE%TYPE := :NEW.UINCODE;
  new$FINTYPE INCOMES32.FINTYPE%TYPE := :NEW.FINTYPE;
  new$INVESTOBJECT INCOMES32.INVESTOBJECT%TYPE := :NEW.INVESTOBJECT;
  new$CONTRACTCOSTSCLS INCOMES32.CONTRACTCOSTSCLS%TYPE := :NEW.CONTRACTCOSTSCLS;
  new$TARGETCLS INCOMES32.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$REJECTCAUSE INCOMES32.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$STOREDCONTENT INCOMES32.STOREDCONTENT%TYPE := :NEW.STOREDCONTENT;
--
  unkKD$ VARCHAR2(20);
  unkVKD$ VARCHAR2(20);
  newKD$ VARCHAR2(20);
  oldKD$ VARCHAR2(20);
  CapProgIndex NUMBER(10);
  CapAcceptDate NUMBER;
  CapReestrNumber VARCHAR2(20);
  IsReject$ NUMBER(10);
  CapProgIndex$ NUMBER(10);
  CapDocNumber$ VARCHAR2(20);
  CapAcceptDate$ NUMBER;
  PayDocCount$ NUMBER(10);
  ConstPayQueue$ NUMBER(10);
  ConstSendBy$ NUMBER(10);
  Divided$ NUMBER(10);
  Kd_Master$ NUMBER(10);
  Date_Pd$ NUMBER(10);
  DocNumber1$ NUMBER(10);
  CapReestrNumber$ VARCHAR2(20);
  CNT$1 NUMBER(10);
  idKD1$ NUMBER(10);
  val_DocCount1$ NUMBER(10);
  val_DocType1$ NUMBER(10);
  val_Org_Ref1$ NUMBER(10);
  val_AccountIndex1$ NUMBER(10);
  val_SubKD1$ NUMBER(10);
  val_RegionCLS1$ NUMBER(10);
  val_GosNI1$ NUMBER(10);
  val_IncAccount1$ NUMBER(10);
  val_BudgetRef1$ NUMBER(10);
  val_MEANSTYPE1$ NUMBER(10);
  val_FACIALACC_CLS1$ NUMBER(10);
  val_TransfertCls1$ NUMBER(10);
  val_ID431$ NUMBER(10);
  CapProgIndex2$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INCOMES32_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  IF (new$Fact IS NULL) THEN
    new$Fact := 0;
  END IF;
  IF (new$DocBase IS NULL) THEN
    new$DocBase := 0;
  END IF;
  IF (new$Gosni IS NULL) THEN
    new$Gosni := 0;
  END IF;
  /* 3 -    */
  IF (new$ProgIndex IS NULL) THEN
    new$ProgIndex := 3;
  END IF;
  IF (new$KD IS NULL) THEN
    new$KD := 0;
  END IF;
  /*   */
  IF (new$FACIALACC_CLS IS NULL) THEN
    new$FACIALACC_CLS := 0;
  END IF;
  IF (new$MeansType IS NULL) THEN
    new$MeansType := 0;
  END IF;
  IF (new$Debit IS NULL) THEN
    new$Debit := 0;
  END IF;
  IF (new$Credit IS NULL) THEN
    new$Credit := 0;
  END IF;
  IF (new$Org_Ref IS NULL) THEN
    new$Org_Ref := 0;
  END IF;
  IF (new$AccountIndex IS NULL) THEN
    new$AccountIndex := 0;
  END IF;
  IF (new$DocType IS NULL) THEN
    new$DocType := 0;
  END IF;
  IF (new$SubKD IS NULL) THEN
    new$SubKD := 0;
  END IF;
  IF (new$RegionCLS IS NULL) THEN
    new$RegionCLS := 0;
  END IF;
  IF (new$DocCount IS NULL) THEN
    new$DocCount := 1;
  END IF;
  IF (new$BuhPaymentCLS IS NULL) THEN
    new$BuhPaymentCLS := 0;
  END IF;
  IF (new$KVSR IS NULL) THEN
    new$KVSR := 0;
  END IF;
  IF (new$KFSR IS NULL) THEN
    new$KFSR := 0;
  END IF;
  IF (new$KESR IS NULL) THEN
    new$KESR := 0;
  END IF;
  IF (new$KVR IS NULL) THEN
    new$KVR := 0;
  END IF;
  IF (new$KCSR IS NULL) THEN
    new$KCSR := 0;
  END IF;
  IF (new$OKATO IS NULL) THEN
    new$OKATO := 0;
  END IF;
  IF (new$FundsSource IS NULL) THEN
    new$FundsSource := 0;
  END IF;
  IF (new$DirectionCLS IS NULL) THEN
    new$DirectionCLS := 0;
  END IF;
  IF (new$FinType is null) then
    new$FinType := 0;
  END IF;
  IF (new$Debit * new$Credit <> 0) THEN
    RaiseException('ex_FailDebetCretitValue');
  END IF;
  /*   .        */
  IF (new$IFS_CORR IS NULL) THEN
    new$Ifs_Corr := 0;
  END IF;
  IF (new$IFS IS NULL) THEN
    new$Ifs := 0;
  END IF;
  IF (new$BuhOperationCLS IS NULL)
  THEN
    GetIntConst(60, 15,new$BuhOperationCLS);
  END IF;
  BEGIN

    /*     */
    /*   after   ,*/
    /*      */
    SELECT ProgIndex, AcceptDate, ReestrNumber
    INTO CapProgIndex2$, CapAcceptDate$, CapReestrNumber$   FROM QuotesTitle qt
    WHERE
    (qt.ID = new$RecordIndex)
    ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*             
           (  , , ) */
  /*   -    () */
  IF (CapProgIndex2$ = 45)
  THEN
    IF ((CapAcceptDate$ IS NOT NULL) AND (CapReestrNumber$ IS NOT NULL))
    THEN
      /*        ,
                     */
      new$FederalFundsRef := new$ID;
      /* if-then*/
    ELSE
      new$FederalFundsRef := NULL;
      /* if-else*/
    END IF;/* if (CapProgIndex=45) */
  END IF;
  /*     */
  IF (new$BudgetRef <> :old.BudgetRef) THEN
    IF ( NOT((new$BudgetRef IS NULL) AND (:old.BudgetRef IS NULL)) ) THEN
      IF ((new$Progindex = 45) OR (new$Progindex = 42)) THEN
        RaiseException('Ex_CantModufyBudget');
      END IF;
      IF (new$Progindex = 41) THEN
        SELECT COUNT(inc.id ) INTO CNT$1
        FROM incomes32 inc WHERE (inc.recordindex = new$ID) AND (ROWNUM = 1);
        IF ((CNT$1<> 0)) THEN
          RaiseException('Ex_CantModufyBudget');
        END IF;
      END IF;
    END IF;
  END IF;
  /*     \*/
  IF ( (new$FacialAcc_Cls <> :old.FacialAcc_CLS) OR (new$FAOrgType is null) OR
  ((new$IDate is not null) AND ((:old.IDate is null) OR (new$IDate <> :old.IDate))) ) THEN
    BEGIN
      SELECT org.Org_Type      INTO new$FAOrgType FROM Organizations org
      INNER JOIN facialacc_cls fac  on (org.ID = fac.Org_ref)
      WHERE fac.ID = new$FacialACC_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, new$transfertcls, :old.meanstype, new$meanstype,
  new$targetcls,new$targetcls);

-- - - - - - - - - - - - -
-- BU_5 (TR_INCOMES_BU_5)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$DocNum IS NULL) AND NOT (new$DocNumber IS NULL)) THEN
      new$DocNum := CAST (new$DocNumber AS VARCHAR2);
   END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_INCOMES32_BU_0)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

  BEGIN
    SELECT Inn
     INTO new$Inn
     FROM Organizations o
    WHERE (o.ID = new$Org_Ref);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;

-- - - - - - - - - - - - -
-- BU_20 (T_INCOMES32_BU_20)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*      */
  IF (new$ProgIndex <> 42) THEN
    BEGIN
      SELECT ProgIndex, DocNumber, AcceptDate
      INTO CapProgIndex$, CapDocNumber$, CapAcceptDate$     FROM QuotesTitle qt
      WHERE
      (qt.ID = new$RecordIndex)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*   -  ,   */
  IF ( (CapProgIndex$ = 145) OR (new$ProgIndex = 42 ) )
  THEN
    IF ( (new$ProgIndex=42) AND (new$DocType BETWEEN 1010 AND 1019) AND
    (new$Debit>0) AND (new$DOCDATE IS NOT NULL))
    THEN
      BEGIN
        SELECT kd            INTO Kd_Master$ FROM Incomes32 inc
        WHERE inc.id = new$RecordIndex
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
      IF (Kd_Master$ = new$Kd) THEN
        CapAcceptDate$ := new$DOCDATE;
        CapProgIndex$  := new$ProgIndex;
        CapDocNumber$  := new$DocNum;
        /*  */
      END IF;/*       (         )*/
    END IF;
    IF ((CapAcceptDate$ IS NOT NULL) AND (new$DocType BETWEEN 1010 AND 1019) AND ((new$Debit>0) OR (new$Credit<0)))
    THEN

      /*      */
      /* /      Incomes32, ..      ,     */

      /*     /   */
      SELECT COUNT(ID), COUNT(IsDivide), MAX(ANumber), MAX(ACCEPTDATE) /*  ,      */
      INTO PayDocCount$, Divided$, DocNumber1$, Date_Pd$             FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex IN (45,42)) AND (pd.RecordIndex = new$ID)
      ;
      /*            ,  .*/
      /* IF (((NEW.Progindex = 42) AND (DocNumber IS NOT NULL)) AND
                      ((OLD.IDATE = Date_PD) or (OLD.IDATE is null and Date_PD is null))
                     ) THEN
                    EXCEPTION EX_CANNOTUPDATENUMBER;*/


      IF ((new$Progindex = 42) AND (DocNumber1$ IS NOT NULL))
      then
        if ((new$DocType <> :old.DocType )
        or (new$Debit <> :old.Debit )
        or (new$Credit <> :old.Credit)
        or (new$org_ref <> :old.org_ref)
        or ((new$note <> :old.note) or (new$note is not null and :old.note is null))
        or ((new$DOCDate <> :old.DOCDate) or (new$DOCDate is not null and :old.DOCDate is null))
        )
        then
          RaiseException('EX_CANNOTUPDATENUMBER');
        END IF;
      END IF;



      /*           */
      IF (PayDocCount$ = 0)
      THEN
        /*       */
        GetIntConst(11, 2,ConstPayQueue$);
        /*       */
        GetIntConst(11, 1,ConstSendBy$);

        /*    */
        INSERT INTO PayDoc32
        (BudgetRef,AccountRef, PayerAttrRef, InputDate, SendBy, PayQueue,
        Credit, TextNote, ProgIndex, RecordIndex, SourceDocNumber, TaxNote, RealPayerOrg_Ref,FACIALACC_CLS)
        VALUES
        (new$BudgetRef,new$AccountRef, new$IncAccount, CapAcceptDate$, ConstSendBy$, ConstPayQueue$,
        new$Debit - new$Credit, new$Note, new$ProgIndex, new$id, CapDocNumber$, new$TaxNote, new$RealPayerOrg_Ref,new$FACIALACC_CLS);
        /* (new.Debit - new.Credit) --- ..      ,    ,
                                     */

        /* if-then */
      ELSE
        /*     */
        IF (((new$AccountRef = :old.AccountRef) OR
        ((new$AccountRef IS NULL) AND (:old.AccountRef IS NULL)))
        AND (new$IncAccount = :old.IncAccount)
        AND (new$BudgetRef = :old.BudgetRef)
        AND ((new$Note = :old.Note) OR
        ((new$Note IS NULL) AND (:old.Note IS NULL)))
        AND ((new$RealPayerOrg_Ref = :old.RealPayerOrg_Ref) OR
        ((new$RealPayerOrg_Ref IS NULL) AND (:old.RealPayerOrg_Ref IS NULL)))
        AND ((new$TaxNote = :old.TaxNote) OR
        ((new$TaxNote IS NULL) AND (:old.TaxNote IS NULL)))
        )  THEN
          new$AccountRef := new$AccountRef;

        ELSE

          UPDATE PayDoc32 pd
          SET
          pd.AccountRef = new$AccountRef,
          pd.PayerAttrRef = new$IncAccount,
          pd.AcceptorAttrRef = new$AccountRef,
          pd.TextNote = new$Note,
          pd.TaxNote = new$TaxNote,
          pd.BudgetRef = new$BudgetRef,
          pd.RealPayerOrg_Ref = new$RealPayerOrg_Ref,
          pd.InputDate = CapAcceptDate$,
          pd.SourceDocNumber = CapDocNumber$,
          pd.FACIALACC_CLS = new$FACIALACC_CLS
          WHERE
          (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);

        END IF;
        IF (((new$Debit-:old.Debit)>0.001) OR ((new$Debit-:old.Debit)<-0.001)
        OR ((new$Credit-:old.Credit)>0.001) OR ((new$Credit-:old.Credit)<-0.001))
        THEN
          IF (Divided$ > 0)
          THEN
            /*  ,      */
            RaiseException('EX_CANNOTUPDATEDIVIDEDPAYDOC');
          ELSE
            UPDATE PayDoc32 pd
            SET
            pd.Credit = new$Debit - new$Credit
            WHERE
            (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex);

          END IF;/* if-then*/
        END IF;/* if-else*/
      END IF;
      /*     / */
      /*   :     ,     */
      /*  ,     */
      SELECT MAX(pd.AcceptDate)
      INTO Date_Pd$           FROM PayDoc32 pd
      WHERE (pd.RecordIndex = :old.id) AND (pd.ProgIndex = :old.ProgIndex)
      ;
      new$Idate := Date_Pd$;
      /* if-then*/
    ELSE
      /*       
                          -
                    . */
      DELETE FROM PayDoc32 pd
      WHERE
      (pd.ProgIndex = new$ProgIndex)
      AND (pd.RecordIndex = new$id);
      /* if-else*/
    END IF;/* if (CapProgIndex=145)or (new.ProgIndex=42) */
  END IF;

-- - - - - - - - - - - - -
-- BU_30 (TR_INCOMES32_BU_30)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  if ((new$DocDate is null) and (new$ProgIndex=45)) then
    BEGIN
      select q.BuildDate
      into
      new$DocDate        from QuotesTitle q
      where q.id = new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if ((new$DocDate is null) and (new$IDATE is not null)) then
    new$DocDate := new$IDATE;
  END IF;
  if ((new$DOCDATE is not null)) then
    new$RecordDate := new$DOCDATE;
  END IF;
  /*         */
  if ((new$IDate is not null) and (new$RejectCls is not null)) then
    RaiseException('EX_DOCNOTACCEPTREJECT');
  END IF;

-- - - - - - - - - - - - -
-- BU_70 (TR_INCOMES32_BU_70)
-- Last update 29.11.2011
-- - - - - - - - - - - - -

   /*     */
   BEGIN
      SELECT ProgIndex, AcceptDate, ReestrNumber
        INTO CapProgIndex, CapAcceptDate, CapReestrNumber
        FROM QuotesTitle qt
       WHERE (qt.ID = new$RecordIndex);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
   END;

   /*   -    () */
   IF (CapProgIndex = 45) THEN
      IF ((CapAcceptDate IS NOT NULL) AND (CapReestrNumber IS NOT NULL)) THEN
         /*        ,
            */
         new$FederalFundsRef := new$ID;
      ELSE
         new$FederalFundsRef := NULL;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_INCOMES32_BU_100)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 42)
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    BEGIN

      select KDValue   into newKD$ from kd where Id=new$kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN
      select KDValue   into oldKD$ from kd where Id=:old.kd
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    BEGIN

      /*     */
      select KD,DocCount,DocType, Org_Ref, AccountIndex, SubKD, RegionCLS, GosNI,
      IncAccount, BudgetRef, MEANSTYPE,FACIALACC_CLS,TransfertCls
      into
      idKD1$,
      val_DocCount1$,
      val_DocType1$,
      val_Org_Ref1$,
      val_AccountIndex1$,
      val_SubKD1$,
      val_RegionCLS1$,
      val_GosNI1$,
      val_IncAccount1$,
      val_BudgetRef1$,
      val_MEANSTYPE1$  ,
      val_FACIALACC_CLS1$,
      val_TransfertCls1$         from incomes32 where id=new$RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
    if (not idKD1$ is null) then
      if(((newKD$ like unkKD$)or(newKD$ like unkVKD$))and
      (not(oldKD$ like unkKD$))and(not(oldKD$ like unkVKD$)))then
        /*   ,    */
        delete
        from Incomes32
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      (new$Debit<>0))
      /*       */
      then
        RaiseException('ex_UnknownRedirect');
      END IF;
      if((not(newKD$ like unkKD$))and(not(newKD$ like unkVKD$))and
      ((oldKD$ like unkKD$)or(oldKD$ like unkVKD$)))then
        /*   ,   ,   */
        insert into
        Incomes32( CreaterUser, DocNum, DocCount, iDate, DOCDATE, Debit, Credit, DocType,
        Org_Ref, AccountIndex, KD, SubKD, RegionCLS, GosNI, ProgIndex,
        RecordIndex, IncAccount, BudgetRef, Note, MEANSTYPE, FACIALACC_CLS,TransfertCls)
        Values( new$CreaterUser, new$DocNum,val_DocCount1$, new$iDATE, new$DOCDATE, 0, -new$Credit,
        val_DocType1$, val_Org_Ref1$, val_AccountIndex1$, idKD1$, val_SubKD1$,
        val_RegionCLS1$, val_GosNI1$, 43, new$Id, val_IncAccount1$, val_BudgetRef1$,
        new$Note, val_MEANSTYPE1$, val_FACIALACC_CLS1$, val_TransfertCls1$);
      END IF;
      if((not(newKD$ like unkKD$))and(not(oldKD$ like unkKD$))
      and(not(newKD$ like unkVKD$))and(not(oldKD$ like unkVKD$)))then
        /*      ,   */
        update Incomes32
        set
        DocNum = new$DocNum,
        DocCount = val_DocCount1$,
        iDate = new$iDate,
        DOCDATE = new$DOCDATE,
        Debit = 0,
        Credit = -new$Credit,
        DocType = val_DocType1$,
        Org_Ref = val_Org_Ref1$,
        AccountIndex = val_AccountIndex1$,
        KD = idKD1$,
        SubKD = val_SubKD1$,
        RegionCLS = val_RegionCLS1$,
        GosNI = val_GosNI1$,
        ProgIndex = 43,
        RecordIndex = new$Id,
        IncAccount = val_IncAccount1$,
        BudgetRef = val_BudgetRef1$,
        Note = new$Note,
        MEANSTYPE = val_MEANSTYPE1$,
        FACIALACC_CLS = val_FACIALACC_CLS1$,
        TransfertCls = val_TransfertCls1$,
        RVersion = -1
        where
        (ProgIndex=43)and
        (RecordIndex=:old.id);

      END IF;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_105 (TR_INCOMES32_BU_105)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  if (new$ProgIndex = 41)    /*   () */
  then
    /*    */
    GetVarCharConst(3,0,unkKD$);
    /*     */
    GetVarCharConst(3,11,unkVKD$);
    /*       */
    FOR REC$1 IN (SELECT inc.id
     AS val_ID42    FROM Incomes32 inc
    LEFT OUTER JOIN KD ON (kd.id =  inc.kd)
    WHERE (inc.ProgIndex =  42) and
    (inc.RecordIndex =  new$id) and
    (inc.debit = 0) and
    (not(kd.kdvalue like unkKD$)) and
    (not(kd.kdvalue like unkVKD$))
    )
    LOOP
      BEGIN
        /*       */
        select inc.id
        into val_ID431$         FROM Incomes32 inc
        WHERE (inc.ProgIndex =  43) and
        (inc.RecordIndex =  REC$1.val_ID42)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      /*     ,   Credit, ProgIndex, RecordIndex */
      update Incomes32
      set
      DocNum = new$DocNum,
      DocCount = new$DocCount,
      DOCDATE = new$DOCDATE,
      Debit = 0,
      DocType = new$DocType,
      Org_Ref = new$Org_Ref,
      AccountIndex = new$AccountIndex,
      KD = new$Kd,
      SubKD = new$SubKD,
      RegionCLS = new$RegionCLS,
      GosNI = new$GosNI,
      IncAccount = new$IncAccount,
      BudgetRef = new$BudgetRef,
      Note = new$Note,
      MEANSTYPE = new$MEANSTYPE,
      FACIALACC_CLS = new$FACIALACC_CLS,
      FACT = new$FACT,
      TransfertCls = new$TransfertCls,
      DirectionCls = new$DirectionCls,
      rversion = -1
      where id = val_ID431$;


    END LOOP;
  END IF;

-- - - - - - - - - - - - -
-- BU_110 (TR_INCOMES32_BU_110)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF ((new$ClsType IS NULL) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      new$ClsType := 1;       --       ClsType
   ELSIF (new$ClsType IS NULL) THEN
      new$ClsType := 2;                                --  - 
   END IF;

   IF ((new$ClsType = 1) AND (new$KD <> 0)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType = 2) AND (new$IFS <> 0) AND (new$ProgIndex <> 44)) THEN
      --  
      RaiseEXCEPTION ('EX_WRONGBUDCLS');
   END IF;

   IF ((new$ClsType <> 1) AND (new$ClsType <> 2)) THEN
      --   
      RaiseEXCEPTION ('EX_WRONGBUDCLSTYPE');
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (TR_INCOMES32_BU_300)
-- Create 24.06.2010
-- Last update 24.06.2010
-- - - - - - - - - - - - -

  IsReject$ := -1;
  if ((:old.RejectCLS is null)and(:new.RejectCLS is not null)) then
    IsReject$ := 1;
  elsif ((:old.RejectCLS is not null)and(:new.RejectCLS is null)) then
    IsReject$ := 0;
  end if;
  if (IsReject$ <> -1) then
    update LinkRecords set
      IsRejected = IsReject$
    where
      (ChildID = :new.ID)
      or(ChildID in (select d.id from incomes32 d where d.RecordIndex = :new.id));
  end if;

-- - - - - - - - - - - - -
-- BU_700 (TR_INCOMES32_BU_700)
-- Last update 23.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSIF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
      new$RVersion := :OLD.RVersion;
   ELSE
      new$RVersion := :OLD.RVersion + 1;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INCOMES32 SET
    ID = new$ID,
    DOCNUMBER = new$DOCNUMBER,
    DOCCOUNT = new$DOCCOUNT,
    IDATE = new$IDATE,
    DEBIT = new$DEBIT,
    CREDIT = new$CREDIT,
    DOCTYPE = new$DOCTYPE,
    INN = new$INN,
    ORG_REF = new$ORG_REF,
    ACCOUNTINDEX = new$ACCOUNTINDEX,
    KD = new$KD,
    SUBKD = new$SUBKD,
    REGIONCLS = new$REGIONCLS,
    GOSNI = new$GOSNI,
    INCACCOUNT = new$INCACCOUNT,
    PROGINDEX = new$PROGINDEX,
    RECORDINDEX = new$RECORDINDEX,
    BUDGETREF = new$BUDGETREF,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    NOTE = new$NOTE,
    RECORDINDEX2 = new$RECORDINDEX2,
    ELNUM = new$ELNUM,
    NOTEEX = new$NOTEEX,
    BUHPAYMENTCLS = new$BUHPAYMENTCLS,
    ACCOUNTREF = new$ACCOUNTREF,
    ELPACKETNUM = new$ELPACKETNUM,
    FACIALACC_CLS = new$FACIALACC_CLS,
    NDS = new$NDS,
    MEANSTYPE = new$MEANSTYPE,
    RECORDDATE = new$RECORDDATE,
    TOTALREF = new$TOTALREF,
    REQUESTSINDEX = new$REQUESTSINDEX,
    KVSR = new$KVSR,
    TAXNOTE = new$TAXNOTE,
    DOCNUM = new$DOCNUM,
    REALPAYERORG_REF = new$REALPAYERORG_REF,
    DOCDATE = new$DOCDATE,
    DOCBASE = new$DOCBASE,
    FACT = new$FACT,
    RVERSION = new$RVERSION,
    KFSR = new$KFSR,
    KESR = new$KESR,
    KVR = new$KVR,
    KCSR = new$KCSR,
    SUMCOMPLETE = new$SUMCOMPLETE,
    ELDOCREF = new$ELDOCREF,
    REQUESTSINDEX2 = new$REQUESTSINDEX2,
    FEDERALFUNDSREF = new$FEDERALFUNDSREF,
    BUHOPERATIONCLS = new$BUHOPERATIONCLS,
    IFS = new$IFS,
    IFS_CORR = new$IFS_CORR,
    CLSTYPE = new$CLSTYPE,
    NDSNOTE = new$NDSNOTE,
    DOGNUM = new$DOGNUM,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    OKATO = new$OKATO,
    ADDOKATO = new$ADDOKATO,
    REJECTCLS = new$REJECTCLS,
    FUNDSSOURCE = new$FUNDSSOURCE,
    DIRECTIONCLS = new$DIRECTIONCLS,
    ISBLOCKED = new$ISBLOCKED,
    BLOCKEDCAUSE = new$BLOCKEDCAUSE,
    UNBLOCKEDDATE = new$UNBLOCKEDDATE,
    UNBLOCKEDCAUSE = new$UNBLOCKEDCAUSE,
    STIMATEID = new$STIMATEID,
    TRANSFERTCLS = new$TRANSFERTCLS,
    SUBSIDYCLS = new$SUBSIDYCLS,
    FAORGTYPE = new$FAORGTYPE,
    OKTMO = new$OKTMO,
    UINCODE = new$UINCODE,
    FINTYPE = new$FINTYPE,
    INVESTOBJECT = new$INVESTOBJECT,
    CONTRACTCOSTSCLS = new$CONTRACTCOSTSCLS,
    TARGETCLS = new$TARGETCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    STOREDCONTENT = new$STOREDCONTENT
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion OR RVersion IS NULL AND :OLD.RVersion IS NULL);

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INCOMES32_AU_500)
-- Create 15.09.2005
-- - - - - - - - - - - - -

   IF (NEW$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes(TableID, RecordId, DeleteDate)
        VALUES (161, :OLD.ID, SYSDATE);
      DELETE FROM DelRecIndexes
        WHERE (TableID = 161) AND (RecordId = NEW$ID);
   END IF;

END;
/
COMMIT WORK
/


-- #########################################################
-- #########################################################
-- ADD_IFS_WritExecutionDetail.sql
-- #########################################################
-- #########################################################

/*       */
ALTER TABLE WRITEXECUTIONDETAIL ADD (
  IFS NUMBER(10),
    CHECK((IFS<=2147483647)AND(IFS>-2147483648))
)
/
ALTER TABLE WRITEXECUTIONDETAIL ADD (
  constraint FK_WED_IFS
  foreign key (IFS)
  references TB_INNERFINSOURCE(ID)
)
/
CREATE INDEX FK_WED_IFS ON WRITEXECUTIONDETAIL(IFS)
/
UPDATE WRITEXECUTIONDETAIL
SET IFS = 0
/
-- CREATE TRIGGER tr_writexecutiondetail_bi_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BI
  BEFORE INSERT
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  Promise_Count$ NUMBER(10);
  ConstCheck$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_WRITEXECUTIONDETAIL_BI)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;
  if (:new.BudgetRef is null) then
    BEGIN
      select
      writ_c.BudgetRef
      into :new.BudgetRef     from
      WritExecutionCaption writ_c
      where
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

  if (:new.Progindex is null) then
    :new.Progindex := 556;
  END IF;
  if (:new.FacialAcc_Cls is null) then
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then
    :new.SubKesr := 0;
  END IF;

  if (:new.Month01 IS NULL) then
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then
    :new.Month12 := 0;
  END IF;

  if (:new.Quarter1 IS NULL) then
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then
    :new.Quarter4 := 0;
  END IF;

  if (:new.WritExecutionSumma is Null) then
    :new.WritExecutionSumma := 0;
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef$ <> 0) then
    :new.PScheduleRef := ScheduleRef$;

  else
    :new.PScheduleRef := null;
  END IF;
  /*    */
  GETTARGETCLS(null, :new.transfertcls, null, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BI_110 (TR_WritExecutionDetail_BI_110)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
  if (:new.IFS is NULL) then 
    :new.IFS := 0;
  END IF;
    
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else 
      if (:new.IFS <> 0) then
        :new.ClsType := 1;
            
      else
        :new.ClsType := 0;    
      END IF;  
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.KD <> 0) or (:new.ifs <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_WRITEXECUTIONDETAIL_BI_200)
-- Version 7.00.02.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode$);
  getintconst(30, 35,ConstCheck$);
  /* ( )      ,    */
  if ((PromiseMode$ <> 1) and (ConstCheck$ = 1)) then
    if (:new.Promise is not null) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode$ = 1) then
    if ((:new.Promise is not null) and (:new.BudgetPromise is null)) then
      select
      max(InnerPromiseNum)
      into BPInnerNum$       from
      PaymentSchedule
      where
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum$ <> 0) then
        :new.BudgetPromise := BPInnerNum$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;
    /*    ,   ,   */
    if ((:new.BudgetPromise is not null) and (:new.Promise is null)) then
      BEGIN
        select
        ANumber
        into BPInnerNum$       from
        PaymentSchedule
        where
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      :new.Promise := BPInnerNum$;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_210 (TR_WRITEXECUTIONDETAIL_BI_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode1$);
  if (PromiseMode1$ = 1) then
    /*        */
    if (:new.Promise is not null) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_WRITEXECUTIONDETAIL_BI_500)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- CREATE TRIGGER tr_writexecutiondetail_bu_110
CREATE OR REPLACE TRIGGER TR_WRITEXECUTIONDETAIL_BU
  BEFORE UPDATE
  ON WRITEXECUTIONDETAIL
  FOR EACH ROW
DECLARE
  BPInnerNum1$ NUMBER(10);
  PromiseMode1$ NUMBER(10);
  Promise_Count1$ NUMBER(10);
  ConstCheck1$ NUMBER(10);
  PromiseMode$ NUMBER(10);
  ProgIndex$ NUMBER(10);
  ExecID$ NUMBER(10);
  ExecInnerNumber$ NUMBER(10);
  AgrInnerNumber$ NUMBER(10);
  ScheduleRef$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_WRITEXECUTIONDETAIL_BU)
-- Version 12.00.00.1
-- - - - - - - - - - - - -

  if (:new.BudgetRef is null) then
    BEGIN
      select
      writ_c.BudgetRef
      into :new.BudgetRef     from
      WritExecutionCaption writ_c
      where
      writ_c.id = :new.RecordIndex
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (:new.Progindex is null) then
    :new.Progindex := 556;
  END IF;
  if (:new.FacialAcc_Cls is null) then
    :new.FacialAcc_Cls := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.KFSR is null) then
    :new.KFSR := 0;
  END IF;
  if (:new.KESR is null) then
    :new.KESR := 0;
  END IF;
  if (:new.KVR is null) then
    :new.KVR := 0;
  END IF;
  if (:new.KCSR is null) then
    :new.KCSR := 0;
  END IF;
  if (:new.MeansType is null) then
    :new.MeansType := 0;
  END IF;
  if (:new.Fact is null) then
    :new.Fact := 0;
  END IF;
  if (:new.DirectionCls is null) then
    :new.DirectionCls := 0;
  END IF;
  if (:new.RegionCLS is null) then
    :new.RegionCLS := 0;
  END IF;
  if (:new.Finsource is null) then
    :new.Finsource := 0;
  END IF;
  if (:new.FinType is null) then
    :new.FinType := 0;
  END IF;
  if (:new.DocType is null) then
    :new.DocType := 0;
  END IF;
  if (:new.SubKesr is null) then
    :new.SubKesr := 0;
  END IF;

  if (:new.Month01 IS NULL) then
    :new.Month01 := 0;
  END IF;
  if (:new.Month02 IS NULL) then
    :new.Month02 := 0;
  END IF;
  if (:new.Month03 IS NULL) then
    :new.Month03 := 0;
  END IF;
  if (:new.Month04 IS NULL) then
    :new.Month04 := 0;
  END IF;
  if (:new.Month05 IS NULL) then
    :new.Month05 := 0;
  END IF;
  if (:new.Month06 IS NULL) then
    :new.Month06 := 0;
  END IF;
  if (:new.Month07 IS NULL) then
    :new.Month07 := 0;
  END IF;
  if (:new.Month08 IS NULL) then
    :new.Month08 := 0;
  END IF;
  if (:new.Month09 IS NULL) then
    :new.Month09 := 0;
  END IF;
  if (:new.Month10 IS NULL) then
    :new.Month10 := 0;
  END IF;
  if (:new.Month11 IS NULL) then
    :new.Month11 := 0;
  END IF;
  if (:new.Month12 IS NULL) then
    :new.Month12 := 0;
  END IF;

  if (:new.Quarter1 IS NULL) then
    :new.Quarter1 := 0;
  END IF;
  if (:new.Quarter2 IS NULL) then
    :new.Quarter2 := 0;
  END IF;
  if (:new.Quarter3 IS NULL) then
    :new.Quarter3 := 0;
  END IF;
  if (:new.Quarter4 IS NULL) then
    :new.Quarter4 := 0;
  END IF;

  if (:new.WritExecutionSumma is Null) then
    :new.WritExecutionSumma := 0;
  END IF;
  if ((not :new.PROMISE is null) and (not :new.BUDGETPROMISE is null)) then
    BEGIN
      select ps.id     into ScheduleRef$ from PaymentSchedule ps
      where (ps.InnerPromiseNum = :new.BUDGETPROMISE) and
      (ps.ANumber = :new.PROMISE)
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (ScheduleRef$ <> 0) then
    :new.PScheduleRef := ScheduleRef$;

  else
    :new.PScheduleRef := null;
  END IF;
  /*    */
  GETTARGETCLS(:old.transfertcls, :new.transfertcls, :old.meanstype, :new.meanstype,
  :new.targetcls,:new.targetcls);

-- - - - - - - - - - - - -
-- BU_110 (TR_WritExecutionDetail_BU_110)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  if (:new.KD is NULL) then 
    :new.KD := 0;
  END IF;
  if (:new.IFS is NULL) then 
    :new.IFS := 0;
  END IF;
  if (:new.ClsType is NULL) then
    if (:new.KD <> 0) then
      :new.ClsType := 2; /*       ClsType */
          
    else 
      if (:new.IFS <> 0) then
        :new.ClsType := 1;
            
      else
        :new.ClsType := 0;    
      END IF;  
    END IF;
  END IF;
  IF ((:new.ClsType = 0) AND ((:new.KD <> 0) or (:new.ifs <> 0))) THEN  /*   */
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (
  (:new.KVSR <> 0) OR (:new.KFSR <> 0) OR
  (:new.KCSR <> 0) OR (:new.KVR <> 0)
  )) THEN
    RaiseException('EX_WRONGBUDCLS');
  END IF;
  IF ((:new.ClsType <> 0) AND (:new.ClsType <> 2) AND (:new.ClsType <> 1)) THEN /*   */
    RaiseException('EX_WRONGBUDCLSTYPE');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_WRITEXECUTIONDETAIL_BU_200)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*       */
  GetIntConst(30, 15,PromiseMode1$);
  getintconst(30, 35,ConstCheck1$);
  /* ( )      ,    */
  if ((PromiseMode1$ <> 1) and (ConstCheck1$ = 1)) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise ))) then
      select
      count(pr.REGISTRNUMBER)
      into
      Promise_Count1$        from
      promise_detail pr
      where
      (pr.registrnumber = :new.PROMISE)
      ;
      /*    ,  */
      if (Promise_Count1$ = 0) then
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;/* end  PromiseMode <> 1*/
  END IF;
  /* ( )      ,    */
  /*         */
  if (PromiseMode1$ = 1) then
    if ((:new.Promise is not null)and((:old.Promise is null)or(:old.Promise <> :new.Promise )) and
    (:new.BudgetPromise is null) and (:old.BudgetPromise is null)) then
      select
      max(InnerPromiseNum)
      into BPInnerNum1$       from
      PaymentSchedule
      where
      (ANumber = :new.Promise) and (AcceptDate is not null) and (Accepted = 1)
      ;
      if (BPInnerNum1$ <> 0) then
        :new.BudgetPromise := BPInnerNum1$;

      else
        RaiseException('EX_BP_NotExist');
      END IF;
    END IF;

    /*         NULL,    */
    if (:new.Promise is null and ((:new.BudgetPromise is not null and :old.BudgetPromise is null) or
    (:new.BudgetPromise <> :old.BudgetPromise))) then
      BEGIN
        select
        ANumber
        into BPInnerNum1$       from
        PaymentSchedule
        where
        (InnerPromiseNum = :new.BudgetPromise) and (LastAccepted = 1)
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;

      :new.Promise := BPInnerNum1$;

    END IF;

    /*    ,     */
    if ((:new.BudgetPromise is null) and (:old.BudgetPromise is not null)) then
      :new.Promise := null;

    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_210 (TR_WRITEXECUTIONDETAIL_BU_210)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*    ?*/
  GetIntConst(30, 15,PromiseMode$);
  if (PromiseMode$ = 1) then
    /*        */
    if (:new.Promise is not null and (
    (:old.Promise is null or :old.Promise <> :new.Promise) or
    (:old.ExecDoc is null or :new.ExecDoc is null or :old.ExecDoc <> :new.ExecDoc)
    )) then
      BEGIN
        /* ,       ,    */
        select
        ps.ProgIndex, ps.ExecutionRef, edc.InnerNumber, a.InnerNumber
        into ProgIndex$, ExecID$, ExecInnerNumber$, AgrInnerNumber$       from PaymentSchedule ps
        left join ExecutionDocumentsCaption edc on edc.ID = ps.ExecutionRef
        left join Agreements a on a.Id = ps.AgreementRef
        where
        ps.ANumber = :new.Promise and ps.InnerPromiseNum = :new.BudgetPromise
        ;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN NULL;
      END;
    END IF;/*   " "*/
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_WRITEXECUTIONDETAIL_BU_700)
-- Create 02.04.2010
-- Last update 02.04.2010
-- - - - - - - - - - - - -

  if (:new.RVersion is null) then
    :new.RVersion := 1;
  elsif ((:new.RVersion = -1) and (:old.RVersion <> -1)) then
    :new.RVersion := :old.RVersion;
  else
    :new.RVersion := :old.RVersion + 1;
  end if;

END;
/
COMMIT WORK
/
ALTER TABLE WRITEXECUTIONDETAIL MODIFY(IFS NOT NULL)
/

-- #########################################################
-- #########################################################
-- alter_triggers transfertcls.sql
-- #########################################################
-- #########################################################

/*     "  ".  Oracle      EXTID 
      . */
-- CREATE TRIGGER tr_transfertcls_bi_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_II
  INSTEAD OF INSERT
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_TRANSFERTCLS_BI)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  select g_shared.nextval into new$ID from dual;

  if (new$BUDGETREF is null) then
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */

  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;

  END IF;

-- - - - - - - - - - - - -
-- BI_200 (TR_TRANSFERTCLS_BI_200)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_TRANSFERTCLS_BI_500)
-- Create 24.09.2007
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_TRANSFERTCLS (
    ID,
    REGIONCLS,
    CREATERUSER,
    CREATEDATE,
    UPDATERUSER,
    UPDATEDATE,
    CODE,
    RECEIVEKVSR,
    RECEIVEKFSR,
    RECEIVEKVR,
    RECEIVEKESR,
    RECEIVEKD,
    TRANSFERKVSR,
    TRANSFERKFSR,
    TRANSFERKCSR,
    TRANSFERKVR,
    TRANSFERKESR,
    TRANSFERKDVALUE,
    TARGETMEANSSIGN,
    TARGETCLS,
    STARTDATE,
    DELETEDATE,
    NOTE,
    NAME,
    BUDGETREF,
    RECEIVEKCSR,
    SOURCELEVEL,
    DESTLEVEL,
    TRANSFERTKIND,
    GRANTKIND,
    TRANSFERTYEAR,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    FACT,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE
  ) VALUES (
    new$ID,
    new$REGIONCLS,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATERUSER,
    new$UPDATEDATE,
    new$CODE,
    new$RECEIVEKVSR,
    new$RECEIVEKFSR,
    new$RECEIVEKVR,
    new$RECEIVEKESR,
    new$RECEIVEKD,
    new$TRANSFERKVSR,
    new$TRANSFERKFSR,
    new$TRANSFERKCSR,
    new$TRANSFERKVR,
    new$TRANSFERKESR,
    new$TRANSFERKDVALUE,
    new$TARGETMEANSSIGN,
    new$TARGETCLS,
    new$STARTDATE,
    new$DELETEDATE,
    new$NOTE,
    new$NAME,
    new$BUDGETREF,
    new$RECEIVEKCSR,
    new$SOURCELEVEL,
    new$DESTLEVEL,
    new$TRANSFERTKIND,
    new$GRANTKIND,
    new$TRANSFERTYEAR,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$FACT,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE);

-- - - - - - - - - - - - -
-- AI_500 (TR_TRANSFERTCLS_AI_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);

END;
/
-- CREATE TRIGGER tr_transfertcls_bu_200
CREATE OR REPLACE TRIGGER TR_TRANSFERTCLS_IU
  INSTEAD OF UPDATE
  ON TRANSFERTCLS
  FOR EACH ROW
DECLARE
  new$ID TRANSFERTCLS.ID%TYPE := :NEW.ID;
  new$REGIONCLS TRANSFERTCLS.REGIONCLS%TYPE := :NEW.REGIONCLS;
  new$CREATERUSER TRANSFERTCLS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE TRANSFERTCLS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATERUSER TRANSFERTCLS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$UPDATEDATE TRANSFERTCLS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CODE TRANSFERTCLS.CODE%TYPE := :NEW.CODE;
  new$RECEIVEKVSR TRANSFERTCLS.RECEIVEKVSR%TYPE := :NEW.RECEIVEKVSR;
  new$RECEIVEKFSR TRANSFERTCLS.RECEIVEKFSR%TYPE := :NEW.RECEIVEKFSR;
  new$RECEIVEKVR TRANSFERTCLS.RECEIVEKVR%TYPE := :NEW.RECEIVEKVR;
  new$RECEIVEKESR TRANSFERTCLS.RECEIVEKESR%TYPE := :NEW.RECEIVEKESR;
  new$RECEIVEKD TRANSFERTCLS.RECEIVEKD%TYPE := :NEW.RECEIVEKD;
  new$TRANSFERKVSR TRANSFERTCLS.TRANSFERKVSR%TYPE := :NEW.TRANSFERKVSR;
  new$TRANSFERKFSR TRANSFERTCLS.TRANSFERKFSR%TYPE := :NEW.TRANSFERKFSR;
  new$TRANSFERKCSR TRANSFERTCLS.TRANSFERKCSR%TYPE := :NEW.TRANSFERKCSR;
  new$TRANSFERKVR TRANSFERTCLS.TRANSFERKVR%TYPE := :NEW.TRANSFERKVR;
  new$TRANSFERKESR TRANSFERTCLS.TRANSFERKESR%TYPE := :NEW.TRANSFERKESR;
  new$TRANSFERKDVALUE TRANSFERTCLS.TRANSFERKDVALUE%TYPE := :NEW.TRANSFERKDVALUE;
  new$TARGETMEANSSIGN TRANSFERTCLS.TARGETMEANSSIGN%TYPE := :NEW.TARGETMEANSSIGN;
  new$TARGETCLS TRANSFERTCLS.TARGETCLS%TYPE := :NEW.TARGETCLS;
  new$STARTDATE TRANSFERTCLS.STARTDATE%TYPE := :NEW.STARTDATE;
  new$DELETEDATE TRANSFERTCLS.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NOTE TRANSFERTCLS.NOTE%TYPE := :NEW.NOTE;
  new$NAME TRANSFERTCLS.NAME%TYPE := :NEW.NAME;
  new$BUDGETREF TRANSFERTCLS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$RECEIVEKCSR TRANSFERTCLS.RECEIVEKCSR%TYPE := :NEW.RECEIVEKCSR;
  new$SOURCELEVEL TRANSFERTCLS.SOURCELEVEL%TYPE := :NEW.SOURCELEVEL;
  new$DESTLEVEL TRANSFERTCLS.DESTLEVEL%TYPE := :NEW.DESTLEVEL;
  new$TRANSFERTKIND TRANSFERTCLS.TRANSFERTKIND%TYPE := :NEW.TRANSFERTKIND;
  new$GRANTKIND TRANSFERTCLS.GRANTKIND%TYPE := :NEW.GRANTKIND;
  new$TRANSFERTYEAR TRANSFERTCLS.TRANSFERTYEAR%TYPE := :NEW.TRANSFERTYEAR;
  new$EXTID TRANSFERTCLS.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER TRANSFERTCLS.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE TRANSFERTCLS.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$FACT TRANSFERTCLS.FACT%TYPE := :NEW.FACT;
  new$EXTROOTID TRANSFERTCLS.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION TRANSFERTCLS.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE TRANSFERTCLS.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
--
  CurrentDate$ NUMBER;
  CNT$1 NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_TRANSFERTCLS_BU)
-- Version 10.30.00.1
-- - - - - - - - - - - - -

  if (new$BUDGETREF is null) then
    new$BUDGETREF := 0;
  END IF;
  if (new$RECEIVEKVSR is null) then
    new$RECEIVEKVSR := 0;
  END IF;
  if (new$RECEIVEKCSR is null) then
    new$RECEIVEKCSR := 0;
  END IF;
  if (new$RECEIVEKFSR is null) then
    new$RECEIVEKFSR := 0;
  END IF;
  if (new$RECEIVEKESR is null) then
    new$RECEIVEKESR := 0;
  END IF;
  if (new$RECEIVEKD is null) then
    new$RECEIVEKD := 0;
  END IF;
  if ((new$RECEIVEKVR is null) or (new$RECEIVEKVR  is null)) then
    new$RECEIVEKVR := '000';
  END IF;
  if (new$TRANSFERKVSR is null) then
    new$TRANSFERKVSR := 0;
  END IF;
  if (new$TRANSFERKCSR is null) then
    new$TRANSFERKCSR := 0;
  END IF;
  if (new$TRANSFERKFSR is null) then
    new$TRANSFERKFSR := 0;
  END IF;
  if (new$TRANSFERKVR is null) then
    new$TRANSFERKVR := 0;
  END IF;
  if (new$TRANSFERKESR is null) then
    new$TRANSFERKESR := 0;
  END IF;
  if ((new$TRANSFERKDVALUE is null) or (new$TRANSFERKDVALUE  is null)) then
    new$TRANSFERKDVALUE := '00000000000000000000';
  END IF;
  if (new$TARGETMEANSSIGN is null) then
    new$TARGETMEANSSIGN := 1;
  END IF;
  if (new$REGIONCLS is null) then
    new$REGIONCLS := 0;
  END IF;
  if (new$FACT is null) then
    new$FACT := 0;
  END IF;
  if (new$SourceLevel is null) then
    new$SourceLevel := 0;
  END IF;
  if (new$GrantKind is null) then
    new$GrantKind := 0;
  END IF;
  if (new$GrantKind = 2) then /*   "" */
    new$DestLevel := 1; /*    */

  else
    /*   ""  " "   */
    if ((new$GrantKind = 1) or (new$DestLevel is null)) then
      new$DestLevel := 0; /*   */
    END IF;
  END IF;
  if (new$TransfertKind is null) then
    new$TransfertKind  := 0;
  END IF;
  if (new$TransfertYear is null) then
    CurDateToDouble(CurrentDate$);
    new$TransfertYear := CurrentDate$ / 10000;

  END IF;

-- - - - - - - - - - - - -
-- BU_100 (TR_TRANSFERTCLS_BU_100)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  if ((new$id = 0) and (new$Code <> :old.Code)) then
    RaiseException('EX_CANTMODIFY_ZEROTRANFERTSCLS');
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_TRANSFERTCLS_BU_200)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  SELECT COUNT(*) INTO CNT$1
  from TransfertCls t where
  (        (t.ID <> new$ID) and
  (t.CODE=new$CODE) and
  (t.RECEIVEKVSR=new$RECEIVEKVSR) and
  (t.RECEIVEKFSR=new$RECEIVEKFSR) and
  (t.RECEIVEKCSR=new$RECEIVEKCSR) and
  (t.RECEIVEKVR=new$RECEIVEKVR) and
  (t.RECEIVEKESR=new$RECEIVEKESR) and
  (t.RECEIVEKD=new$RECEIVEKD) and
  (t.TRANSFERKVSR=new$TRANSFERKVSR) and
  (t.TRANSFERKFSR=new$TRANSFERKFSR) and
  (t.TRANSFERKCSR=new$TRANSFERKCSR) and
  (t.TRANSFERKVR=new$TRANSFERKVR) and
  (t.TRANSFERKESR=new$TRANSFERKESR) and
  (t.TRANSFERKDVALUE=new$TRANSFERKDVALUE) and
  (t.TARGETMEANSSIGN=new$TARGETMEANSSIGN) and
  (t.REGIONCLS=new$REGIONCLS) and
  (t.DESTLEVEL=new$DESTLEVEL) and
  (t.BUDGETREF=new$BUDGETREF) and
  ((t.EXTID is null and new$EXTID is null) or (t.EXTID = new$EXTID)) and
  (t.FACT=new$FACT)) AND (ROWNUM = 1);
  if ((CNT$1<> 0)) then
    RaiseException('EX_DUPLICATE_TRANSFERT');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_TRANSFERTCLS SET
    ID = new$ID,
    REGIONCLS = new$REGIONCLS,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    UPDATEDATE = new$UPDATEDATE,
    CODE = new$CODE,
    RECEIVEKVSR = new$RECEIVEKVSR,
    RECEIVEKFSR = new$RECEIVEKFSR,
    RECEIVEKVR = new$RECEIVEKVR,
    RECEIVEKESR = new$RECEIVEKESR,
    RECEIVEKD = new$RECEIVEKD,
    TRANSFERKVSR = new$TRANSFERKVSR,
    TRANSFERKFSR = new$TRANSFERKFSR,
    TRANSFERKCSR = new$TRANSFERKCSR,
    TRANSFERKVR = new$TRANSFERKVR,
    TRANSFERKESR = new$TRANSFERKESR,
    TRANSFERKDVALUE = new$TRANSFERKDVALUE,
    TARGETMEANSSIGN = new$TARGETMEANSSIGN,
    TARGETCLS = new$TARGETCLS,
    STARTDATE = new$STARTDATE,
    DELETEDATE = new$DELETEDATE,
    NOTE = new$NOTE,
    NAME = new$NAME,
    BUDGETREF = new$BUDGETREF,
    RECEIVEKCSR = new$RECEIVEKCSR,
    SOURCELEVEL = new$SOURCELEVEL,
    DESTLEVEL = new$DESTLEVEL,
    TRANSFERTKIND = new$TRANSFERTKIND,
    GRANTKIND = new$GRANTKIND,
    TRANSFERTYEAR = new$TRANSFERTYEAR,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    FACT = new$FACT,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE
  WHERE Id = :old.Id;

-- - - - - - - - - - - - -
-- AU_500 (TR_TRANSFERTCLS_AU_500)
-- Create 04.10.2007
-- - - - - - - - - - - - -

  if (new$Id <> :old.Id) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (203, :Old.Id, SYSDATE);
    delete from DelRecIndexes where (TableID = 203) and (RecordId = new$ID);
  end if;

END;
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_StoredContent_WritExecution.sql
-- #########################################################
-- #########################################################

/*   STOREDCONTENT (  )   */
ALTER TABLE WritExecutionCaption ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
ALTER TABLE WritExecutionDetail ADD (
  STOREDCONTENT VARCHAR2(4000)
)
/
COMMIT WORK
/



-- #########################################################
-- #########################################################
-- alter_oos_contrfin_add_ikz.sql
-- #########################################################
-- #########################################################

/*    IKZ "  "   OOS_CONTRACT_FINANCES.    2017.*/
ALTER TABLE OOS_CONTRACT_FINANCES ADD (
  IKZ VARCHAR2(50)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- UpdateDocFields_URM_5201_Ora.sql
-- #########################################################
-- #########################################################


--  : 120000 - 121000.     10.01.2017 20:10:20.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
            DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
          PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(5201, 555, ' / ', 0, 'WritExecutionCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5201, ' / ', '{623EE404-09D9-4069-9115-27974DB69AD1}', '') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/




CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_          NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
                   FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--  / , (0)
CALL ImportField(520100038, '()', 'LevierInn', '()', 'LevierOrgINN', 0, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520100039, '()', 'LevierInn20', '()', 'LevierOrgKPP', 0, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520100060, '()', 'LevierName', '', 'LevierName', 0, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520100063, ' ( )', 'StoredContent', ' ( )', 'StoredContent', 0, 5201, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(520100035, '', 'LevierParent', '', ' ', 0, 5201, 0, 0, '', 0, null, 0, 0, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- update_ContractCostsCls.sql
-- #########################################################
-- #########################################################

update ContractCostsCls set name = ' ' where id = 100 
/
update ContractCostsCls set name = '  ' where id = 130 
/
update ContractCostsCls set name = ' ' where id = 200 
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_oos_contract_add_ikz.sql
-- #########################################################
-- #########################################################

/*    IKZ "  "   OOS_CONTRACT.      7.0.*/
ALTER TABLE OOS_CONTRACT ADD (
  IKZ VARCHAR2(50)
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- Add_EditionNumber_OOSContract.sql
-- #########################################################
-- #########################################################

/*    EditionNumber ( )
   oos_contract */
ALTER TABLE oos_contract ADD (
  EditionNumber NUMBER(10),
    CHECK((EditionNumber<=2147483647)AND(EditionNumber>-2147483648))
)
/
COMMIT WORK 
/


-- #########################################################
-- #########################################################
-- Alter_OOS_C_F_Add_prices.sql
-- #########################################################
-- #########################################################

/*        "" */
ALTER TABLE OOS_CONTRACT_FINANCES ADD (
  PriceFirst NUMBER(15,2) default 0,
  PriceSecond NUMBER(15,2) default 0,
  PriceSubsec NUMBER(15,2) default 0
)
/
commit work
/

-- #########################################################
-- #########################################################
-- TR_OOS_CascadeDelete.sql
-- #########################################################
-- #########################################################

/*          */
-- CREATE TRIGGER OOS_CONTRACT_BD0
CREATE OR REPLACE TRIGGER TR_OOS_CONTRACT_BD
  BEFORE DELETE
  ON OOS_CONTRACT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (OOS_CONTRACT_BD0)
-- Version 12.10.00.1
-- - - - - - - - - - - - -

  delete from oos_contract_products where oos_contract_products.RECORDINDEX = :old.ID;
  delete from oos_contract_finances where oos_contract_finances.RECORDINDEX = :old.ID;
  delete from oos_contractprocedure where oos_contractprocedure.RegNum = :old.RegNum;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- alter_OOS_CONTRACT_ANUMBER.sql
-- #########################################################
-- #########################################################

/*     ANUMBER  OOS_CONTRACT  100  */
ALTER TABLE OOS_CONTRACT ADD (
  TempANUMBER VARCHAR2(100)
)
/
update OOS_CONTRACT set TempANUMBER = ANUMBER 
/
ALTER TABLE OOS_CONTRACT DROP (ANUMBER)
/
ALTER TABLE OOS_CONTRACT ADD (
  ANUMBER VARCHAR2(100)
)
/
update OOS_CONTRACT set ANUMBER = TempANUMBER 
/
ALTER TABLE OOS_CONTRACT DROP (TempANUMBER)
/
commit work 
/



-- #########################################################
-- #########################################################
-- UpdDocFields_12.10.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 121000 - 121000.     24.01.2017 11:46:24.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(201, 32, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(202, 260, ' ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(203, 261, '  ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(204, 262, ' , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(205, 263, '', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL ImportDocType(206, 268, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(207, 272, '  ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL ImportDocType(208, 273, '   ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(209, 274, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(209, ' ', '{DA309359-EF6B-4D29-AC0D-309040B5CDB6}', '') ;

CALL ImportDocType(210, 252, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(210, ' ', '{2EF0F811-E21F-4ADB-BC7E-A3A9B16059A4}', '') ;

CALL ImportDocType(211, 275, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(211, ' ', '{AE8281A0-BE7F-4F3A-90BD-A7831E8D842F}', '') ;

CALL ImportDocType(212, 276, '  , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(212, '  , ', '{B743C24B-6E28-4C9C-B3CA-16AC6E529D07}', '') ;

CALL ImportDocType(301, 66, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(303, 65, ' ()', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(305, 61, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(308, 67, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(308, ' ', '{B50F2C63-9CF4-42C3-8062-E355EABD53E4}', '') ;

CALL ImportDocType(322, 73, '  ', 0, 'FacialFinCaption', 0,-1,'_',10200,'') ;

CALL ImportDocType(323, 75, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1807, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1807, '  ', '{DCD3A201-01A8-11D5-9238-4854E826BF13}', '') ;

CALL ImportDocType(1818, 0, '    ', 0, 'OOS_CONTRACT', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1818, '    ', '{BA8DC899-AE20-4BDB-9B15-278A56CB01C5}', '') ;

CALL ImportDocType(2503, 308, '  ', 0, 'ExecutionDocumentsCaption', 0,-65537,'',10100,'') ;

CALL ImportDocType(4401, 251, ' ', 0, 'UnionNotifyCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(4401, ' ', '{AB6937F7-A672-461D-A94C-808F4DCA4D71}', '') ;

CALL ImportDocType(5101, 0, '  ', 0, 'StoredAttributesCaption', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(5101, '  ', '{12614FA4-D546-4C45-8946-43813CED6EBF}', '') ;

CALL ImportDocType(5201, 555, ' / ', 0, 'WritExecutionCaption', 0,-1,'',10100,'') ;

CALL UpdateInterfaces(5201, ' / ', '{623EE404-09D9-4069-9115-27974DB69AD1}', '') ;

CALL ImportDocType(5501, 312, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5502, 313, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(9898, 0, ' ', 0, 'PURCHASETYPE ', 0,0,'',20100,'') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL SELECTIONS_IMPORT(40457, 1, 'ONTRACTOSTSCLS', '', 0, 0, 'ONTRACTOSTSCLS', 'CCC', 0, 0, 0, 2, '', 1, 0, 1800, null, 5, '', '', null, 0) ;

CALL SELECTIONS_IMPORT(40480, 1, 'PURCHASETYPE', ' ', 0, 0, 'PURCHASETYPE', 'PURCHASETYPE', 0, 0, 0, 2, '', 1, 0, 1800, null, 5, '', '', null, 0) ;

-- ONTRACTOSTSCLS
CALL FIELDSINFO_IMPORT(40458, 0, 1, null, 40457, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40459, 0, 1, null, 40457, null, 'CODE', 1, 0, 20, '', '', 0, '999', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40460, 0, 1, null, 40457, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40461, 0, 1, null, 40457, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40462, 0, 1, null, 40457, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40463, 0, 1, null, 40457, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40464, 0, 1, null, 40457, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40465, 0, 1, null, 40457, null, 'DELETEDATE', 11, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40466, 0, 1, null, 40457, null, 'STARTDATE', 11, 0, 0, '   ', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40467, 0, 1, null, 40457, null, 'NOTE', 1, 0, 255, '', '', 0, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40468, 0, 1, null, 40457, null, 'BUDGETREF', 3, 0, 0, ' ', '', 11, '', '', '', 0, 0, null, 1, 16803, 0, 0, 0, '', 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40471, 0, 1, null, 40457, null, 'PURCHASETYPE ', 3, 0, 0, ' ', '', 20, '', '', '', 0, 0, null, 0, 40480, 0, 0, 0, '', 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- PURCHASETYPE
CALL FIELDSINFO_IMPORT(40481, 0, 1, null, 40480, null, 'ID', 3, 0, 0, ' ', '', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40482, 0, 1, null, 40480, null, 'CREATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40483, 0, 1, null, 40480, null, 'UPDATEDATE', 11, 0, 0, ' ', '', 20, '99/99/9999', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40484, 0, 1, null, 40480, null, 'CREATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40485, 0, 1, null, 40480, null, 'UPDATERUSER', 1, 0, 30, '', '', 30, '', '', '', 1, 0, null, 1, null, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(40486, 0, 1, null, 40480, null, 'NAME', 1, 0, 1024, '', '', 60, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 0) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 314) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(993000, 9930, '', 'AUTOSANCTIONDATA', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301000, 3010, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 242) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

CALL ImportDocCLS(181800, 1818, '', 'OOS_CONTRACT', 'OOS_CONTRACT', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(301100, 3011, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 243) ;

CALL ImportDocCLS(301101, 3011, ' ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 243) ;

CALL ImportDocCLS(300500, 3005, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 240) ;

CALL ImportDocCLS(181801, 1818, '', 'OOS_CONTRACT_FINANCES', 'OOS_CONTRACT_FINANCES', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181802, 1818, '', 'OOS_CONTRACT_PRODUCTS', 'OOS_CONTRACT_PRODUCTS', 'ID', 'ID', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(181803, 1818, '', 'OOS_CONTRACTPROCEDURE', 'OOS_CONTRACTPROCEDURE', 'ID', 'ID', 'RegNum', 'RegNum', 0, null, null, null) ;

CALL ImportDocCLS(989700, 9897, ' ', 'ontractostsCls', 'ontractostsCls', 'id', 'id', '', '', 97, null, null, null) ;

CALL ImportDocCLS(989800, 9898, ' ', 'PURCHASETYPE ', 'PURCHASETYPE ', 'id', 'id', '', '', 98, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER,
   ATTRIBUTENAME_     VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			       FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_,
             ATTRIBUTENAME = ATTRIBUTENAME_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )
                  AND (
                          (
                           (ATTRIBUTENAME_ IS NOT NULL AND ATTRIBUTENAME IS NOT NULL) AND
                           (UPPER (ATTRIBUTENAME_) = UPPER (ATTRIBUTENAME))
                          )
                       OR (ATTRIBUTENAME_ IS NULL AND ATTRIBUTENAME IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND, ATTRIBUTENAME
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_, ATTRIBUTENAME_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(520110038) ;

--    (), (1)
CALL ImportField(20110083, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 201, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20111194, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20111195, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 201, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20111198, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 201, 1, 0, '', 0, null, 0, 2, '') ;

--  (), (1)
CALL ImportField(20210091, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 202, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20211111, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 202, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20211112, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 202, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20211115, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 202, 1, 0, '', 0, null, 0, 2, '') ;

--   (), (1)
CALL ImportField(20310082, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 203, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20311101, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 203, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20311102, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 203, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20311103, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 203, 1, 0, '', 0, null, 0, 2, '') ;

--  , , (1)
CALL ImportField(20410087, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 204, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20411120, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 204, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20411121, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 204, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20411124, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 204, 1, 0, '', 0, null, 0, 2, '') ;

-- , (1)
CALL ImportField(20510090, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 205, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20511107, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 205, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20511108, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 205, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20511111, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 205, 1, 0, '', 0, null, 0, 2, '') ;

--    (), (1)
CALL ImportField(20610090, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 206, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20611188, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 206, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20611189, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 206, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20611190, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 206, 1, 0, '', 0, null, 0, 2, '') ;

--   , (1)
CALL ImportField(20710161, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 207, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20711188, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 207, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20711189, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 207, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20711190, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 207, 1, 0, '', 0, null, 0, 2, '') ;

--    , (1)
CALL ImportField(20810161, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 208, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20811189, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 208, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(20811190, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 208, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(20811191, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 208, 1, 0, '', 0, null, 0, 2, '') ;

--  , (1)
CALL ImportField(20910028, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 209, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(20911145, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 209, 1, 0, '', 0, null, 0, 2, '') ;

--  , (1)
CALL ImportField(21010028, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 210, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21011049, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 210, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21012061, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 210, 2, 0, '', 0, null, 0, 2, '') ;

--  , (1)
CALL ImportField(21110028, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 211, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21111049, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 211, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21111050, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 211, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21112048, '', 'ContractCostsCls', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112049, '', 'ContractCostsClsCode', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21112050, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 211, 2, 0, '', 0, null, 0, 2, '') ;

--   , , (1)
CALL ImportField(21210028, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 212, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21211050, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 212, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21211051, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 212, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(21212049, '', 'ContractCostsCls', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212050, '', 'ContractCostsClsCode', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(21212051, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 212, 2, 0, '', 0, null, 0, 2, '') ;

--   \, (1)
CALL ImportField(30210163, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 302, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30211156, '', 'SourceInvestObject', '', 'SourceInvestObjectKey', 1, 302, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30211157, '', 'SourceInvestObjectCode', '', 'SourceInvestObject', 1, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211158, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 302, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30211194, '', 'SourceContractCostsClsCode', '', 'SourceContractCostsCls', 1, 302, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30211195, '', 'SourceContractCostsCls', '', 'SourceContractCostsClsKey', 1, 302, 1, 1, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(30410147, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 304, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(30410148, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 304, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(30410149, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 304, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(30410150, '  ', 'StoredPaymentProps', '', ' ', 1, 304, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30410151, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 304, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30411147, '', 'SourceContractCostsClsCode', '', 'SourceContractCostsCls', 1, 304, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30411148, '', 'SourceContractCostsCls', '', 'SourceContractCostsClsKey', 1, 304, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30411149, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 304, 1, 0, '', 0, null, 0, 2, '') ;

--   \, (1)
CALL ImportField(30510173, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 305, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30511148, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 305, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30511149, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 305, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30511150, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 305, 1, 0, '', 0, null, 0, 2, '') ;

--   , (1)
CALL ImportField(30611150, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 306, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30611151, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 306, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(30710014, ' ', 'CryptoStatus', '   ', 'CryptoStatus', 1, 307, 0, 1, '', 0, 19109, 0, 0, '') ;

--  , (1)
CALL ImportField(30810071, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 308, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(30810072, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 308, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(30810073, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 308, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(30810074, '  ', 'StoredPaymentProps', '', ' ', 1, 308, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30810075, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 308, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(30811115, ' ', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 308, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30811116, ' ', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 308, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30811117, ' ', 'SourceContractCostsCls', '', 'SourceContractCostsClsKey', 1, 308, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811118, ' ', 'SourceContractCostsClsCode', '', 'SourceContractCostsCls', 1, 308, 1, 0, ',', 0, null, 0, 0, '') ;

CALL ImportField(30811119, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 308, 1, 0, '', 0, null, 0, 2, '') ;

--    , (1)
CALL ImportField(31111109, '', 'SourceContractCostsCls', '', 'SourceContractCostsClsKey', 1, 311, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31111110, '', 'SourceContractCostsClsCode', '', 'SourceContractCostsCls', 1, 311, 1, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(31211144, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 312, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(31211145, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 312, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(31411144, '', 'SourceContractCostsClsCode', '', 'SourceContractCostsCls', 1, 314, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31411145, '', 'SourceContractCostsCls', '', 'SourceContractCostsClsKey', 1, 314, 1, 1, '', 0, null, 0, 0, '') ;

--      , (1)
CALL ImportField(31511100, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 315, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(31511101, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 315, 1, 1, '', 0, null, 0, 0, '') ;

--   , (1)
CALL ImportField(32210078, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 322, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(32210079, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 322, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(32210080, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 322, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(32210081, '  ', 'StoredPaymentProps', '', ' ', 1, 322, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32210082, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 322, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(32211094, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 322, 1, 0, '', 0, null, 0, 2, '') ;

--  , (1)
CALL ImportField(32310140, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 323, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(32310141, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 323, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(32310142, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 323, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(32310143, '  ', 'StoredPaymentProps', '', ' ', 1, 323, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32310144, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 323, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(32311165, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 323, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32311166, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 323, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32311167, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 323, 1, 0, '', 0, null, 0, 2, '') ;

--  , (1)
CALL ImportField(32410177, '(  )', 'DestStoredPaymentProps', '', 'DestStoredPaymentProps', 1, 324, 0, 0, '', 0, 31657, 0, 2, '') ;

CALL ImportField(32410178, '(  )', 'SourceStoredPaymentProps', '', 'SourceStoredPaymentProps', 1, 324, 0, 0, '', 0, 31658, 0, 2, '') ;

CALL ImportField(32410179, ' (  )', 'StoredPaymentNote', '', 'StoredPaymentNote', 1, 324, 0, 0, '', 0, 31659, 0, 2, '') ;

CALL ImportField(32410180, '  ', 'StoredPaymentProps', '', ' ', 1, 324, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32410181, '.  ', 'StoredPaymentContent', '.  ', 'StoredPaymentContent', 1, 324, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(32411205, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 324, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(32411206, '', 'DestContractCostsClsCode', '', 'DestContractCostsCls', 1, 324, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(32411207, '.   ()', 'StoredPaymentContent', '.   ()', 'StoredPaymentContentDet', 1, 324, 1, 0, '', 0, null, 0, 2, '') ;

--   , (1)
CALL ImportField(90310001, ' ', 'BUILDDATE', ' ', 'BuildDate', 1, 903, 0, 0, '', 0, 17645, 0, 1, '') ;

CALL ImportField(90310002, ' ', 'ACCEPTDATE', ' ', 'AcceptDate', 1, 903, 0, 0, '', 0, 17646, 0, 1, '') ;

CALL ImportField(90310003, ' ', 'DFAccountName', ' ', 'IncAccountName', 1, 903, 0, 0, '', 0, 17112, 0, 1, '') ;

CALL ImportField(90310008, '', 'BudgetRef', '', 'BudgetRef', 1, 903, 0, 0, '', 0, 17649, 0, 1, '') ;

CALL ImportField(90310009, '  ', 'RejectCls', '  ', 'RejectCls', 1, 903, 0, 0, '', 0, 17663, 0, 1, '') ;

CALL ImportField(90310010, '  ()', 'RejectCause', '  ()', 'RejectCause', 1, 903, 0, 0, '', 0, 17664, 0, 1, '') ;

CALL ImportField(90310011, ' ', 'DocNumber', ' ', 'DocNumber', 1, 903, 0, 0, '', 0, 17648, 0, 1, '') ;

CALL ImportField(90310059, ' ', 'ID', ' ', 'ID', 1, 903, 0, 1, '', 0, 17644, 0, 1, '') ;

CALL ImportField(90310061, ' ()', 'INCACCOUNT', ' ', 'IncAccount', 1, 903, 0, 1, '', 0, 17647, 0, 1, '') ;

CALL ImportField(90310072, ' (-)', 'Summa', ' (-)', 'Summa', 1, 903, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(90310073, '  ', 'SenderID', '  ', 'SenderID', 1, 903, 0, 1, '', 0, 17660, 0, 1, '') ;

CALL ImportField(90310075, ' ', 'DocStateRef', ' ', 'DocStateRef', 1, 903, 0, 1, '', 0, 25481, 0, 1, '') ;

CALL ImportField(90310076, '', 'DepartmentCls', '  ,  ', 'DepartmentCls', 1, 903, 0, 0, '', 0, 27626, 0, 1, '') ;

CALL ImportField(90311020, '', 'GOSNI', '', 'GosNI', 1, 903, 1, 0, '', 0, 17683, 0, 1, '') ;

CALL ImportField(90311021, '', 'INN20', ' ', 'Org_refKPP', 1, 903, 1, 0, '', 0, 16653, 0, 1, '') ;

CALL ImportField(90311022, '', 'INN', ' ', 'Org_refINN', 1, 903, 1, 0, '', 0, 16645, 0, 1, '') ;

CALL ImportField(90311023, '', 'DOCNUM', '', 'DocNum', 1, 903, 1, 0, '', 0, 17707, 0, 1, '') ;

CALL ImportField(90311024, '. ', 'SUBKD', '. ', 'SubKD', 1, 903, 1, 0, '', 0, 17681, 0, 1, '') ;

CALL ImportField(90311025, '', 'NDS', '', 'NDS', 1, 903, 1, 0, '', 0, 17698, 0, 1, '') ;

CALL ImportField(90311026, ' ', 'MeansType', ' ', 'MeansType', 1, 903, 1, 0, '', 0, 17699, 0, 1, '') ;

CALL ImportField(90311027, ' ', 'ACC', '  ', 'AccountRefName', 1, 903, 1, 0, '', 0, 17112, 0, 1, '') ;

CALL ImportField(90311028, ' ', 'DocDate', ' ', 'DocDate', 1, 903, 1, 0, '', 0, 17708, 0, 1, '') ;

CALL ImportField(90311029, ' ', 'facialAcc_Cls', ' ', 'FacialAcc_Cls', 1, 903, 1, 0, '', 0, 17697, 0, 1, '') ;

CALL ImportField(90311030, '', 'KESR', '', 'KESR', 1, 903, 1, 0, '', 0, 17712, 0, 1, '') ;

CALL ImportField(90311033, '', 'Debit', '', 'Debit', 1, 903, 1, 0, '', 0, 17673, 0, 1, '') ;

CALL ImportField(90311035, ' ', 'CLSType', ' ', 'ClsType', 1, 903, 1, 0, '', 0, 17723, 0, 1, '') ;

CALL ImportField(90311036, '', 'Credit', '', 'Credit', 1, 903, 1, 0, '', 0, 17674, 0, 1, '') ;

CALL ImportField(90311037, '', 'Name', ' -', 'Org_refName', 1, 903, 1, 0, '', 0, 16646, 0, 1, '') ;

CALL ImportField(90311038, '', 'DOCTYPE', '', 'DocType', 1, 903, 1, 0, '', 0, 17675, 0, 1, '') ;

CALL ImportField(90311039, '', 'Note', '', 'Note', 1, 903, 1, 0, '', 0, 17692, 0, 1, '') ;

CALL ImportField(90311040, '', 'BuhOperationCLS', '', 'BuhOperationCLS', 1, 903, 1, 0, '', 0, 17720, 0, 1, '') ;

CALL ImportField(90311041, '', 'OKATO', 'OKATO', 'OKATO', 1, 903, 1, 1, '', 0, 17728, 0, 1, '') ;

CALL ImportField(90311042, ' ', 'ADDOKATO', ' ', 'AddOKATO', 1, 903, 1, 1, '', 0, 17729, 0, 1, '') ;

CALL ImportField(90311045, ' ', 'REGIONCLS', '', 'RegionCLS', 1, 903, 1, 0, ',', 0, 17682, 0, 1, '') ;

CALL ImportField(90311047, '', 'ACCOUNTINDEX', '', 'AccountIndex', 1, 903, 1, 0, '', 0, 17678, 0, 1, '') ;

CALL ImportField(90311048, '', 'FactCode', '', 'Fact', 1, 903, 1, 0, '', 0, 36863, 0, 1, '') ;

CALL ImportField(90311049, '', 'DocBaseCode', '', 'DocBase', 1, 903, 1, 0, ',', 0, 36865, 0, 1, '') ;

CALL ImportField(90311052, '( )', 'IsBlocked', '', 'IsBlocked', 1, 903, 1, 0, '', 0, 17734, 0, 1, '') ;

CALL ImportField(90311053, ' ( )', 'BlockedCause', ' ', 'BlockedCause', 1, 903, 1, 0, '', 0, 17735, 0, 1, '') ;

CALL ImportField(90311054, ' ( )', 'UnBlockedDate', ' ', 'UnBlockedDate', 1, 903, 1, 0, '', 0, 17736, 0, 1, '') ;

CALL ImportField(90311055, ' ( )', 'UnBlockedCause', ' ', 'UnblockedCause', 1, 903, 1, 0, '', 0, 17737, 0, 1, '') ;

CALL ImportField(90311056, ' ', 'FundsSource', ' ', 'FundsSource', 1, 903, 1, 0, '', 0, 17732, 0, 1, '') ;

CALL ImportField(90311057, '', 'DirectionCLSCode', '', 'DirectionCls', 1, 903, 1, 0, '', 0, 36861, 0, 1, '') ;

CALL ImportField(90311058, '   ', 'taxnote', '   ', 'TaxNote', 1, 903, 1, 0, '', 0, 17705, 0, 1, '') ;

CALL ImportField(90311062, ' ', 'PROGINDEX', ' ', 'ProgIndex', 1, 903, 1, 1, '', 0, 17685, 0, 1, '') ;

CALL ImportField(90311063, '()', 'IFS', '   ', 'IFS', 1, 903, 1, 1, '', 0, 17721, 0, 1, '') ;

CALL ImportField(90311064, '()', 'KD', '   ', 'KD', 1, 903, 1, 1, '', 0, 17680, 0, 1, '') ;

CALL ImportField(90311066, ' ', 'ID', ' ', 'Id', 1, 903, 1, 1, '', 0, 17669, 0, 1, '') ;

CALL ImportField(90311067, '  ', 'ORG_REF', '', 'Org_ref', 1, 903, 1, 1, '', 0, 17677, 0, 1, '') ;

CALL ImportField(90311069, 'REcordIndex', 'RECORDINDEX', 'REcordIndex', 'RecordIndex', 1, 903, 1, 1, '', 0, 17686, 0, 1, '') ;

CALL ImportField(90311070, ' ()', 'ACC_REF', ' ()', 'AccountRef', 1, 903, 1, 1, '', 0, 17679, 0, 1, '') ;

CALL ImportField(90311074, ' . (  )', 'ELNUM', ' . ', 'EL_DocNumber', 1, 903, 1, 1, '', 0, 19317, 0, 1, '') ;

CALL ImportField(90311075, '   ()', 'TransfertCls', '   ()', 'TransfertCls', 1, 903, 1, 1, '', 0, 17739, 0, 1, '') ;

CALL ImportField(90311076, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 903, 1, 0, '', 0, 25326, 0, 1, '') ;

CALL ImportField(90311079, ' ', 'SubsidyCls', '  ()', 'SubsidyCls', 1, 903, 1, 1, '', 0, 26627, 0, 1, '') ;

CALL ImportField(90311080, ' ', 'SubsidyClsCode', ' ', 'SubsidyClsCode', 1, 903, 1, 0, '', 0, 26641, 0, 1, '') ;

CALL ImportField(90311081, ' ', 'KDValue', ' ', 'KDValue', 1, 903, 1, 0, '', 0, 16836, 0, 1, '') ;

CALL ImportField(90311086, '', 'UINCode', '  ', 'UINCode', 1, 903, 1, 0, '', 0, 35368, 0, 1, '') ;

CALL ImportField(90311087, ' .  ()', 'FinType', '  ', 'FINTYPEKey', 1, 903, 1, 1, ',', 0, 36856, 0, 1, '') ;

CALL ImportField(90311088, ' . ', 'FinTypeCode', '  ', 'FINTYPE', 1, 903, 1, 0, ',', 0, 36853, 0, 1, '') ;

CALL ImportField(90311089, ' ()', 'DirectionCLS', '', 'DirectionClsKey', 1, 903, 1, 1, '', 0, 17733, 0, 1, '') ;

CALL ImportField(90311090, ' ()', 'Fact', '', 'FactKey', 1, 903, 1, 1, '', 0, 17710, 0, 1, '') ;

CALL ImportField(90311091, ' ()', 'DocBase', '', 'DocBaseKey', 1, 903, 1, 1, ',', 0, 17709, 0, 1, '') ;

CALL ImportField(90311095, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 903, 1, 0, '', 0, null, 0, 2, '') ;

--   , (1)
CALL ImportField(90510047, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 905, 0, 0, '', 0, null, 0, 2, '') ;

--   (), (1)
CALL ImportField(90611089, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 906, 1, 0, '', 0, null, 0, 2, '') ;

--   (), (1)
CALL ImportField(90710059, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 907, 0, 0, '', 0, null, 0, 2, '') ;

--   , (1)
CALL ImportField(180710004, ' ', 'Note', '', ' ', 1, 1807, 0, 0, '', 0, null, 0, 0, '') ;

--     , (1)
CALL ImportField(181810001, ' ', 'ID', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810002, ' ', 'ARCHIVENAME', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810003, ' ', 'PACKETNAME', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810004, ' ', 'REGNUM', '  ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810005, ' ', 'ANUMBER', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810006, ' ', 'SIGNDATE', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810007, ' ', 'VERSIONNUMBER', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810008, '  ', 'CUSTOMER_REGNUM', '  ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810009, ' ', 'CUSTOMER_FULLNAME', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810010, ' ', 'CUSTOMER_INN', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810011, ' ', 'CUSTOMER_KPP', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810012, ' ', 'PROTOCOLDATE', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810013, '-', 'DOCUMENTBASE', '-', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810014, '', 'PRICE', '', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810015, ' ', 'SINGLECUSTOMERREASON_ID', '     ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810016, '', 'SINGLECUSTOMERREASON_NAME', '      ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810017, ' ', 'EXECUTIONDATE_MONTH', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810018, ' ', 'EXECUTIONDATE_YEAR', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810019, ' ', 'SUPPLIER_INN', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810020, ' ', 'SUPPLIER_KPP', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810021, ' ', 'SUPPLIER_ORGANIZATIONNAME', ' ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810022, '  ', 'HREF', '   ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810023, '  ', 'FCSORDER_PLACING', '  ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810024, '', 'CUSTOMER_HEAD', '', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810025, '', 'SUPPLIER_HEAD', '', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810026, '  ', 'SINGLECUSTOMERREASON_HEAD', '     ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810027, ' ', 'EXECUTIONDATE_HEAD', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810028, '   ', 'FCSORDER_PLAC', '   ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810029, '  ', 'SUPPLIER_LF_SINGULARNAME', '   ()', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810030, ' ', 'PUBLISHDATE', '  ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181810031, ' ', 'BUDGET_CODE', ' ', ' ', 1, 1818, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811032, ' ', 'RECORDINDEX', ' ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811033, '  ', 'ID', '  ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811034, ' ', 'ISBUDGETARY', ' ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811035, '', 'AYEAR', '', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811036, ' ', 'SUBSTAGEMONTH', ' ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811037, ' ', 'SUBSTAGEYEAR', ' ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811038, '', 'KBK', '', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811039, '', 'PRICE', '', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181811040, ' ', 'ISBUDGETAR', '  ', ' ', 1, 1818, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181812041, ' ', 'RECORDINDEX', ' ', ' ', 1, 1818, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181812042, '  ', 'ID', '  ', ' ', 1, 1818, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181812043, '', 'NAME', ' ', ' ', 1, 1818, 2, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813044, '  ', 'ID', '  ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813045, ' ', 'ARCHIVENAME', ' ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813046, ' ', 'PACKETNAME', ' ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813047, ' ', 'REGNUM', '  ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813048, '  ', 'VERSIONNUMBER', '  ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813049, '', 'TERMINATION_PAID', '', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813050, ' ', 'CURRENTCONTRACTSTAGE', ' ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(181813051, ' ', 'PUBLISHDATE', ' ', ' ', 1, 1818, 3, 0, '', 0, null, 0, 0, '') ;

--  (), (1)
CALL ImportField(190110088, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 1901, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(190111108, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 1901, 1, 0, '', 0, null, 0, 2, '') ;

--    (), (1)
CALL ImportField(190210087, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 1902, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(190211106, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 1902, 1, 0, '', 0, null, 0, 2, '') ;

--   (), (1)
CALL ImportField(190310088, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 1903, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(190311107, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 1903, 1, 0, '', 0, null, 0, 2, '') ;

--    (), (1)
CALL ImportField(190610089, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 1906, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(190611109, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 1906, 1, 0, '', 0, null, 0, 2, '') ;

--   (), (1)
CALL ImportField(220110071, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 2201, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(220111082, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 2201, 1, 0, '', 0, null, 0, 2, '') ;

--   , +(2)
CALL ImportField(250310044, ' ', 'InfoNumber', '', 'InfoNumber', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250310045, ' ', 'NotifyDate', '', 'NotifyDate', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250310046, ' ', 'MoneyPromiseNumber', '', 'MoneyPromiseNumber', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250310047, ' ', 'PurportDoc', '', 'PurportDoc', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250310048, '  ', 'SupplierStoredProps', '', 'SupplierStoredProps', 2, 2503, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(250312054, '    ', 'OldNumber', '', 'OldNumber', 2, 2503, 2, 0, '', 0, 20263, 0, 0, '') ;

CALL ImportField(250312055, ' ', 'PromiseNumber', '', 'PromiseNumber', 2, 2503, 2, 0, '', 0, 27624, 0, 0, '') ;

--  , +(2)
CALL ImportField(250412107, '   ()', 'BudAllocationCls', '', ' ', 2, 2504, 2, 1, '', 0, null, 0, 0, '') ;

--  -, +(2)
CALL ImportField(300611065, '   ()', 'BudAllocationCls', '', ' ', 2, 3006, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(440110061, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 4401, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(440111072, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 4401, 1, 0, '', 0, null, 0, 2, '') ;

--  ,, (1)
CALL ImportField(440310057, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 4403, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(440311069, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 4403, 1, 0, '', 0, null, 0, 2, '') ;

--  / , (1)
CALL ImportField(520110001, ' ', 'id', ' ', 'id', 1, 5201, 0, 1, '', 0, 25404, 0, 1, '') ;

CALL ImportField(520110002, '   ', 'ISSUEDATE', '   ', 'ISSUEDATE', 1, 5201, 0, 0, '', 0, 25405, 0, 1, '') ;

CALL ImportField(520110004, ' ( )', 'LAWDEPARTMENTDATE', ' ( )', 'LAWDEPARTMENTDATE', 1, 5201, 0, 0, '', 0, 25407, 0, 1, '') ;

CALL ImportField(520110005, ' ( )', 'LAWDEPARTMENTNUMBER', ' ( )', 'LAWDEPARTMENTNUMBER', 1, 5201, 0, 0, '', 0, 25408, 0, 1, '') ;

CALL ImportField(520110006, '    ', 'LEVIERACC_REF', '   ', 'LEVIERACC_REF', 1, 5201, 0, 1, '', 0, 25409, 0, 0, '') ;

CALL ImportField(520110007, '   ', 'LEVIERORG_REF', '   ', 'LEVIERORG_REF', 1, 5201, 0, 1, '', 0, 25410, 0, 0, '') ;

CALL ImportField(520110008, '  ', 'NAMEJUDICIALAGENCY', '  ', 'NAMEJUDICIALAGENCY', 1, 5201, 0, 0, '', 0, 25411, 0, 1, '') ;

CALL ImportField(520110009, '  ', 'NAMEJUDICIALDECISION', '  ', 'NAMEJUDICIALDECISION', 1, 5201, 0, 0, '', 0, 25412, 0, 1, '') ;

CALL ImportField(520110010, '', 'NOTE', '', 'NOTE', 1, 5201, 0, 0, '', 0, 25413, 0, 1, '') ;

CALL ImportField(520110011, '  ', 'UNIQUENUMBER', '    ', 'UNIQUENUMBER', 1, 5201, 0, 0, '', 0, 31836, 0, 1, '') ;

CALL ImportField(520110012, '  ( )', 'PRESENTDATE', '(  )', 'PRESENTDATE', 1, 5201, 0, 0, '', 0, 31834, 0, 1, '') ;

CALL ImportField(520110013, ' ', 'NUMBERDOSSIER', ' ', 'NUMBERDOSSIER', 1, 5201, 0, 0, '', 0, 25416, 0, 1, '') ;

CALL ImportField(520110015, ' ', 'REJECTCAUSE', '  ()', 'REJECTCAUSE', 1, 5201, 0, 0, '', 0, 25419, 0, 1, '') ;

CALL ImportField(520110016, ' ', 'REJECT_CLS', ' ', 'RejectCls', 1, 5201, 0, 1, '', 0, 25418, 0, 1, '') ;

CALL ImportField(520110017, '  ', 'SHEETSCOUNT', '  ', 'SHEETSCOUNT', 1, 5201, 0, 0, '', 0, 31835, 0, 1, '') ;

CALL ImportField(520110018, '   ', 'DELIVERYDATE', '   ', 'DELIVERYDATE', 1, 5201, 0, 0, '', 0, 31832, 0, 1, '') ;

CALL ImportField(520110019, '-    ', 'COURTSHEETSCOUNT', '    ', 'COURTSHEETSCOUNT', 1, 5201, 0, 0, '', 0, 31830, 0, 1, '') ;

CALL ImportField(520110021, '      ', 'STARTDATE', '      ', 'STARTDATE', 1, 5201, 0, 1, '', 0, 25427, 0, 1, '') ;

CALL ImportField(520110026, '', 'BUDGETREF', '', 'BudgetRef', 1, 5201, 0, 0, '', 0, 25391, 0, 1, '') ;

CALL ImportField(520110029, '  ', 'DOCNUMBER', '  ', 'DOCNUMBER', 1, 5201, 0, 0, '', 0, 25398, 0, 1, '') ;

CALL ImportField(520110030, '', 'DOCSTATEREF', '', 'DOCSTATEREF', 1, 5201, 0, 1, '', 0, 25399, 0, 1, '') ;

CALL ImportField(520110032, '', 'ISINVALID', '   ,          ', 'ISINVALID', 1, 5201, 0, 0, '', 0, 31833, 0, 1, '') ;

CALL ImportField(520110033, '/  ', 'FACIALACC_CLS', '/  ', 'FACIALACC_CLS', 1, 5201, 0, 0, '', 0, 25403, 0, 1, '') ;

CALL ImportField(520110034, '', 'WRITEXECUTIONTOTALSUMMA', '', 'WRITEXECUTIONTOTALSUMMA', 1, 5201, 0, 0, '', 0, 25432, 0, 1, '') ;

CALL ImportField(520110039, '()', 'LivierInn20', '()', 'LevierOrgKPP', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110045, '()', 'LevierInn', '()', 'LevierOrgINN', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110046, '()', 'LevierName', '', 'LevierName', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110048, '  ', 'SENDERID', '', 'SenderID', 1, 5201, 0, 0, '', 0, 25425, 0, 1, '') ;

CALL ImportField(520110049, '    ', 'ENDDATE', '     ', 'ENDDATE', 1, 5201, 0, 0, '', 0, 25402, 0, 1, '') ;

CALL ImportField(520110051, '  ', 'CASECATEGORY', '  ', 'CASECATEGORY', 1, 5201, 0, 0, '', 0, 31829, 0, 1, '') ;

CALL ImportField(520110052, ' . ', 'WritType', '  : 0 - ; 1 - /; 2 -   ', 'WritType', 1, 5201, 0, 0, '', 0, 31838, 0, 1, '') ;

CALL ImportField(520110053, '', 'WritPeriod', '   : 0 - ; 1 - ; 2 - ', 'WritPeriod', 1, 5201, 0, 0, '', 0, 31837, 0, 1, '') ;

CALL ImportField(520110054, ' ', 'InnerNumber', '', 'InnerNumber', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110055, '  -', 'NameJudicialAgencyRef', '', 'NameJudicialAgencyRef', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110056, '  ', 'JudicialDecisionDate', '', 'JudicialDecisionDate', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110057, '  ', 'NumberPostNotice', '', 'NumberPostNotice', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110058, '  ', 'DatePostNotice', '', 'DatePostNotice', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110059, ' ', 'NumberDepartmentCB', '', 'NumberDepartmentCB', 1, 5201, 0, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520110061, ' ', 'CompletionDate', '   ', 'CompletionDate', 1, 5201, 0, 0, '', 0, 38743, 0, 1, '') ;

CALL ImportField(520110062, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 5201, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(520111001, '.  ', 'BudgetPromise', '.  ', 'BudgetPromise', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111003, '', 'DIRECTIONCLSCode', '', 'DIRECTIONCLS', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111004, ' ', 'DOCTYPE', ' ', 'DOCTYPE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111005, '  ', 'FACIALACC_CLS', '  ', 'FACIALACC_CLS', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111006, '', 'FACTCode', '', 'FACT', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111007, ' ', 'FINSOURCE', ' ', 'FINSOURCE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111008, ' . ', 'FINTYPECode', ' . ', 'FINTYPE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111009, '', 'KCSR', '', 'KCSR', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111010, '()', 'KCSRCode', '()', 'KCSR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111011, '', 'KESR', '', 'KESR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111012, '()', 'KFSR', '()', 'KFSR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111013, '', 'KVR', '', 'KVR', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111014, '()', 'KVRCode', '()', 'KVR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111015, '', 'KVSR', '', 'KVSR', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111016, '()', 'KVSRCode', '()', 'KVSR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111017, ' ', 'MEANSTYPE', ' ', 'MEANSTYPE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111018, ' ', 'PROGINDEX', ' ', 'PROGINDEX', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111019, ' ', 'PROMISE', ' ', 'PROMISE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111020, ' ', 'RECORDINDEX', ' ', 'RECORDINDEX', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111021, ' ', 'REGIONCLS', '', 'REGIONCLS', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111022, ' ', 'SUBKESR', ' ', 'SUBKESR', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111023, '   ', 'WRITEXECUTIONSUMMA', '   ', 'WRITEXECUTIONSUMMA', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111030, '( )', 'MONTH01', '     ', 'MONTH01', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111031, '( )', 'MONTH02', '     ', 'MONTH02', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111032, '( )', 'MONTH03', '     ', 'MONTH03', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111033, '( )', 'MONTH04', '     ', 'MONTH04', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111034, '( )', 'MONTH05', '     ', 'MONTH05', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111035, '( )', 'MONTH06', '     ', 'MONTH06', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111036, '( )', 'MONTH07', '     ', 'MONTH07', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111037, '( )', 'MONTH08', '     ', 'MONTH08', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111038, '( )', 'MONTH09', '     ', 'MONTH09', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111039, '( )', 'MONTH10', '     ', 'MONTH10', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111040, '( )', 'MONTH11', '     ', 'MONTH11', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111041, '( )', 'MONTH12', '     ', 'MONTH12', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111042, ' 1( )', 'QUARTER1', '      ', 'QUARTER1', 1, 5201, 1, 0, '1', 0, null, 0, 1, '1') ;

CALL ImportField(520111043, ' 2( )', 'QUARTER2', '      ', 'QUARTER2', 1, 5201, 1, 0, '2', 0, null, 0, 1, '2') ;

CALL ImportField(520111044, ' 3( )', 'QUARTER3', '      ', 'QUARTER3', 1, 5201, 1, 0, '3', 0, null, 0, 1, '3') ;

CALL ImportField(520111045, ' 4( )', 'QUARTER4', '      ', 'QUARTER4', 1, 5201, 1, 0, '4', 0, null, 0, 1, '4') ;

CALL ImportField(520111046, '    ( )', 'MONTHLYDATE', '    ', 'MONTHLYDATE', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111047, '    ( )', 'QUARTERLYMONTHDAY', '     ', 'QUARTERLYMONTHDAY', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111048, '    ( )', 'QUARTERLYMONTHNUMBER', '      ', 'QUARTERLYMONTHNUMBER', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111050, ' ', 'SubsidyCls', '  ()', 'SubsidyCls', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111051, ' ', 'SubsidyClsCode', ' ', 'SubsidyClsCode', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111052, '  ', 'TransfertCls', '   ()', 'TransfertCls', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111053, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111054, '  ', 'BudAllocationClsCode', '', 'BudAllocationClsCode', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111055, '  ', 'BudAllocationCls', '', 'BudAllocationCls', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111056, '  ', 'PayPromiseClsCode', '', 'PayPromiseClsCode', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111057, '  ', 'PayPromiseCls', '', 'PayPromiseCls', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111058, ' ', 'id', ' ', 'id', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111059, ' ()', 'DIRECTIONCLS', '', 'DIRECTIONCLSKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111060, ' ()', 'FACT', '', 'FACTKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111061, ' . ()', 'FINTYPE', ' . ()', 'FINTYPEKey', 1, 5201, 1, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520111064, ' ', 'kd', ' ', 'KD', 1, 5201, 1, 1, '', 0, 38500, 0, 1, '') ;

CALL ImportField(520111070, ' ', 'KDValue', '', 'KDValue', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111071, ' ', 'ClsType', ' ', 'ClsType', 1, 5201, 1, 0, '', 0, 38499, 0, 1, '') ;

CALL ImportField(520111072, ' ', 'Note', '  ', 'Note', 1, 5201, 1, 0, '', 0, 38765, 0, 1, '') ;

CALL ImportField(520111073, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111074, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 5201, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(520111075, ' ', 'IFS', ' ', 'IFS', 1, 5201, 1, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520111076, ' ()', 'IFS_DescriptionCode', ' ()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111077, '()', 'IFS_KVSRCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111078, '()', 'IFSAGCode', '()', ' ', 1, 5201, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(520111079, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 5201, 1, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(520112001, ' ', 'id', ' ', 'id', 1, 5201, 2, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520112002, '  ()', 'NOTIFYCLS', ' ', 'NOTIFYCLS', 1, 5201, 2, 0, '', 0, 31865, 0, 1, '') ;

CALL ImportField(520112003, '', 'DESCRIPTION', '', 'DESCRIPTION', 1, 5201, 2, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520112004, '', 'NOTE', '', 'NOTE', 1, 5201, 2, 0, '', 0, 31864, 0, 1, '') ;

CALL ImportField(520112005, ' ', 'RECORDINDEX', '  ', 'RECORDINDEX', 1, 5201, 2, 1, '', 0, null, 0, 1, '') ;

CALL ImportField(520112006, '', 'NOTIFYNUMBER', ' ', 'NOTIFYNUMBER', 1, 5201, 2, 0, '', 0, null, 0, 1, '') ;

CALL ImportField(520112007, '', 'NOTIFYDATE', ' ', 'NOTIFYDATE', 1, 5201, 2, 0, '', 0, null, 0, 1, '') ;

--    , (1)
CALL ImportField(550110166, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 5501, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(550111168, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 5501, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550111169, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111170, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 5501, 1, 0, '', 0, null, 0, 2, '') ;

--    , +(2)
CALL ImportField(550111001, ' ', 'ExecDocMPNum', ' ', 'ExecDocMPNum', 2, 5501, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550111002, ' ', 'ExecDocDate', '  ', 'ExecDocDate', 2, 5501, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550210151, '.  ', 'StoredContent', '.  ', 'StoredContent', 1, 5502, 0, 0, '', 0, null, 0, 2, '') ;

CALL ImportField(550211147, '', 'ContractCostsCls', '', 'ContractCostsClsKey', 1, 5502, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(550211148, '', 'ContractCostsClsCode', '', 'ContractCostsCls', 1, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211158, '.   ()', 'StoredContentDet', '.   ()', 'StoredContentDet', 1, 5502, 1, 0, '', 0, null, 0, 2, '') ;

--    , +(2)
CALL ImportField(550211001, ' ', 'ExecDocMPNum', ' ', 'ExecDocMPNum', 2, 5502, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(550211002, ' ', 'ExecDocDate', '  ', 'ExecDocDate', 2, 5502, 1, 0, '', 0, null, 0, 0, '') ;

--    , (1)
CALL ImportField(550311064, '', 'ContractCostsCls', '', 'ontractostsClsKey', 1, 5503, 1, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(989810004, '', 'CREATERUSER', '', ' ', 1, 9898, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989810006, '', 'UPDATERUSER', '', ' ', 1, 9898, 0, 1, '', 0, null, 0, 0, '') ;

--  , +(2)
CALL ImportField(989810001, '', 'ID', '', ' ', 2, 9898, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989810002, '', 'NAME', '', ' ', 2, 9898, 0, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(989810003, ' ', 'CREATEDATE', '', ' ', 2, 9898, 0, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(989810005, ' ', 'UPDATEDATE', '', ' ', 2, 9898, 0, 1, '', 0, null, 0, 0, '') ;

--  , (1)
CALL ImportField(30111175, ' -', 'DestContractCostsClsCode', ' ', 'DestContractCostsCls', 1, 301, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30111176, ' -', 'DestContractCostsCls', ' ', 'DestContractCostsClsKey', 1, 301, 1, 1, '', 0, null, 0, 0, '') ;

CALL ImportField(30111177, ' .', 'SourceContractCostsCls', ' ', 'SourceContractCostsClsKey', 1, 301, 1, 1, ',', 0, null, 0, 0, '') ;

CALL ImportField(30111178, ' .', 'SourceContractCostsClsCode', ' ', 'SourceContractCostsCls', 1, 301, 1, 0, ',', 0, null, 0, 0, '') ;

--  (), (1)
CALL ImportField(30311097, '', 'DestContractCostsCLSCode', '', 'DestContractCostsCls', 1, 303, 1, 0, '', 0, null, 0, 0, '') ;

CALL ImportField(30311098, '', 'DestContractCostsCls', '', 'DestContractCostsClsKey', 1, 303, 1, 1, '', 0, null, 0, 0, '') ;

--   , +(2)
CALL ImportField(301110053, ' ', 'SaleType', '', ' ', 2, 3011, 0, 0, '', 0, 21287, 0, 0, '') ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_IMPORT('     ',0,200,1,0,11,0,'[20011012] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[20011017] = 0)  ([988410008] = .[20011026]) 
   ((("..",[988410006])=0)
    (((".",.[20011017]), (".",[988410006]), "9.99.99.999.99"))
   (((".",[988410006])=(".",.[20011017]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[20011017]))) 
(((".", .[20011017]) div 100000) between 218 and 219)  
(((".", .[20011017]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 200, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',200,1,20011011,1) ;

CALL DOCLOCK_IMPORT('  ',0,201,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 201, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',201,-1,20110083,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',201,-1,20111198,1) ;

CALL DOCLOCK_IMPORT('  ',0,202,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 202, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',202,-1,20210091,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',202,-1,20211115,1) ;

CALL DOCLOCK_IMPORT('  ',0,203,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 203, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',203,-1,20310082,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',203,-1,20311103,1) ;

CALL DOCLOCK_IMPORT('  ',0,204,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 204, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',204,-1,20410087,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',204,-1,20411124,1) ;

CALL DOCLOCK_IMPORT('  ',0,205,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 205, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',205,-1,20510090,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',205,-1,20511111,1) ;

CALL DOCLOCK_IMPORT('  ',0,206,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 206, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',206,-1,20610090,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',206,-1,20611190,1) ;

CALL DOCLOCK_IMPORT('  ',0,207,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 207, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',207,-1,20710161,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',207,-1,20711190,1) ;

CALL DOCLOCK_IMPORT('  ',0,208,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 208, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',208,-1,20810161,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',208,-1,20811191,1) ;

CALL DOCLOCK_IMPORT('  ',0,209,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 209, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',209,-1,20910028,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',209,-1,20911145,1) ;

CALL DOCLOCK_IMPORT('  ',0,210,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 210, -1, 0, 1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',210,-1,21012061,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',210,-1,21010028,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',210,-1,21011049,1) ;

CALL DOCLOCK_IMPORT('  ',0,211,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 211, -1, 0, 1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,-1,21112050,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,-1,21110028,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',211,-1,21111050,1) ;

CALL DOCLOCK_IMPORT('  ',0,212,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 212, -1, 0, 1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,-1,21212051,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,-1,21210028,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',212,-1,21211051,1) ;

CALL DOCLOCK_IMPORT('     ',0,300,1,0,11,0,'([30011019] = 2)   ((( <> 305)  ( <> 302))    (("_..",[30010008]) between 010800 and 011099))',0,3,'          ,    / , ()         /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30011025] = 0)  (.[30011034] = [988410008])
 ((("..",[988410006])=0)
  (((".",.[30011025]), (".",[988410006]), "9.99.99.999.99"))
  (((".",[988410006])=(".",.[30011025]))
     ((".",[988410006])=0))
 (("..",[988410006])=("..",.[30011025])))
 (((".", .[30011025]) div 100000) between 218 and 219) 
 (((".", .[30011025]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 300, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',300,1,30011018,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,301,1,0,11,0,'[30110110] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30111122] = 0)  (.[30111130] = [988410008])
 ((("..",[988410006])=0)
    (((".",.[30111122]), (".",[988410006]), "9.99.99.999.99"))
   (((".",[988410006])=(".",.[30111122]))
     ((".",[988410006])=0))
   (("..",[988410006])=("..",.[30111122])))
 (((".", .[30111122]) div 100000) between 218 and 219)
 (((".", .[30111122]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 301, 1, 0, 1) ;

--  "   ."
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',301,1,30111136,1) ;

CALL DOCLOCK_IMPORT('  ',0,302,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 302, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',302,-1,30210163,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',302,-1,30211158,1) ;

CALL DOCLOCK_IMPORT('  ',0,304,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 304, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30410150,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30411149,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30410147,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30410148,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30410151,1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',304,-1,30410149,1) ;

CALL DOCLOCK_IMPORT('  ',0,305,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 305, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',305,-1,30510173,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',305,-1,30511150,1) ;

CALL DOCLOCK_IMPORT('  ',0,308,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 308, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',308,-1,30810075,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',308,-1,30811119,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',308,-1,30810071,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',308,-1,30810072,1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',308,-1,30810073,1) ;

CALL DOCLOCK_IMPORT('    .  ',0,308,1,0,11,0,'[30811003] = 2',0,1,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[30811019] = 0)  (.[30811093] = [988410008]) 
 ((("..",[988410006])=0)
  (((".",.[30811019]), (".",[988410006]), "9.99.99.999.99"))
  (((".",[988410006])=(".",.[30811019]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[30811019])))
 (((".", .[30811019]) div 100000) between 218 and 219)
 (((".", .[30811019]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('    .  ', 308, 1, 0, 1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    .  ',308,1,30811063,1) ;

CALL DOCLOCK_IMPORT('  ',0,322,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 322, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',322,-1,32210082,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',322,-1,32211094,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',322,-1,32210078,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',322,-1,32210079,1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',322,-1,32210080,1) ;

CALL DOCLOCK_IMPORT('  ',0,323,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 323, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32310143,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32310144,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32311167,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32310140,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32310141,1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',323,-1,32310142,1) ;

CALL DOCLOCK_IMPORT('  ',0,324,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 324, -1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32410180,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32410181,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32411207,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32410177,1) ;

--  "(  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32410178,1) ;

--  " (  )"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',324,-1,32410179,1) ;

CALL DOCLOCK_IMPORT('     ',0,900,1,0,11,0,'([90011001] = 2)  (( <> 903)    (("_..",[90011008]) between 010800 and 011099))',0,3,'          ,  / , ()   (09.03)   .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[90011004] = 0)  (.[90011005] = [988410008]) 
 ((("..",[988410006])=0)
  (((".",.[90011004]), (".",[988410006]), "9.99.99.999.99"))
  (((".",[988410006])=(".",.[90011004]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[90011004])))
 (((".", .[90011004]) div 100000) between 218 and 219) 
 (((".", .[90011004]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 900, 1, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',900,1,90011002,1) ;

CALL DOCLOCK_IMPORT('  ',0,903,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 903, 1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',903,1,90311095,1) ;

CALL DOCLOCK_IMPORT('  ',0,905,0,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 905, 0, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',905,0,90510047,1) ;

CALL DOCLOCK_IMPORT('  ',0,906,1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 906, 1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',906,1,90611089,1) ;

CALL DOCLOCK_IMPORT('  ',0,907,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 907, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',907,-1,90710059,1) ;

CALL DOCLOCK_IMPORT('  ',0,1901,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1901, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1901,-1,190110088,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1901,-1,190111108,1) ;

CALL DOCLOCK_IMPORT('  ',0,1902,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1902, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1902,-1,190210087,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1902,-1,190211106,1) ;

CALL DOCLOCK_IMPORT('  ',0,1903,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1903, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1903,-1,190310088,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1903,-1,190311107,1) ;

CALL DOCLOCK_IMPORT('  ',0,1906,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 1906, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1906,-1,190610089,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',1906,-1,190611109,1) ;

CALL DOCLOCK_IMPORT('  ',0,2201,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2201, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2201,-1,220110071,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2201,-1,220111082,1) ;

CALL DOCLOCK_IMPORT('     ',0,2201,1,0,11,0,'',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[220111046] = 0)  (.[220111012] = [988410008])
 ((("..",[988410006])=0)                          
  (((".",.[220111046]), (".",[988410006]), "9.99.99.999.99")) 
  (((".",[988410006])=(".",.[220111046]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[220111046])))
 (((".", .[220111046]) div 100000) between 218 and 219) 
 (((".", .[220111046]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 2201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',2201,1,220111064,1) ;

CALL DOCLOCK_IMPORT('  ',0,2503,2,0,12,0,'(50,52,3) = 1',0,3,'',0,'',null,'',2) ;

CALL DOCLOCKFIELDS_DELETE('  ', 2503, 2, 0, 2) ;

--  "    "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312054,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312055,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312029,2) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',2503,2,250312002,2) ;

CALL DOCLOCK_IMPORT('    -',0,3006,0,0,10,0,'([300610051] is not null)  ([300610017] < 2017)',0,1,'',0,'    -',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('    -', 3006, 0, 0, 2) ;

--  "  /"
CALL DOCLOCKFIELDS_INSERTFIELD('    -',3006,0,300610051,2) ;

CALL DOCLOCK_IMPORT('     ',0,3011,0,0,10,0,'[301110029] is not null',0,1,'',0,'     ',0,'',2) ;

CALL DOCLOCKFIELDS_DELETE('     ', 3011, 0, 0, 2) ;

--  "  /"
CALL DOCLOCKFIELDS_INSERTFIELD('     ',3011,0,301110029,2) ;

CALL DOCLOCK_IMPORT('  ',0,4401,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 4401, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',4401,-1,440110061,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',4401,-1,440111072,1) ;

CALL DOCLOCK_IMPORT('  ',0,4403,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 4403, -1, 0, 1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',4403,-1,440311069,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',4403,-1,440310057,1) ;

CALL DOCLOCK_IMPORT('  ',0,5201,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, -1, 0, 1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,-1,520111079,1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,-1,520110062,1) ;

CALL DOCLOCK_IMPORT('  ',0,5201,0,0,10,0,'([520110052] = 5)  (([520110052] = 4)    (("_._",[520110033])   ("_._",[520110033])   ("_.",[520110033])))   (([520110052] = 3)    (("_.",[520110033])  ("_.",[520110033])   ))   (([520110052] = 0)  ([520110052] = 1)  ([520110052] = 2))',0,3,'',0,'       ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 0, 0, 1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110052,1) ;

CALL DOCLOCK_IMPORT('     ',0,5201,1,0,11,0,'[520111071] = 2',0,3,'          .      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[520111064] = 0)  ([988410008] = .[520111070]) 
   ((("..",[988410006])=0)
   (((".",.[520111064]), (".",[988410006]), "9.99.99.999.99"))
   (((".",[988410006])=(".",.[520111064]))
    ((".",[988410006])=0))
   (("..",[988410006])=("..",.[520111064]))) 
(((".", .[520111064]) div 100000) between 218 and 219) 
(((".", .[520111064]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5201, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5201,1,520111052,1) ;

CALL DOCLOCK_IMPORT('  ',0,5501,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5501, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5501,-1,550110166,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5501,-1,550111170,1) ;

CALL DOCLOCK_IMPORT('     ',0,5501,1,0,11,0,'([550111066] = 2)  ((("_..",[550111052]) between 010800 and 011099))',0,3,'          ,    / , ().      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550111090] = 0)  (.[550111156] = [988410008]) 
 ((("..",[988410006])=0)
  (((".",.[550111090]), (".",[988410006]), "9.99.99.999.99"))  
  (((".",[988410006])=(".",.[550111090]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[550111090])))
 (((".", .[550111090]) div 100000) between 218 and 219) 
  (((".", .[550111090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5501, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5501,1,550111144,1) ;

CALL DOCLOCK_IMPORT('  ',0,5502,-1,0,12,0,'',0,3,'',0,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5502, -1, 0, 1) ;

--  ".  "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5502,-1,550210151,1) ;

--  ".   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5502,-1,550211158,1) ;

CALL DOCLOCK_IMPORT('     ',0,5502,1,0,11,0,'([550211066] = 2)  ((("_..",[550211052]) between 010800 and 011099))',0,3,'          ,    / , ().      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       . ',0,'      ',null,'([988410006] = 0)  (.[550211090] = 0)  (.[550211135] = [988410008]) 
 ((("..",[988410006])=0)
  (((".",.[550211090]), (".",[988410006]), "9.99.99.999.99"))
  (((".",[988410006])=(".",.[550211090]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[550211090])))
 (((".", .[550211090]) div 100000) between 218 and 219) 
  (((".", .[550211090]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5502, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5502,1,550211125,1) ;

CALL DOCLOCK_IMPORT('     ',0,5503,1,0,11,0,'[550311008] = 2',0,1,'          ,    /          /.      0-  ,      ,   ,     0-     (  )  , , .       ,    ,       .',0,'      ',null,'([988410006] = 0)  (.[550311022] = 0)  (.[550311022] = [988410006])
 ((("..",[988410006])=0)
  (((".",.[550311022]), (".",[988410006]), "9.99.99.999.99"))
  (((".",[988410006])=(".",.[550311022]))
   ((".",[988410006])=0))
  (("..",[988410006])=("..",.[550311022])))
 (((".", .[550311022]) div 100000) between 218 and 219) 
 (((".", .[550311022]) div 1000) = 11302)',1) ;

CALL DOCLOCKFIELDS_DELETE('     ', 5503, 1, 0, 1) ;

--  "  "
CALL DOCLOCKFIELDS_INSERTFIELD('     ',5503,1,550311025,1) ;

CALL DOCLOCK_IMPORT('    ',0,202,1,0,11,0,'([20211096]=0) ((32,45,3) between 0 and 2)',0,3,'         ,    "() "',0,'    .      ,    "() "',null,'(((32,45,3) = 0)   ([980410006] like "?00") 
   (([980410006] like "??0")  (".KVR[CODE].{COUNTNOTNULL(CODE)}",
  (''CODE like "''+ [980410006] div 1 +''_"''))>1))
 (((32,45,3) = 1)  ([980410006] like "??0")  ([980410006] <> "000")) 
 (((32,45,3) = 2)  ([980410006] like "?00")  ([980410006] <> "000"))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 202, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',202,1,20211021,1) ;

CALL DOCLOCK_IMPORT('   ',0,204,0,0,11,0,'',0,1,'    .    () ,         01.08.00  01.11.99',0,'  .     () , (),   ,   ',null,'([960110035] between 10800 and 11199)',1) ;

CALL DOCLOCKFIELDS_DELETE('   ', 204, 0, 0, 1) ;

--  " ()"
CALL DOCLOCKFIELDS_INSERTFIELD('   ',204,0,20410039,1) ;

CALL DOCLOCK_IMPORT('   /',0,204,1,0,11,0,'',0,1,'  - \. -          01.08.00  01.11.99',0,'-       () , (),   ,   ',null,'(("..",[984110031]) between 10800 and 11199)',1) ;

CALL DOCLOCKFIELDS_DELETE('   /', 204, 1, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   /',204,1,20411033,1) ;

CALL DOCLOCK_IMPORT('     (3)',0,300,0,0,11,0,'(("/._",[30010021]) = 1)   (("/.",[30010021]) = 0)   (("/._",[30010021]) = 0)  (("/.",[30010021]) = 0)  (("/.",[30010021])=0)',0,1,'         /,   /c,      (),    ,   ',0,'         (),     ',null,'((".",[984110031]) between 011000 and 011199) 
((".",[984110031]) between 010100 and 010199)',1) ;

CALL DOCLOCKFIELDS_DELETE('     (3)', 300, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('     (3)',300,0,30010008,1) ;

CALL DOCLOCK_IMPORT('   ()',0,9903,0,0,9,0,'(([990310057] >= 10800)  ([990310057] <= 11099)    (([990312091]) = 0)    (([990312089]) <= ([990312090])))  (([990310057] >= 11100)  ([990310057] <= 11199)    (([990312091]) = 0)  (([990312088]) = 0)    (([990312089])= 0)  (([990312090]) = 0)   (([990312093]) = 0))   (([990310057] >= 10000)  ([990310057] <= 10499)    (([990312088]) = 0)  (([990312092])= 0)    (([990312090]) = 0)  (([990312093]) = 0))  (([990310057] >= 10500)  ([990310057] <= 10799)    (([990312091]) = 0)  (([990312088]) = 0)    (([990312092])= 0)  (([990312090]) = 0)   (([990312093]) = 0))  (([990310057] >= 20000)  ([990310057] <= 999999))  ([990310057] = 0)',0,3,'   /       01.00.00 - 01.11.99(, , ,  . )',0,'          ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('   ()', 9903, 0, 0, 1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('   ()',9903,0,990310057,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(20204900,'->_',null,20301,20601,' ()    ()',1,0,0,1,1,'',1,'','1616',0,'',1,0) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_DELETE(992502600) ;

CALL STATICLINK_IMPORT(990231000,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,20211112,0,0) ;

CALL STATICLINK_IMPORT(990231100,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,20311102,0,0) ;

CALL STATICLINK_IMPORT(990231200,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,20411120,0,0) ;

CALL STATICLINK_IMPORT(990231300,'.1.CONTRACTCOSTSCLS()->.ID',989710001,20511107,0,0) ;

CALL STATICLINK_IMPORT(990231400,'__.1.CONTRACTCOSTSCLS()->.ID',989710001,20611188,0,0) ;

CALL STATICLINK_IMPORT(990231500,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,20711188,0,0) ;

CALL STATICLINK_IMPORT(990231600,'__.1.CONTRACTCOSTSCLS()->.ID',989710001,20811189,0,0) ;

CALL STATICLINK_IMPORT(990231700,'_.2.CONTRACTCOSTSCLS()->.ID',989710001,21112048,0,0) ;

CALL STATICLINK_IMPORT(990231800,'_.2.CONTRACTCOSTSCLS()->.ID',989710001,21212049,0,0) ;

CALL STATICLINK_IMPORT(990336500,'.1.SOURCECONTRACTCOSTSCLS()->.ID',989710001,30211195,0,0) ;

CALL STATICLINK_IMPORT(990336600,'.1.SOURCECONTRACTCOSTSCLS()->.ID',989710001,30411148,0,0) ;

CALL STATICLINK_IMPORT(990336700,'.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,30511149,0,0) ;

CALL STATICLINK_IMPORT(990336800,'.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,30611151,0,0) ;

CALL STATICLINK_IMPORT(990337000,'.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,30811116,0,0) ;

CALL STATICLINK_IMPORT(990336900,'.1.SOURCECONTRACTCOSTSCLS(,)->.ID',989710001,30811117,0,0) ;

CALL STATICLINK_IMPORT(990337100,'_.1.SOURCECONTRACTCOSTSCLS()->.ID',989710001,31111109,0,0) ;

CALL STATICLINK_IMPORT(990337200,'_.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,31211144,0,0) ;

CALL STATICLINK_IMPORT(990337300,'_.1.SOURCECONTRACTCOSTSCLS()->.ID',989710001,31411145,0,0) ;

CALL STATICLINK_IMPORT(990337400,'_.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,31511101,0,0) ;

CALL STATICLINK_IMPORT(990337500,'.1.SOURCECONTRACTCOSTSCLS()->.ID',989710001,32211092,0,0) ;

CALL STATICLINK_IMPORT(990337700,'.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,32411205,0,0) ;

CALL STATICLINK_IMPORT(995504200,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,550111168,0,0) ;

CALL STATICLINK_IMPORT(995504300,'_.1.CONTRACTCOSTSCLS()->.ID',989710001,550211147,0,0) ;

CALL STATICLINK_IMPORT(995504400,'.1.CONTRACTCOSTSCLS()->.ID',989710001,550311064,0,0) ;

CALL STATICLINK_IMPORT(992502500,'.2.CONTRACTCOSTSCLS()->.ID',989710001,250212058,0,0) ;

CALL STATICLINK_IMPORT(992502800,'.2.CONTRACTCOSTSCLS()->.ID',989710001,250312052,0,0) ;

CALL STATICLINK_IMPORT(992502700,'.2.CONTRACTCOSTSCLS()->.ID',989710001,250412057,0,0) ;

CALL STATICLINK_IMPORT(993002500,'.1.CONTRACTCOSTSCLS()->.ID',989710001,300111100,0,0) ;

CALL STATICLINK_IMPORT(993002600,'.1.CONTRACTCOSTSCLS()->.ID',989710001,300611062,0,0) ;

CALL STATICLINK_IMPORT(995200900,'.1.CONTRACTCOSTSCLS()->.ID',989710001,520111074,0,0) ;

CALL STATICLINK_IMPORT(999903800,'.PURCHASETYPE ->.ID',989810001,989710010,0,0) ;

CALL STATICLINK_IMPORT(990337600,'.1.DESTCONTRACTCOSTSCLS()->.ID',989710001,32311166,0,0) ;

CALL STATICLINK_IMPORT(993002700,'.1.CONTRACTCOSTSCLS()->.ID',989710001,301111049,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
CALL STATUSICONS_IMPORT(40393,' ,   ',1807,0,'',1,1,1,0,'[180710004]',0,0,'([180710004] is not null) and ([180710004] <> '''')',1) ;

DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (1580, 121000, 121000, TO_DATE('24.01.2017 11:46:24', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 18.18, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.02, 30.03, 30.04, 30.05, 30.06, 30.10, 30.11, 36.10, 37.01, 39.01, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.97, 98.98, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.27, 99.28, 99.29, 99.30, 99.31', 'MALINOVKIN/malinovkin', TO_DATE('24.01.2017 11:47:24', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('12.10.00', 1210, 00, ' 12.1')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
